@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "High contrast theme" : "Kontrastreiches Design",
     "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ein kontrastreiches Design, das die Navigation erleichtert. Die Bildqualität wird reduziert, aber die Klarheit wird verbessert.",
-    "Dark theme (beta)" : "Dunkles Design (beta)",
+    "Dark theme" : "Dunkles Design",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ein dunkles Design, das die Augen entspannt, indem es die allgemeine Lichtstärke und Helligkeit reduziert. Es befindet sich noch in der Entwicklung, also melde bitte alle Probleme, die Du findest.",
     "Dyslexia font" : "Legasthenie-Schriftart",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren.",
@@ -13,6 +13,12 @@ OC.L10N.register(
     "Web Content Accessibility Guidelines" : "Richtlinien für die Barrierefreiheit von Webinhalten",
     "our issue tracker" : "Unser Issue Tracker",
     "our design team" : "Unser Design-Team",
-    "Enable" : "Aktivieren"
+    "Enable" : "Aktivieren",
+    "Dark theme (beta)" : "Dunkles Design (beta)",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic ist eine freie Schriftart, die entwickelt wurde, um einige der häufigsten Lesefehler, die durch Legasthenie verursacht werden, zu reduzieren. Die Schriftart wurde von Abelardo Gonzalez erstellt, die unter einer Quelloffenen Lizenz veröffentlicht wurde.",
+    "Provides multiple accessibilities options to ease your use of nextcloud" : "Bietet verschiedene Optionen für Barrierefreiheit, um die Nutzung von Nextcloud zu erleichtern.",
+    "Themes" : "Themen",
+    "Fonts" : "Schriftarten",
+    "enabled" : "aktiviert"
 },
 "nplurals=2; plural=(n != 1);");
