@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "High contrast theme" : "ハイコントラストテーマ",
     "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "ハイコントラストテーマは表示の質は下がりますが、見やすさは上がります。",
-    "Dark theme (beta)" : "ダークテーマ (ベータ版)",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "ダークテーマは目の負担になりにくいです。このテーマは開発中のためバグを見つけたら報告してください。",
     "Dyslexia font" : "Dyslexia フォント",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexicは、ディスレクシアによって引き起こされる一般的な読み間違いの一部を軽減するためにデザインされた、無料で利用できる書体/フォントです。",
@@ -13,6 +12,7 @@ OC.L10N.register(
     "Web Content Accessibility Guidelines" : "Webコンテンツ アクセシビリティガイドライン",
     "our issue tracker" : "問題追跡",
     "our design team" : "デザインチーム",
-    "Enable" : "有効にする"
+    "Enable" : "有効にする",
+    "Dark theme (beta)" : "ダークテーマ (ベータ版)"
 },
 "nplurals=1; plural=0;");
