@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "High contrast theme" : "Temă cu contrast înalt",
     "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Temă cu contrast înalt pentru ușurarea navigării. Calitatea visuală va fi redusă dar claritatea va fi mărită.",
-    "Dark theme (beta)" : "Temă întunecată (beta)",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Temă întunecată pentru ușurarea ochilor prin reducerea generală a luminozității. Temă în curs de dezvoltare deci vă rugăm să raportați orice problemă găsită.",
     "Dyslexia font" : "Font dislexic",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic este un tip de caractere / font gratuit destinat să atenueze unele erori comune de citire cauzate de dislexie.",
@@ -13,6 +12,7 @@ OC.L10N.register(
     "Web Content Accessibility Guidelines" : "Instrucțiuni privind accesibilitatea conținutului web",
     "our issue tracker" : "instrumentul nostru de urmărire a problemelor",
     "our design team" : "echipa noastră de design",
-    "Enable" : "Activează"
+    "Enable" : "Activează",
+    "Dark theme (beta)" : "Temă întunecată (beta)"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
