@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "High contrast theme" : "Motív vzhľadu s vysokým kontrastom",
     "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Motív vzhľadu s vysokým kontrastom pre uľahčenie navigácie. Zníži sa síce vizuálna kvalita, ale zvýši sa čitateľnosť.",
-    "Dark theme (beta)" : "Tmavý motív vzhľadu (beta)",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tmavý motív vzhľadu pre úľavu vašim očiam znížením celkovej svietivosti a jasu. Je ešte stále vo vývoji, ak náhodou narazíte na nejaký problém, tak nám ho prosím nahláste.",
     "Dyslexia font" : "Písmo pre dyslektikov",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je slobodný typ písma navrhnutý priamo pre obmedzenie vplyvu niektorých bežných porúch čítania spôsobených dyslexiou.",
@@ -13,6 +12,12 @@ OC.L10N.register(
     "Web Content Accessibility Guidelines" : "Usmernenia o prístupnosti webového obsahu",
     "our issue tracker" : "náš systém evidencie hlásenia chýb",
     "our design team" : "náš tím dizajnérov",
-    "Enable" : "Zapnúť"
+    "Enable" : "Zapnúť",
+    "Dark theme (beta)" : "Tmavý motív vzhľadu (beta)",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic je slobodný typ písma navrhnutý priamo pre obmedzenie vplyvu niektorých bežných porúch čítania spôsobených dyslexiou. Typ písma bol vytvorený autorom Abelardo Gonzalez, ktorý ho zverejnil pomocou open-source licencie.",
+    "Provides multiple accessibilities options to ease your use of nextcloud" : "Poskytuje viac možností prístupnosti pre uľahčenie používania Nextcloud",
+    "Themes" : "Vzhľady tém",
+    "Fonts" : "Druhy písma",
+    "enabled" : "povolené"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
