@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "High contrast theme" : "Тема високог контраста",
     "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Тема високог контраста олакшава навигацију. Биће мање лепа али јаснија и читљивија.",
-    "Dark theme (beta)" : "Тамна тема (бета)",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Тамна тема олакшава очима смањујући укупну осветљеност. Још је у развоју, па пријавите све грешке, уколико их нађете.",
     "Dyslexia font" : "Фонт Дислексија",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "„OpenDyslexic“ је бесплатни фонт дизајниран да умањи честе грешке у читању изазване дислексијом.",
@@ -13,6 +12,12 @@ OC.L10N.register(
     "Web Content Accessibility Guidelines" : "Смернице приступачности веб садржаја",
     "our issue tracker" : "наш пратилац проблема",
     "our design team" : "наши тим дизајнера",
-    "Enable" : "Укључи"
+    "Enable" : "Укључи",
+    "Dark theme (beta)" : "Тамна тема (бета)",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "„OpenDyslexic“ је бесплатни словни лик/фонт дизајниран да умањи честе грешке у читању изазване дислексијом. Словни лик је направио Абелардо Гонзалез, који га је дао под лиценцом отвореног кода.",
+    "Provides multiple accessibilities options to ease your use of nextcloud" : "Нуди више опција за приступачност да олакша употребу Некстклауда",
+    "Themes" : "Теме",
+    "Fonts" : "Фонтови",
+    "enabled" : "укључено"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
