@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "High contrast theme" : "Högkontrasttema",
     "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ett tema med hög kontrast för att underlätta din navigering. Visuell kvalitet kommer att minskas men klarhet kommer att ökas.",
-    "Dark theme (beta)" : "Mörkt tema (beta)",
     "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ett mörkt tema för att lätta dina ögon genom att minska den allmänna ljusstyrkan. Det är fortfarande under utveckling, så rapportera gärna eventuella problem ni hittar.",
     "Dyslexia font" : "Dyslexi-typsnitt",
     "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic är ett fritt typsnitt/font som är utformat för att mildra några av de vanligaste lässvårigheterna som orsakas av dyslexi.",
@@ -13,6 +12,12 @@ OC.L10N.register(
     "Web Content Accessibility Guidelines" : "Riktlinjer för webbinnehåll ur tillgänglighetssynpunkt",
     "our issue tracker" : "vår felrapportering",
     "our design team" : "vårt designteam",
-    "Enable" : "Aktivera"
+    "Enable" : "Aktivera",
+    "Dark theme (beta)" : "Mörkt tema (beta)",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic är en fri typsnitt/font som är utformad för att mildra några av de vanliga läsfel som orsakas av dyslexi. Typsnittet skapades av Abelardo Gonzalez, som släppte det som öppen källkod.",
+    "Provides multiple accessibilities options to ease your use of nextcloud" : "Ger flera åtkomstalternativ för att underlätta din användning av nextcloud",
+    "Themes" : "Teman",
+    "Fonts" : "Typsnitt",
+    "enabled" : "aktiverad"
 },
 "nplurals=2; plural=(n != 1);");
