@@ -10,7 +10,9 @@ OC.L10N.register(
     "%1$s commented on %2$s" : "%1$s σχολίασε στο %2$s",
     "{author} commented on {file}" : "Ο {author} σχολίασε στο {file}",
     "<strong>Comments</strong> for files" : "<strong>Σχόλια</strong> για αρχεία",
+    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Το όνομά σας αναφέρθηκε στο “{file}”, σε σχόλιο ενός χρήστη ο οποίος έχει πλέον διαγραφεί",
     "{user} mentioned you in a comment on “{file}”" : "Ο {user} σας ανέφερε σε σχόλιο στο “{file}”",
+    "Files app plugin to add comments to files" : "Επέκταση της εφαρμογής αρχείων που επιτρέπει την προσθήκη σχολίων σε αρχεία.",
     "Edit comment" : "Επεξεργασία σχολίου",
     "Delete comment" : "Διαγραφή σχολίου",
     "New comment …" : "Νέο σχόλιο ...",
@@ -26,6 +28,7 @@ OC.L10N.register(
     "Error occurred while posting comment" : "Ένα σφάλμα προέκυψε κατά την δημοσίευση σχολίου",
     "_%n unread comment_::_%n unread comments_" : ["%n αδιάβαστο σχόλιο","%n αδιάβαστα σχόλια"],
     "Comment" : "Σχόλιο",
+    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Το όνομά σας αναφέρθηκε στο \"%s\", σε σχόλιο ενός χρήστη ο οποίος έχει πλέον διαγραφεί",
     "%1$s mentioned you in a comment on “%2$s”" : "%1$s σας ανέφερε σε σχόλιο στο “%2$s”"
 },
 "nplurals=2; plural=(n != 1);");
