@@ -12,6 +12,7 @@ OC.L10N.register(
     "<strong>Comments</strong> for files" : "파일의 <strong>댓글</strong>",
     "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "삭제된 사용자가 남긴 “{file}”의 댓글에서 여러분을 언급함",
     "{user} mentioned you in a comment on “{file}”" : "{user} 님이 “{file}”에 남긴 댓글에서 여러분을 언급함",
+    "Files app plugin to add comments to files" : "파일에 댓글을 남기는 파일 앱 플러그인",
     "Edit comment" : "댓글 편집",
     "Delete comment" : "댓글 삭제",
     "New comment …" : "새로운 댓글 …",
@@ -21,10 +22,12 @@ OC.L10N.register(
     "No comments yet, start the conversation!" : "아직 댓글이 없습니다. 대화를 시작하십시오!",
     "More comments …" : "더 많은 댓글 …",
     "Save" : "저장",
-    "Allowed characters {count} of {max}" : "{count}/{max} 글자 사용 가능",
+    "Allowed characters {count} of {max}" : "{count}/{max}글자 사용 가능",
+    "Error occurred while retrieving comment with ID {id}" : "댓글 ID {id} 가져오기 오류",
     "Error occurred while updating comment with id {id}" : "댓글 ID {id}을(를) 업데이트하는 동안 오류가 발생했습니다 ",
     "Error occurred while posting comment" : "댓글을 게시하는 중 오류가 발생했습니다",
     "_%n unread comment_::_%n unread comments_" : ["읽지 않은 댓글 %n개"],
+    "_1 new comment_::_{unread} new comments_" : ["새 댓글 {unread}개"],
     "Comment" : "설명",
     "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "삭제된 사용자가 남긴 “%s”의 댓글에서 여러분을 언급함",
     "%1$s mentioned you in a comment on “%2$s”" : "%1$s 님이 “%2$s”에 남긴 댓글에서 여러분을 언급함"
