@@ -11,7 +11,7 @@ OC.L10N.register(
     "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
     "You updated calendar {calendar}" : "Du hast den Kalender {calendar} aktualisiert",
     "You shared calendar {calendar} as public link" : "Du hast den Kalender {calendar}  als öffentlichen Link geteilt",
-    "You removed public link for calendar {calendar}" : "Sie haben den öffentlichen Link für Kalender {calendar} entfernt",
+    "You removed public link for calendar {calendar}" : "Du hast den öffentlichen Link für Kalender {calendar} entfernt",
     "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit Dir geteilt",
     "You shared calendar {calendar} with {user}" : "Du hast den Kalender {calendar} mit {user} geteilt",
     "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
@@ -60,6 +60,9 @@ OC.L10N.register(
     "More options …" : "Weitere Optionen...",
     "More options at %s" : "Weitere Optionen unter %s",
     "Contacts" : "Kontakte",
+    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Dein %s muss konfiguriert werden, um HTTPS zusammen mit CalDAV und CardDAV unter iOS/macOS nutzen zu können.",
+    "Configures a CalDAV account" : "Ein CalDAV-Konto einrichten",
+    "Configures a CardDAV account" : "Ein CardDAV-Konto einrichten",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAV-Endpunkt",
     "Technical details" : "Technische Details",
@@ -72,7 +75,9 @@ OC.L10N.register(
     "Save" : "Speichern",
     "Your attendance was updated successfully." : "Dein Anwesenheits-Status wurde aktualisiert.",
     "Calendar server" : "Kalender-Server",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installiere außerdem die {calendarappstoreopen}Kalender-App{linkclose}, oder {calendardocopen}verbinde Deinen Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
     "Send invitations to attendees" : "Einladungen an die Teilnehmer versenden",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stelle sicher, dass Du {emailopen}den E-Mail Server{linkclose} ordnungsgemäß einrichtest.",
     "Automatically generate a birthday calendar" : "Automatisch einen Kalender für Geburtstage erstellen",
     "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einem Hintergrund-Auftrag erstellt",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es ein wenig dauern bis zur Anzeige.",
@@ -80,7 +85,6 @@ OC.L10N.register(
     "The meeting »%s« with %s was canceled." : "Der Termin »%s« mit %s wurde abgesagt.",
     "The meeting »%s« with %s was updated." : "Der Termin  »%s« mit  %s wurde aktualisiert.",
     "%s invited you to »%s«" : "%s hat Dich zu »%s« eingeladen",
-    "CalDAV server" : "CalDAV-Server",
     "Please make sure to properly set up the email settings above." : "Bitte sicherstellen, dass die E-Mail Einstellungen oben korrekt angegeben sind."
 },
 "nplurals=2; plural=(n != 1);");
