@@ -29,6 +29,7 @@ OC.L10N.register(
     "You deleted event {event} from calendar {calendar}" : "Poistit tapahtuman {event} kalenterista {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} päivitti tapahtuman {event} kalenteriin {calendar}",
     "You updated event {event} in calendar {calendar}" : "Päivitit tapahtuman {event} kalenteriin {calendar}",
+    "Busy" : "Varattu",
     "{actor} created todo {todo} in list {calendar}" : "{actor} loi tehtävän {todo} listaan {calendar}",
     "You created todo {todo} in list {calendar}" : "Loit tehtävän {todo} listaan {calendar}",
     "{actor} deleted todo {todo} from list {calendar}" : "{actor} poisti tehtävän {todo} listasta {calendar}",
@@ -54,6 +55,9 @@ OC.L10N.register(
     "Decline" : "Kieltäydy",
     "More options …" : "Lisää valintoja…",
     "Contacts" : "Yhteystiedot",
+    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s tulee asettaa käyttämään HTTPS-yhteyttä, jotta CalDAVia ja CardDAVia voi käyttää iOSilla tai macOS:llä.",
+    "Configures a CalDAV account" : "Määrittää CalDAV-tilin",
+    "Configures a CardDAV account" : "Määrittää CardDAV-tilin",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAV-päätepiste",
     "Technical details" : "Tekniset yksityiskohdat",
@@ -62,17 +66,19 @@ OC.L10N.register(
     "There was an error updating your attendance status." : "Osallistumisesi tilaa päivittäessä tapahtui virhe.",
     "Please contact the organizer directly." : "Ota yhteys suoraan järjestäjään.",
     "Are you accepting the invitation?" : "Hyväksytkö kutsun?",
+    "Tentative" : "Alustava",
     "Save" : "Tallenna",
     "Your attendance was updated successfully." : "Osallistumisesi päivitettiin onnistuneesti.",
     "Calendar server" : "Kalenteripalvelin",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Asenna myös {calendarappstoreopen}kalenterisovellus{linkclose}, tai {calendardocopen}yhdistä tietokoneesi ja mobiililaitteesi synkronointiyhteyteen ↗{linkclose}.",
     "Send invitations to attendees" : "Lähetä kutsut osallistujille",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Varmista että määrität {emailopen}sähköpostipalvelimen{linkclose} asetukset oikein.",
     "Automatically generate a birthday calendar" : "Luo syntymäpäiväkalenteri automaattisesti",
     "Birthday calendars will be generated by a background job." : "Syntymäpäiväkalenterit luodaan taustatyön toimesta.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Sen vuoksi ne eivät ole välittömästi saatavilla käyttöönoton jälkeen, vaan ne tulevat näkyviin pienellä viiveellä.",
     "The meeting »%s« with %s was canceled." : "Tapaaminen »%s« henkilön %s kanssa peruttiin.",
     "The meeting »%s« with %s was updated." : "Tapaaminen »%s« henkilön %s kanssa päivitettiin.",
     "%s invited you to »%s«" : "%s kutsui sinut »%s«",
-    "CalDAV server" : "CalDAV-palvelin",
     "Please make sure to properly set up the email settings above." : "Varmista, että määrität sähköpostiasetukset oikein yläpuolelle. "
 },
 "nplurals=2; plural=(n != 1);");
