@@ -29,6 +29,7 @@ OC.L10N.register(
     "You deleted event {event} from calendar {calendar}" : "행사 {event}을(를) 달력 {calendar}에서 삭제함",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} 님이 달력 {calendar}의 행사 {event}을(를) 업데이트함",
     "You updated event {event} in calendar {calendar}" : "달력 {calendar}의 행사 {event}을(를) 업데이트함",
+    "Busy" : "바쁨",
     "{actor} created todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}에 할 일 {todo}을(를) 생성함",
     "You created todo {todo} in list {calendar}" : "목록 {calendar}에 할 일 {todo}을(를) 생성함",
     "{actor} deleted todo {todo} from list {calendar}" : "{actor} 님이 목록 {calendar}에서 할 일 {todo}을(를) 삭제함",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "달력 <strong>행사</strong>가 수정됨",
     "A calendar <strong>todo</strong> was modified" : "달력의 <strong>할 일</strong>이 수정됨",
     "Contact birthdays" : "연락처에 등록된 생일",
+    "%1$s via %2$s" : "%1$s(%2$s 경유)",
     "Invitation canceled" : "초대장 취소됨",
     "Hello %s," : "%s 님 안녕하세요,",
     "The meeting »%1$s« with %2$s was canceled." : "\"%1$s\" 행사(%2$s 님이 진행함)가 취소되었습니다.",
@@ -54,14 +56,28 @@ OC.L10N.register(
     "Description:" : "설명:",
     "Link:" : "링크:",
     "Accept" : "수락",
+    "Decline" : "거절",
+    "More options …" : "더 많은 옵션 …",
+    "More options at %s" : "%s에 더 많은 옵션 있음",
     "Contacts" : "연락처",
+    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS에서 CalDAV 및 CardDAV를 사용하려면 %s에서 HTTPS를 사용하도록 설정해야 합니다.",
+    "Configures a CalDAV account" : "CalDAV 계정 설정",
+    "Configures a CardDAV account" : "CardDAV 계정 설정",
+    "WebDAV" : "WebDAV",
+    "WebDAV endpoint" : "WebDAV 종단점",
     "Technical details" : "기술 정보",
     "Remote Address: %s" : "원격 주소: %s",
     "Request ID: %s" : "요청 ID: %s",
+    "There was an error updating your attendance status." : "참석 상태를 업데이트하는 중 오류가 발생했습니다.",
+    "Please contact the organizer directly." : "주최자에게 직접 연락하십시오.",
     "Are you accepting the invitation?" : "초대를 수락하시겠습니까?",
     "Tentative" : "예정됨",
     "Save" : "저장",
+    "Your attendance was updated successfully." : "참석 정보를 업데이트했습니다.",
+    "Calendar server" : "달력 서버",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "{calendarappstoreopen}달력 앱{linkclose}을 설치하거나 {calendardocopen}동기화할 데스크톱과 모바일 장치를 연결 ↗{linkclose}하십시오.",
     "Send invitations to attendees" : "참석자에게 초대장 보내기",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "{emailopen}이메일 서버{linkclose}가 올바르게 설치되어 있는지 확인하십시오..",
     "Automatically generate a birthday calendar" : "자동으로 생일 달력 생성",
     "Birthday calendars will be generated by a background job." : "배경 작업으로 생일 달력을 생성합니다.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "생일 달력이 생성되는 데 시간이 걸릴 수도 있습니다.",
