@@ -135,9 +135,8 @@ OC.L10N.register(
     "Unlimited" : "Senlima",
     "Upload (max. %s)" : "Alŝuti (maks. %s)",
     "File Management" : "Dosieradministrado",
-    "%s of %s used" : "%s uzataj el %s",
-    "%1$s%% of %2$s used" : "%1$s%% el %2$s uzataj",
     "%s used" : "%s uzataj",
+    "%1$s of %2$s used" : "%1$s uzataj el %2$s",
     "Settings" : "Agordo",
     "Show hidden files" : "Montri kaŝitajn dosierojn",
     "WebDAV" : "WebDAV",
@@ -167,7 +166,8 @@ OC.L10N.register(
     "Save" : "Konservi",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Per PHP-FPM, ŝanĝoj povas postuli 5 minutojn por aplikiĝi.",
     "Missing permissions to edit from here." : "Mankas permesoj por redakti ekde ĉi tie.",
+    "%s of %s used" : "%s uzataj el %s",
     "Cancel upload" : "Nuligi alŝuton",
-    "%1$s of %2$s used" : "%1$s uzataj el %2$s"
+    "%1$s%% of %2$s used" : "%1$s%% el %2$s uzataj"
 },
 "nplurals=2; plural=(n != 1);");
