@@ -8,19 +8,27 @@ OC.L10N.register(
     "Recent" : "Nesenās",
     "Favorites" : "Iecienītie",
     "File could not be found" : "Datni nevar atrast",
+    "Move or copy" : "Pārvietot vai kopēt",
     "Download" : "Lejupielādēt",
     "Delete" : "Dzēst",
     "Home" : "Mājas",
     "Close" : "Aizvērt",
     "Could not create folder \"{dir}\"" : "Nevarēja izveidot mapi \"{dir}\"",
+    "This will stop your current uploads." : "Tādējādi tiks pārtraukta jūsu pašreizējā augšupielāde.",
     "Upload cancelled." : "Augšupielāde ir atcelta.",
+    "Processing files …" : "Notiek failu apstrāde …",
+    "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturoša datne.",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
     "Target folder \"{dir}\" does not exist any more" : "Mape \"{dir}\" vairs neeksistē",
     "Not enough free space" : "Nav pietiekami daudz brīvas vietas",
+    "An unknown error has occurred" : "Radusies nezināma kļūda",
+    "Uploading …" : "Augšupielādē…",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} no {totalSize} ({bitrate})",
     "Actions" : "Darbības",
     "Rename" : "Pārsaukt",
+    "Copy" : "Kopēt",
+    "Open" : "Atvērt",
     "Disconnect storage" : "Atvienot glabātuvi",
     "Unshare" : "Pārtraukt koplietošanu",
     "Could not load info for file \"{file}\"" : "Nevar ielādēt informāciju par datni \"{file}\"",
@@ -33,6 +41,7 @@ OC.L10N.register(
     "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
     "Could not move \"{file}\", target exists" : "Nevarēja pārvietot \"{file}\", mērķis eksistē",
     "Could not move \"{file}\"" : "Nevarēja pārvietot \"{file}\"",
+    "copy" : "kopēt",
     "{newName} already exists" : "{newName} jau eksistē",
     "Could not rename \"{fileName}\", it does not exist any more" : "Nevarēja pārsaukt \"{fileName}\", tā vairs neeksistē",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nosaukums \"{targetName}\" jau tiek izmantots mapē \"{dir}\". Lūdzu izvēlies citu nosaukumu.",
@@ -59,11 +68,15 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
     "_matches '{filter}'_::_match '{filter}'_" : ["atrasts pēc '{filter}'","atrasts pēc '{filter}'","atrasti pēc '{filter}'"],
     "View in folder" : "Skatīt mapē",
+    "Copied!" : "Nokopēts!",
     "Path" : "Ceļš",
     "_%n byte_::_%n bytes_" : ["%n baiti","%n baits","%n baiti"],
     "Favorited" : "Favorīti",
     "Favorite" : "Iecienītais",
     "New folder" : "Jauna mape",
+    "Upload file" : "Augšupielādēt datni",
+    "Remove from favorites" : "Noņemt no favorītiem",
+    "Add to favorites" : "Pievienot izlasei",
     "An error occurred while trying to update the tags" : "Notika kļūda atjaunojot atzīmi",
     "Added to favorites" : "Pievienot favorītiem",
     "Removed from favorites" : "Noņemt no favorītiem",
@@ -94,6 +107,7 @@ OC.L10N.register(
     "A new file or folder has been <strong>created</strong>" : "<strong>Izveidota</strong> jauna datne vai mape",
     "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitēt ziņojumus par jūsu <strong>iecienīto datņu</strong> izveidošanu un izmaiņām <em>(tikai datu straumei)</em>",
     "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
+    "%s used" : "%s izmantoti",
     "Settings" : "Iestatījumi",
     "Show hidden files" : "Rādīt slēptās datnes",
     "WebDAV" : "WebDAV",
@@ -117,6 +131,7 @@ OC.L10N.register(
     "max. possible: " : "maksimālais iespējamais:",
     "Save" : "Saglabāt",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "Ar PHP-FPM var aizņemt 5 minūtes, kamēr izmaiņas stāsies spēkā.",
-    "Missing permissions to edit from here." : "Nepietiekamas tiesības lai rediģētu no šejienes."
+    "Missing permissions to edit from here." : "Nepietiekamas tiesības lai rediģētu no šejienes.",
+    "Cancel upload" : "Atcelt augšupielādi"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
