@@ -103,17 +103,10 @@ OC.L10N.register(
     "A file or folder has been <strong>restored</strong>" : "Një skedar ose dosje është <strong> rikthyer </strong>",
     "Unlimited" : "E palimituar",
     "Upload (max. %s)" : "Ngarkim (max. %s)",
-    "File handling" : "Trajtim kartele",
-    "Maximum upload size" : "Madhësi maksimale ngarkimi",
-    "max. possible: " : "maks. i mundshëm: ",
-    "Save" : "Ruaje",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Me PHP-FPM mund të duhen 5 minuta që ndryshimet të hyjnë në fuqi.",
-    "Missing permissions to edit from here." : "Mungojnë lejet për përpunim që nga këtu.",
     "%s used" : "%s të përdorura",
     "Settings" : "Rregullime",
     "Show hidden files" : "Shfaq kartela të fshehura",
     "WebDAV" : "WebDAV",
-    "Cancel upload" : "Anulo ngarkimin",
     "No files in here" : "S’ka kartela këtu",
     "Upload some content or sync with your devices!" : "Ngarkoni ca lëndë ose bëni njëkohësim me pajisjet tuaja!",
     "No entries found in this folder" : "Në këtë dosje s’u gjetën zëra",
@@ -132,6 +125,13 @@ OC.L10N.register(
     "Text file" : "Kartelë tekst",
     "New text file.txt" : "Kartelë e re file.txt",
     "Target folder" : "Dosja e synuar",
-    "%s of %s used" : "%s nga %s është përdorur"
+    "File handling" : "Trajtim kartele",
+    "Maximum upload size" : "Madhësi maksimale ngarkimi",
+    "max. possible: " : "maks. i mundshëm: ",
+    "Save" : "Ruaje",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Me PHP-FPM mund të duhen 5 minuta që ndryshimet të hyjnë në fuqi.",
+    "Missing permissions to edit from here." : "Mungojnë lejet për përpunim që nga këtu.",
+    "%s of %s used" : "%s nga %s është përdorur",
+    "Cancel upload" : "Anulo ngarkimin"
 },
 "nplurals=2; plural=(n != 1);");
