@@ -27,10 +27,12 @@ OC.L10N.register(
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} з {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "Завантаження цього елемента не підтримується",
     "Target folder does not exist any more" : "Цільовий каталог більше не існує",
+    "Error when assembling chunks, status code {status}" : "Помилка під час збірки частин, код помилки {status}",
     "Actions" : "Дії",
     "Rename" : "Перейменувати",
     "Copy" : "Скопіювати",
     "Choose target folder" : "Виберіть цільовий каталог",
+    "Open" : "Відкрити",
     "Disconnect storage" : "Від’єднати сховище",
     "Unshare" : "Закрити доступ",
     "Could not load info for file \"{file}\"" : "Не вдалося завантажити інформацію для файлу \"{file}\"",
@@ -67,6 +69,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "У вас недостатньо прав для вивантаження або створення тут файлів",
     "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів","Вивантаження %n файлів"],
     "New" : "Створити",
+    "Select file range" : "Виберіть набір файлів",
     "{used} of {quota} used" : "використано {used} з {quota}",
     "{used} used" : "використано {used}",
     "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
@@ -85,6 +88,7 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n байт","%n байти","%n байт","%n байт"],
     "Favorited" : "Улюблений",
     "Favorite" : "В улюблене",
+    "You can only favorite a single file or folder at a time" : "Одночасно вподобати можна лише один файл чи каталог",
     "New folder" : "Нова тека",
     "Upload file" : "Вивантажити файл",
     "Not favorited" : "Не улюблене",
@@ -106,11 +110,16 @@ OC.L10N.register(
     "You created {file}" : "Ви створили {file}",
     "You created an encrypted file in {file}" : "Ви створили зашифрований файл у {file}",
     "{user} created {file}" : "Користувач {user} створив {file}",
+    "{user} created an encrypted file in {file}" : "{user} створив зашифрований файл у {file}",
     "{file} was created in a public folder" : "Файл {file} створено у спільній теці",
     "You changed {file}" : "Ви змінили {file}",
+    "You changed an encrypted file in {file}" : "Ви змінили зашифрований файл у {file}",
     "{user} changed {file}" : "Користувач {user} змінив {file}",
+    "{user} changed an encrypted file in {file}" : "{user} змінив зашифрований файл у {file}",
     "You deleted {file}" : "Ви видалили {file}",
+    "You deleted an encrypted file in {file}" : "Ви вилучити зашифрований файл у {file}",
     "{user} deleted {file}" : "Користувач {user} видалив {file}",
+    "{user} deleted an encrypted file in {file}" : "{user} вилучив зашифрований файл у {file}",
     "You restored {file}" : "Ви відновили {file}",
     "{user} restored {file}" : "Користувач {user} відновив {file}",
     "You renamed {oldfile} to {newfile}" : "Ви перейменували {oldfile} в {newfile}",
@@ -126,12 +135,13 @@ OC.L10N.register(
     "Unlimited" : "Необмежено",
     "Upload (max. %s)" : "Вивантаження (макс. %s)",
     "File Management" : "Управління файлами",
-    "%s of %s used" : "%s з %s використано",
     "%s used" : "%s використано",
+    "%1$s of %2$s used" : "використано %1$s з %2$s",
     "Settings" : "Налаштування",
     "Show hidden files" : "Показати приховані файли",
     "WebDAV" : "WebDAV",
     "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Використовуйте цю адресу для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">доступ до своїх файлів через WebDAV</a>",
+    "Toggle grid view" : "Показати плитками",
     "No files in here" : "Тут немає файлів",
     "Upload some content or sync with your devices!" : "Вивантажте щось або синхронізуйте з пристроями!",
     "No entries found in this folder" : "В цій теці нічого немає",
@@ -142,9 +152,11 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Файли і теки, які ви позначили як улюблені, з’являться тут",
     "Tags" : "Теги",
     "Deleted files" : "Видалені файли",
+    "Shares" : "Спільний доступ",
     "Shared with others" : "Поділились з іншими",
     "Shared with you" : "Поділились з вами",
     "Shared by link" : "Доступне за посиланням",
+    "Deleted shares" : "Вилучено зі спільного доступу",
     "Text file" : "Текстовий файл",
     "New text file.txt" : "Новий текстовий файл file.txt",
     "Target folder" : "Тека призначення",
@@ -154,6 +166,8 @@ OC.L10N.register(
     "Save" : "Зберегти",
     "With PHP-FPM it might take 5 minutes for changes to be applied." : "З PHP-FPM прийняття змін може тривати до 5 хвилин.",
     "Missing permissions to edit from here." : "Недостатньо прав для редагування звідси.",
-    "%1$s of %2$s used" : "використано %1$s з %2$s"
+    "%s of %s used" : "%s з %s використано",
+    "Cancel upload" : "Скасувати завантаження",
+    "%1$s%% of %2$s used" : "використано %1$s%% з %2$s"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
