@@ -16,8 +16,8 @@ OC.L10N.register(
     "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
     "This will stop your current uploads." : "這會終止目前任何的上傳。",
     "Upload cancelled." : "上傳已取消",
-    "…" : "...",
     "Processing files …" : "正在處理檔案…",
+    "…" : "...",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
     "Target folder \"{dir}\" does not exist any more" : "資料夾 \"{dir}\" 不存在",
@@ -32,6 +32,7 @@ OC.L10N.register(
     "Rename" : "重新命名",
     "Copy" : "複製",
     "Choose target folder" : "選擇目標資料夾",
+    "Open" : "開啟",
     "Disconnect storage" : "切斷儲存空間連接",
     "Unshare" : "取消分享",
     "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
@@ -134,20 +135,13 @@ OC.L10N.register(
     "Unlimited" : "無限制",
     "Upload (max. %s)" : "上傳（至多 %s）",
     "File Management" : "檔案管理",
-    "File handling" : "檔案處理",
-    "Maximum upload size" : "上傳限制",
-    "max. possible: " : "最大允許：",
-    "Save" : "儲存",
-    "With PHP-FPM it might take 5 minutes for changes to be applied." : "如果使用 PHP-FPM ，此設定值需要5分鐘左右才會生效。",
-    "Missing permissions to edit from here." : "您沒有在此編輯的權限",
-    "%s of %s used" : "在 %s 中使用了%s ",
     "%s used" : "%s已使用",
+    "%1$s of %2$s used" : "在  %2$s中使用了%1$s ",
     "Settings" : "設定",
     "Show hidden files" : "顯示隱藏檔",
     "WebDAV" : "WebDAV",
     "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "使用這個位址來<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">使用 WebDAV 存取檔案</a>",
     "Toggle grid view" : "切換網格檢視",
-    "Cancel upload" : "取消上傳",
     "No files in here" : "沒有任何檔案",
     "Upload some content or sync with your devices!" : "在您的裝置中同步或上傳一些內容",
     "No entries found in this folder" : "在此資料夾中沒有任何項目",
@@ -165,6 +159,15 @@ OC.L10N.register(
     "Deleted shares" : "已刪除的分享",
     "Text file" : "文字檔",
     "New text file.txt" : "新文字檔.txt",
-    "Target folder" : "目標資料夾"
+    "Target folder" : "目標資料夾",
+    "File handling" : "檔案處理",
+    "Maximum upload size" : "上傳限制",
+    "max. possible: " : "最大允許：",
+    "Save" : "儲存",
+    "With PHP-FPM it might take 5 minutes for changes to be applied." : "如果使用 PHP-FPM ，此設定值需要5分鐘左右才會生效。",
+    "Missing permissions to edit from here." : "您沒有在此編輯的權限",
+    "%s of %s used" : "在 %s 中使用了%s ",
+    "Cancel upload" : "取消上傳",
+    "%1$s%% of %2$s used" : "在%2$s使用了%1$s%%"
 },
 "nplurals=1; plural=0;");
