@@ -74,7 +74,7 @@ class FileChanges implements IFilter {
 	 * @since 11.0.0
 	 */
 	public function getIcon() {
-		return $this->url->getAbsoluteURL($this->url->imagePath('core', 'places/files-dark.svg'));
+		return $this->url->getAbsoluteURL($this->url->imagePath('core', 'places/files.svg'));
 	}
 
 	/**
