@@ -30,7 +30,6 @@ OC.L10N.register(
     "There was an error with message: " : "Terjadi kesalahan dengan pesan:",
     "External mount error" : "Kesalahan mount eksternal",
     "external-storage" : "penyimpanan-eksternal",
-    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Beberapa mount point eksternal tidak terhubung. Klik barisan merah untuk informasi selanjutnya",
     "Please enter the credentials for the {mount} mount" : "Masukkan kredensial untuk mount {mount}",
     "Username" : "Nama Pengguna",
     "Password" : "Kata sandi",
@@ -109,8 +108,7 @@ OC.L10N.register(
     "Add storage" : "Tambahkan penyimpanan",
     "Advanced settings" : "Pengaturan Lanjutan",
     "Allow users to mount external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal",
-    "OpenStack" : "OpenStack",
-    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" tidak terpasang. Mengaitkan %s tidak memungkinkan. Harap tanya administrator sistem anda untuk memasangnya.",
-    "Allow users to mount the following external storage" : "Izinkan pengguna untuk mengaitkan penyimpanan eksternal berikut"
+    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Beberapa mount point eksternal tidak terhubung. Klik barisan merah untuk informasi selanjutnya",
+    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" tidak terpasang. Mengaitkan %s tidak memungkinkan. Harap tanya administrator sistem anda untuk memasangnya."
 },
 "nplurals=1; plural=0;");
