@@ -19,9 +19,11 @@ OC.L10N.register(
     "Check for changes" : "Patikrinti ar nėra pakeitimų",
     "Never" : "Niekada",
     "Once every direct access" : "Kartą per tiesioginę peržiūrą",
+    "Read only" : "Tik skaitymui",
     "Delete" : "Ištrinti",
     "Admin defined" : "Administratorius apibrėžtas",
     "Are you sure you want to delete this external storage?" : "Ar tikrai norite ištrinti šią išorinę saugyklą?",
+    "Delete storage?" : "Ištrinti saugyklą?",
     "Saved" : "Įrašyta",
     "Saving..." : "Įrašoma...",
     "Save" : "Įrašyti",
@@ -31,7 +33,7 @@ OC.L10N.register(
     "Couldn't get the list of external mount points: {type}" : "Nepavyko gauti išorinių prijungimo taškų sąrašo: {type}",
     "There was an error with message: " : "Klaidos žinutė:",
     "External mount error" : "Išorinio prijungimo klaida",
-    "external-storage" : "išorinė saugykla",
+    "external-storage" : "išorinė-saugykla",
     "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Neįmanoma gauti duomenų sąrašo ir Windows tinkle prijungto disko. Nėra jokio atsakymo.",
     "Please enter the credentials for the {mount} mount" : "Prašome įvesti prisijungimo duomenis skirtus saugyklos {mount} prijungimui",
     "Username" : "Naudotojo vardas",
@@ -52,8 +54,8 @@ OC.L10N.register(
     "%s" : "%s",
     "Storage with ID \"%d\" is not user editable" : "Naudotojai negali redaguoti saugyklos identifikuotos kaip \"%d\"",
     "Access key" : "Prieigos raktas",
-    "Secret key" : "Slaptažodis",
-    "Builtin" : "Įmontuotas",
+    "Secret key" : "Slaptasis raktas",
+    "Builtin" : "Įtaisytasis",
     "None" : "Nėra",
     "OAuth1" : "OAuth1",
     "App key" : "Trečiųjų šalių programinės įrangos identifikacijos raktas",
@@ -99,6 +101,7 @@ OC.L10N.register(
     "SFTP with secret key login" : "SFTP protokolas su prisijungimu",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "Dalintis",
+    "Show hidden files" : "Rodyti paslėptus failus",
     "SMB / CIFS using OC login" : "SMB / CIFS, naudojant OC prisijungimą",
     "Username as share" : "Dalinimosi vardas kaip ir vartotojo vardas",
     "OpenStack Object Storage" : "Objektų saugykla \"OpenStack\"",
@@ -106,6 +109,7 @@ OC.L10N.register(
     "Request timeout (seconds)" : "Prisijungimo laikas (sekundėmis)",
     "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP palaikymas yra neįjungtas arba neįdiegtas į PHP. %s prijungimas neįmanomas. Paprašykite sistemos administratoriaus pagalbos.",
+    "No external storage configured or you don't have the permission to configure them" : "Nėra sukonfigūruota jokia išorinė saugykla arba jūs neturite leidimo jų konfigūruoti",
     "Name" : "Pavadinimas",
     "Storage type" : "Saugyklos tipas",
     "Scope" : "Leidimas",
