@@ -27,7 +27,8 @@ OC.L10N.register(
     "Share not found" : "未找到共享",
     "You are not authorized to open this share" : "您没有权限访问这个共享",
     "Invalid range request" : "无效的范围强求",
-    "Text editor" : "文本编辑",
-    "This application enables Nextcloud users to open, save and edit text files in the web browser. If enabled, an entry called \"Text file\" in the \"New\" button menu at the top of the web browser appears. When clicked, a new text file opens in the browser and the file can be saved into the current Nextcloud directory. Further, when a text file is clicked in the web browser, it will be opened and editable. If the privileges allow, a user can also edit shared files and save these changes back into the web browser.\nMore information is available in the text editor documentation." : "此应用使Nextcloud用户能在浏览器中打开、保存和编辑文本文件。此应用一旦启用，浏览器顶部的\"新建\"按钮目录中将出现\"文本文件\"的条目。点击这一条目，将在浏览器中打开一个新的文本文件，此文件可保存到当前Nextcloud文件夹中。而且，在浏览器中点击一个文本文件时，文件将被打开并处于可编辑状态。当权限允许时，用户可编辑共享的文本文件并在浏览器中保存变更。\n更多信息请参考文本编辑器文档。"
+    "Plain text editor" : "纯文本编辑器",
+    "This application enables Nextcloud users to open, save and edit text files in the web browser. If enabled, an entry called \"Text file\" in the \"New\" button menu at the top of the web browser appears. When clicked, a new text file opens in the browser and the file can be saved into the current Nextcloud directory. Further, when a text file is clicked in the web browser, it will be opened and editable. If the privileges allow, a user can also edit shared files and save these changes back into the web browser.\nMore information is available in the text editor documentation." : "此应用使Nextcloud用户能在浏览器中打开、保存和编辑文本文件。此应用一旦启用，浏览器顶部的\"新建\"按钮目录中将出现\"文本文件\"的条目。点击这一条目，将在浏览器中打开一个新的文本文件，此文件可保存到当前Nextcloud文件夹中。而且，在浏览器中点击一个文本文件时，文件将被打开并处于可编辑状态。当权限允许时，用户可编辑共享的文本文件并在浏览器中保存变更。\n更多信息请参考文本编辑器文档。",
+    "Text editor" : "文本编辑"
 },
 "nplurals=1; plural=0;");
