@@ -1,6 +1,11 @@
 OC.L10N.register(
     "firstrunwizard",
     {
+    "Copy to clipboard" : "クリップボードにコピー",
+    "Copied!" : "コピーしました！",
+    "Not supported!" : "サポートされていません！",
+    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
+    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
     "First run wizard" : "初期ウィザード",
     "Add your profile information! For example your email is needed to reset your password." : "プロフィール情報を追加しましょう! パスワードをリセットするにはメールアドレスが必要です。",
     "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "プロフィール情報を追加してください! プロフィール画像とフルネームを設定すると、すべての機能をより簡単に認識できます。",
@@ -15,6 +20,7 @@ OC.L10N.register(
     "Communication with Nextcloud Talk" : "Nextcloud Talk によるコミュニケーション",
     "Collaboration apps for document editing" : "ドキュメント編集用のコラボレーションアプリケーション",
     "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "二要素認証、SSOおよびランサムウェア保護などのセキュリティおよび認証機能",
+    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "音楽プレイヤー、パスワード管理、かんばんアプリ、ダウンロードマネージャー、markdownエディターなど、他にもたくさん",
     "Browse the app store" : "アプリストアをブラウザでみる",
     "Stay in sync" : "同期して",
     "Nextcloud gives you access to your files wherever you are." : "Nextcloud を使用すると、どこにいてもファイルにアクセスできます。",
@@ -27,6 +33,7 @@ OC.L10N.register(
     "Connect your calendar" : "カレンダーに接続",
     "Connect your contacts" : "連絡先に接続",
     "Access files via WebDAV" : "WebDAV 経由でファイルにアクセス",
+    "Download macOS/iOS configuration profile" : "macOS/iOS 設定プロファイルをダウンロード",
     "Get help" : "ヘルプの入手",
     "Get more information" : "詳細情報の取得",
     "The Nextcloud documentation for home users:" : "ホームユーザーのための Nextcloud のドキュメント：",
@@ -40,17 +47,20 @@ OC.L10N.register(
     "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "あなたは Nextcloud で一定の改善をしたいですか？ 問題が見つかりましたか？ Nextcloud の翻訳、宣伝、または文書化を手伝いたいですか？",
     "Become part of the Community" : "コミュニティの一員になる",
     "Enterprise support" : "エンタープライズサポート",
+    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Nextcloud を大勢のユーザーと大量のデータを扱うミッションクリティカルな環境で運用し、Nextcloud 技術の裏側にいるエキスパートによる確実なサポートが必要であれば、Nextcloud からのエンタープライズサブスクリプションが電子メールと電話サポートで利用できます。",
     "Get enterprise support" : "エンタープライズサポートを受ける",
     "A safe home for all your data" : "すべてのデータの安全な保管場所",
     "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud は、あなたのコントロール下であなたの指先にデータを置きます。 あなたの会社、自宅、私たちのプロバイダの一人、またはあなたが知っているデータセンターのサーバーに文書、カレンダー、連絡先、写真を保管してください。",
     "Host your data and files where you decide" : "決定した場所でデータとファイルをホストする",
     "Open Standards and Interoperability" : "オープンスタンダードと相互運用性",
-    "100%% Open Source & community-focused" : "コミュニティ主体の100% %% オープンソース",
+    "100%% Open Source & community-focused" : "コミュニティ主体の100 %% オープンソース",
     "Learn more about %s" : "%sの詳細",
     "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s はあなたがどこにいても、あなたのファイルへのアクセスを提供します。私たちの使いやすいデスクトップとモバイルクライアントは、ゼロコストですべての主要なプラットフォームで利用可能です。",
     "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "<a href=\"%s\">アプリのパスワード</a>を使用して同期クライアントのセットアップを行ってください。あなたがデバイスを失くした場合に、このようにしてアクセスを取り消せることを確認できます。",
     "Connect other apps to %s" : "他のアプリを %s に接続する",
     "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "同期クライアントのほかに、WebDAV/CalDAV/CardDAV プロトコルをサポートする他のソフトウェアを %s に接続できます。",
+    "Server address" : "サーバーアドレス",
+    "Use this URL to connect your clients to this server:" : "このサーバーにクライアントを接続するにはこのURLを使用してください:",
     "Previous" : "前へ",
     "Next" : "次へ"
 },
