@@ -20,7 +20,7 @@ OC.L10N.register(
     "Groupware apps like Calendar, Contacts, Mail" : "群组应用如日历，联系人，邮件",
     "Communication with Nextcloud Talk" : "使用Nextcloud通话应用沟通",
     "Collaboration apps for document editing" : "用于文档编辑的协作应用",
-    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "安全与认证特性如双因素认证，单点登录和勒索病毒保护",
+    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "安全与认证特性如两步验证，单点登录和勒索病毒保护",
     "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "还有很多应用如音乐播放器，密码管理器，看板app，下载管理器和markdown编辑器",
     "Browse the app store" : "浏览应用商店",
     "Stay in sync" : "保持同步",
