@@ -170,7 +170,7 @@
 			 * At this stage, there is no loading taking place, so we can look for new rows
 			 */
 
-			var scroll = $('#content-wrapper').scrollTop() + $(window).scrollTop();
+			var scroll = $(window).scrollTop() + $(window).scrollTop();
 			// 2 windows worth of rows is the limit from which we need to start loading new rows.
 			// As we scroll down, it grows
 			var targetHeight = ($(window).height() * 2) + scroll;
@@ -311,9 +311,15 @@
 			if (!$uploadEl.exists()) {
 				return;
 			}
+
+			this._operationProgressBar = new OCA.Files.OperationProgressBar();
+			this._operationProgressBar.render();
+			$('#content').find('#uploadprogresswrapper').replaceWith(this._operationProgressBar.$el);
+
 			this._uploader = new OC.Uploader($uploadEl, {
 				fileList: FileList,
-				dropZone: $('#content')
+				dropZone: $('#content'),
+				progressBar: this._operationProgressBar
 			});
 			this._uploader.on('add', function (e, data) {
 				data.targetDir = '/' + Gallery.currentAlbum;
@@ -375,7 +381,6 @@
 			$('#album-info-button').click(Gallery.showInfo);
 			$('#sort-name-button').click(Gallery.sorter);
 			$('#sort-date-button').click(Gallery.sorter);
-			$('#save #save-button').click(Gallery.showSaveForm);
 			$('.save-form').submit(Gallery.saveForm);
 			this._renderNewButton();
 			// Trigger cancelling of file upload
@@ -491,7 +496,7 @@
 		 * @private
 		 */
 		_setBackgroundColour: function () {
-			var wrapper = $('#content-wrapper');
+			var wrapper = $('#app-content');
 			var albumDesign = Gallery.config.albumDesign;
 			if (!$.isEmptyObject(albumDesign) && albumDesign.background) {
 				wrapper.css('background-color', albumDesign.background);
@@ -511,7 +516,7 @@
 		_setSortButton: function (sortType, sortOrder, active) {
 			var button = $('#sort-' + sortType + '-button');
 			// Removing all the classes which control the image in the button
-			button.removeClass('active-button');
+			button.removeClass('active');
 			button.find('img').removeClass('front');
 			button.find('img').removeClass('back');
 
@@ -527,7 +532,7 @@
 
 			// The active button needs a hover action for the flip effect
 			if (active) {
-				button.addClass('active-button');
+				button.addClass('active');
 				if (button.is(":hover")) {
 					button.removeClass('hover');
 				}
@@ -567,13 +572,8 @@
 			if (!$actionsContainer.length) {
 				return;
 			}
-			if (!this._addButtonTemplate) {
-				this._addButtonTemplate = Handlebars.compile(TEMPLATE_ADDBUTTON);
-			}
-			var $newButton = $(this._addButtonTemplate({
-				addText: t('gallery', 'New'),
-				iconUrl: OC.imagePath('core', 'actions/add')
-			}));
+
+			var $newButton = $(TEMPLATE_ADDBUTTON);
 
 			$actionsContainer.prepend($newButton);
 			$newButton.tooltip({'placement': 'bottom'});
