@@ -2,7 +2,6 @@ OC.L10N.register(
     "gallery",
     {
     "Configuration error" : "Konfiguratiouns Feeler",
-    "New" : "Nei",
     "Error loading slideshow template" : "Feeler beim Luede vun der Virlag fir d'Diashow",
     "Next" : "Weider",
     "Play" : "Ofspillen",
@@ -35,7 +34,6 @@ OC.L10N.register(
     "Set expiration date" : "Verfallsdatum setzen",
     "Expiration" : "Leeft of",
     "Expiration date" : "Verfallsdatum",
-    "An error occured. Please try again" : "Et ass e Fehler opgetrueden. W.e.g. probéier nach emol",
     "Adding user..." : "Benotzer derbäi fügen",
     "group" : "Grupp",
     "remote" : "Op Distanz",
@@ -51,10 +49,10 @@ OC.L10N.register(
     "Password protected" : "Passwuertgeschützt",
     "Error unsetting expiration date" : "Feeler beim Läsche vum Verfallsdatum",
     "Error setting expiration date" : "Feeler beim Setze vum Verfallsdatum",
-    "Sending ..." : "Gëtt geschéckt...",
     "Email sent" : "Email geschéckt",
     "Warning" : "Warnung",
     "The password is wrong. Try again." : "Den Passwuert ass incorrect. Probeier ed nach eng keier.",
-    "Cancel upload" : "Eroplueden ofbriechen"
+    "Cancel upload" : "Eroplueden ofbriechen",
+    "New" : "Nei"
 },
 "nplurals=2; plural=(n != 1);");
