@@ -57,10 +57,12 @@ OC.L10N.register(
     "Set expiration date" : "Iestaties termiņa datumu",
     "Expiration" : "Termiņš",
     "Expiration date" : "Termiņa datums",
+    "An error occurred. Please try again" : "Notika kļūda. Mēģini vēlreiz.",
     "Adding user..." : "Lietotāja pievienošana...",
     "group" : "grupa",
     "remote" : "attālināti",
     "Resharing is not allowed" : "Atkārtota dalīšanās nav atļauta",
+    "Error while retrieving shares" : "Kļūda, izgūstot koplietošanu",
     "Unshare" : "Pārtraukt dalīšanos",
     "notify by email" : "ziņot e-pastā",
     "can share" : "Var dalīties",
@@ -76,12 +78,14 @@ OC.L10N.register(
     "Email sent" : "Vēstule nosūtīta",
     "Warning" : "Brīdinājums",
     "shared by %s" : "Koplietoja %s",
+    "Direct link" : "Tiešā saite",
     "Add to your Nextcloud" : "Pievienot savam Nextcloud",
+    "Media gallery for Nextcloud" : "Nextcloud multivides galerija",
     "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
     "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
+    "Cancel upload" : "Atcelt augšupielādi",
     "Sort by name" : "Kārtot pēc nosaukuma",
     "Sort by date" : "Kārtot pēc datuma",
-    "Cancel upload" : "Atcelt augšupielādi",
     "Album information" : "Albūma informācija",
     "File list" : "Failu saraksts",
     "Sorry, this file could not be found." : "Atvainojiet, šo failu nevar atrast.",
