@@ -3,19 +3,19 @@ OC.L10N.register(
     {
     "Error parsing log" : "Napló feldolgozási hiba",
     "Cased by " : "Létrehozta",
-    "Copy" : "Másol",
-    "Copy raw" : "Eredeti formában másol",
-    "Copy formatted" : "Formázva másol",
-    "No server logs" : "Nincsenek szervernaplók",
+    "Copy" : "Másolás",
+    "Copy raw" : "Másolás eredeti formába",
+    "Copy formatted" : "Másolás formázva",
+    "No server logs" : "Nincsenek kiszolgálónaplók",
     "One or more entries are hidden by the log level filter" : "Egy vagy több bejegyzés elrejtve a naplózási szint szűrő miatt",
     "Everything is working fine" : "Minden rendben működik",
     "Log levels" : "Naplózási szintek",
-    "Log content" : "Napló tartalom",
+    "Log content" : "Naplótartalom",
     "Live update" : "Élő frissítés",
     "Download logs" : "Naplók letöltése",
     "Logging" : "Naplózás",
-    "Log Reader" : "Napló olvasó",
-    "A log reader for Nextcloud" : "Egy Nextcloud log olvasó",
-    "Log reader for Nextcloud" : "Nextcloud log olvasó"
+    "Log Reader" : "Naplóolvasó",
+    "A log reader for Nextcloud" : "Egy naplóolvasó a Nextcloudhoz",
+    "Log reader for Nextcloud" : "Naplóolvasó a Nextcloudhoz"
 },
 "nplurals=2; plural=(n != 1);");
