@@ -2,14 +2,20 @@ OC.L10N.register(
     "logreader",
     {
     "Error parsing log" : "로그 처리 오류",
+    "Cased by " : "발생 원인",
+    "Copy" : "복사",
+    "Copy raw" : "원본 복사",
+    "Copy formatted" : "형식을 지정하여 복사",
+    "No server logs" : "서버 로그 없음",
+    "One or more entries are hidden by the log level filter" : "로그 단계 필터에 의해서 하나 이상의 항목이 숨겨짐",
+    "Everything is working fine" : "모두 올바르게 작동하고 있습니다",
     "Log levels" : "로그 단계",
     "Log content" : "로그 내용",
     "Live update" : "실시간 업데이트",
     "Download logs" : "로그 다운로드",
-    "No server logs" : "서버 로그 없음",
-    "One or more entries are hidden by the log level filter" : "로그 단계 필터에 의해서 하나 이상의 항목이 숨겨짐",
-    "Everything is working fine" : "모두 올바르게 작동하고 있습니다",
     "Logging" : "로그",
-    "Log Reader" : "로그 리더"
+    "Log Reader" : "로그 리더",
+    "A log reader for Nextcloud" : "Nextcloud 로그 리더",
+    "Log reader for Nextcloud" : "Nextcloud 로그 리더"
 },
 "nplurals=1; plural=0;");
