@@ -3,14 +3,21 @@ OC.L10N.register(
     {
     "Error parsing log" : "Błąd w trakcie przetwarzania loga",
     "Cased by " : "Spowodowane przez",
-    "Log levels" : "Poziomy logowania",
-    "Log content" : "Zawartość loga",
-    "Live update" : "Aktualizacja na żywo",
-    "Download logs" : "Pobierz logi",
+    "Copy" : "Kopiuj",
+    "Copy raw" : "Kopiuj raw",
+    "Copy formatted" : "Kopiuj sformatowany",
     "No server logs" : "Brak logów serwera",
     "One or more entries are hidden by the log level filter" : "Co najmniej jeden wpis jest ukryty ze względu na aktywny filtr poziomu logów",
     "Everything is working fine" : "Wszystko pracuje prawidłowo",
-    "Logging" : "Logowanie",
+    "Level" : "Poziom",
+    "App" : "Aplikacja",
+    "Message" : "Komunikat",
+    "Time" : "Czas",
+    "Log levels" : "Poziomy",
+    "Log content" : "Zawiera",
+    "Live update" : "Aktualizacja na żywo",
+    "Download logs" : "Pobierz",
+    "Logging" : "Dziennik zdarzeń",
     "Log Reader" : "Czytnik logów",
     "A log reader for Nextcloud" : "Czytnik logów dla Nextcloud",
     "Log reader for Nextcloud" : "Czytnik logów dla Nextcloud"
