@@ -1,6 +1,7 @@
 OC.L10N.register(
     "oauth2",
     {
+    "Your client is not authorized to connect. Please inform the administrator of your client." : "Seu cliente não está autorizado a conectar-se. Informe isso ao administrador.",
     "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "A URL de redirecionamento precisa ser completa, por exemplo: https://yourdomain.com/path",
     "OAuth 2.0" : "OAuth 2.0",
     "Allows OAuth2 compatible authentication from other web applications." : "Permite a autenticação compatível com OAuth2 de outros aplicativos da web.",
@@ -14,7 +15,6 @@ OC.L10N.register(
     "Add client" : "Adicionar cliente",
     "Add" : "Adicionar",
     "Show client secret" : "Mostra senha do cliente",
-    "Delete" : "Excluir",
-    "OAuth 2.0 allows external services to request access to %s." : "OAuth 2.0 permite que serviços externos solicitem acesso a %s."
+    "Delete" : "Excluir"
 },
 "nplurals=2; plural=(n > 1);");
