@@ -11,31 +11,31 @@ OC.L10N.register(
     "Links" : "Lenker",
     "Federated sent" : "«Forent sendt» - delingen sendt eksternt",
     "Federated received" : "«Forent mottatt» - en ekstern deling mottatt",
-    "Last 24 hours" : "Siste 24 timer",
-    "Last 1 hour" : "Siste time",
-    "Last 5 mins" : "Siste 5 minutter",
     "Copy" : "Kopier",
     "Copied!" : "Kopiert!",
     "Not supported!" : "Ikke støttet!",
     "Monitoring" : "Overvåker",
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gir nyttig serverinformasjon, som CPU-belastning, RAM-bruk, diskbruk, antall brukere, ned mere.",
-    "CPU load" : "CPU last",
-    "Memory usage" : "Minnebruk",
+    "Files:" : "Filer:",
     "Active users" : "Aktive brukere",
     "Shares" : "Delinger",
-    "Storage" : "Lagring",
-    "Users:" : "Brukere:",
-    "Files:" : "Filer:",
-    "Version:" : "Versjon:",
-    "Apps installed:" : "Apper installert:",
-    "Apps updates available:" : "App-oppdateringer tilgjengelig:",
     "PHP" : "PHP",
+    "Version:" : "Versjon:",
     "Memory Limit:" : "Minnegrense:",
     "Max Execution Time:" : "Maks. kjøringstid:",
     "Upload max size:" : "Maks. opplastingstørrelse:",
     "Database" : "Database",
     "Type:" : "Type:",
     "Size:" : "Størrelse:",
-    "External monitoring tool" : "Eksternt overvåkingsverktøy"
+    "External monitoring tool" : "Eksternt overvåkingsverktøy",
+    "Last 24 hours" : "Siste 24 timer",
+    "Last 1 hour" : "Siste time",
+    "Last 5 mins" : "Siste 5 minutter",
+    "CPU load" : "CPU last",
+    "Memory usage" : "Minnebruk",
+    "Storage" : "Lagring",
+    "Users:" : "Brukere:",
+    "Apps installed:" : "Apper installert:",
+    "Apps updates available:" : "App-oppdateringer tilgjengelig:"
 },
 "nplurals=2; plural=(n != 1);");
