@@ -12,9 +12,6 @@ OC.L10N.register(
     "Links" : "Odkazy",
     "Federated sent" : "Odoslané do Zduženého Cloudu",
     "Federated received" : "Prijaté zo Združeného Cloudu",
-    "Last 24 hours" : "Posledných 24 hodín",
-    "Last 1 hour" : "Posledná 1 hodina",
-    "Last 5 mins" : "Posledných 5 minút",
     "Copy" : "Kopírovať",
     "Copied!" : "Skopírované!",
     "Not supported!" : "Nepodporované!",
@@ -23,20 +20,13 @@ OC.L10N.register(
     "Monitoring" : "Sledovanie",
     "Monitoring app with useful server information" : "Monitorovacia aplikácia s užitočnými informáciami o servri",
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Poskytuje užitočné informácie o servri, ako napríklad vyťaženie CPU, RAM, využitie diskov, počet používateľov, atď.",
-    "CPU load" : "Zaťaženie CPU",
-    "Memory usage" : "Využitie pamäte",
-    "Active users" : "Aktívni používatelia",
-    "Shares" : "Sprístupnené položky",
-    "Storage" : "Úložisko",
-    "Users:" : "Používatelia:",
     "Files:" : "Súbory:",
     "Storages:" : "Úložiská:",
     "Free Space:" : "Voľné miesto:",
-    "Nextcloud" : "Nextcloud",
-    "Version:" : "Verzia:",
-    "Apps installed:" : "Nainštalované aplikácie:",
-    "Apps updates available:" : "Dostupné aktualizácie aplikácií:",
+    "Active users" : "Aktívni používatelia",
+    "Shares" : "Sprístupnené položky",
     "PHP" : "PHP",
+    "Version:" : "Verzia:",
     "Memory Limit:" : "Obmedzenie pamäte:",
     "Max Execution Time:" : "Maximálny čas pre spustenie:",
     "Upload max size:" : "Maximálna veľkosť pre nahratie:",
@@ -45,6 +35,16 @@ OC.L10N.register(
     "Size:" : "Veľkosť:",
     "External monitoring tool" : "Externý sledovací nástroj",
     "You can connect an external monitoring tool by using this end point:" : "Pre pripojenie externého sledovacieho nástroja použite tento koncový bod:",
-    "Did you know?" : "Vedeli ste?"
+    "Did you know?" : "Vedeli ste?",
+    "Last 24 hours" : "Posledných 24 hodín",
+    "Last 1 hour" : "Posledná 1 hodina",
+    "Last 5 mins" : "Posledných 5 minút",
+    "CPU load" : "Zaťaženie CPU",
+    "Memory usage" : "Využitie pamäte",
+    "Storage" : "Úložisko",
+    "Users:" : "Používatelia:",
+    "Nextcloud" : "Nextcloud",
+    "Apps installed:" : "Nainštalované aplikácie:",
+    "Apps updates available:" : "Dostupné aktualizácie aplikácií:"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
