@@ -10,6 +10,7 @@ OC.L10N.register(
     "Number of shares <em>(per type and permission setting)</em>" : "Antal delningar <em>(per typ och rättighetsinställning)</em>",
     "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljö<em>(version, minnesgräns, max. exekveringstid, max. filstorlek)</em>",
     "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serverinstansdetaljer <em>(version, använt memcache, status över låsning/förhandsvisning/avatarer)</em>",
+    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statistik <em>(antal filer, användare, lagringar per typ, kommentarer och taggar)</em>",
     "Help improve Nextcloud" : "Hjälp till att  förbättra Nextcloud",
     "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vill du hjälpa oss förbättra Nextcloud genom att förse oss med anonym data om din installation och användning? Du kan stänga av det när som helst i administratörsinställningarna.",
     "Not now" : "Inte nu",
@@ -23,9 +24,6 @@ OC.L10N.register(
     "Send usage survey monthly" : "Skicka användarstatistik månadsvis",
     "Data to send" : "Data att inkludera",
     "Last report sent on: %s" : "Senaste rapporten skickad den: %s",
-    "Last report" : "Senaste rapport",
-    "Sent on: {on}" : "Sändes: {on}",
-    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Antal: filer, användare, lagringar per typ, kommentarer och taggar)</em>",
-    "Sent on: %s" : "Sändes: %s"
+    "Last report" : "Senaste rapport"
 },
 "nplurals=2; plural=(n != 1);");
