@@ -5,11 +5,6 @@ OC.L10N.register(
     "Update" : "Aktualisieren",
     "Create" : "Erstellen",
     "Select tag…" : "Tag wählen…",
-    "Tagged files" : "Mit Tags versehene Dateien",
-    "Select tags to filter by" : "Wähle Tags nach denen gefilter werden soll",
-    "No tags found" : "Keine Tags gefunden",
-    "Please select tags to filter by" : "Bitte wähle die Tags nach denen gefiltert werden soll",
-    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
     "System tag %1$s added by the system" : "System-Tag %1$s vom System hinzugefügt",
     "Added system tag {systemtag}" : "System-Tag {systemtag} hinzugefügt",
     "Added system tag %1$s" : "System-Tag %1$s hinzugefügt",
@@ -50,6 +45,11 @@ OC.L10N.register(
     "Collaborative tags" : "Kollaborative Tags",
     "Collaborative tagging functionality which shares tags among users." : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt.",
     "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Gemeinschaftliche Schlagwort-Funktionalität, welche Schlagworte unter den Benutzern teilt. Sehr gut für Gruppen.\n(Wenn Du ein Anbieter mit einer Mehrkundeninstallation bist, so ist angeraten diese App zu deaktiveren, da die Schlagworte mit allen Kunden geteilt werden.)",
+    "Tagged files" : "Mit Tags versehene Dateien",
+    "Select tags to filter by" : "Wähle Tags nach denen gefilter werden soll",
+    "No tags found" : "Keine Tags gefunden",
+    "Please select tags to filter by" : "Bitte wähle die Tags nach denen gefiltert werden soll",
+    "No files found for the selected tags" : "Keine Dateien für die ausgewählten Tags gefunden",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Öffentliche Schlagworte sind für alle Benutzer verfügbar. Eingeschränkte Schlagworte sind für alle Benutzer sichtbar, können jedoch nicht zugewiesen werden. Nicht sichtbare Schlagworte sind für interne Verwendung und können vom Benutzer nicht eingesehen und nicht zugewiesen werden.",
     "Select tag …" : "Tag wählen…",
     "Create a new tag" : "Neues Schlagwort erstellen",
@@ -62,7 +62,6 @@ OC.L10N.register(
     "No files in here" : "Keine Dateien vorhanden",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
     "Size" : "Größe",
-    "Modified" : "Geändert",
-    "Create and edit collaborative tags. These tags affect all users." : "Erstelle und bearbeite die gemeinsamen Tags. Diese Schlagworte betreffen alle Benutzer."
+    "Modified" : "Geändert"
 },
 "nplurals=2; plural=(n != 1);");
