@@ -5,20 +5,33 @@ OC.L10N.register(
     "Saved" : "저장됨",
     "Admin" : "관리자",
     "a safe home for all your data" : "내 모든 데이터 안전 저장소",
+    "Name cannot be empty" : "이름이 비어 있을 수 없음",
     "The given name is too long" : "입력한 이름이 너무 김",
     "The given web address is too long" : "입력한 웹 주소가 너무 김",
+    "The given legal notice address is too long" : "입력한 법적 고지가 너무 김",
+    "The given privacy policy address is too long" : "입력한 개인 정보 취급 방침 주소가 너무 김",
     "The given slogan is too long" : "입력한 슬로건이 너무 김",
     "The given color is invalid" : "입력한 색상이 잘못됨",
+    "The file was uploaded" : "파일을 업로드함",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
+    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
     "No file was uploaded" : "업로드한 파일 없음",
     "Missing a temporary folder" : "임시 폴더 없음",
+    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
+    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
     "No file uploaded" : "업로드한 파일 없음",
     "Unsupported image type" : "지원하지 않는 사진 형식",
+    "You are already using a custom theme. Theming app settings might be overwritten by that." : "사용자 정의 테마를 사용하고 있습니다. 테마 앱에서 해당 설정을 덮어쓸 수 있습니다.",
     "Theming" : "테마",
+    "Legal notice" : "법적 고지",
+    "Privacy policy" : "개인 정보 취급 방침",
+    "Adjust the Nextcloud theme" : "Nextcloud 테마 사용자 정의",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "테마를 사용하여 내 인스턴스와 지원하는 클라이언트의 모습을 변경할 수 있습니다. 테마는 모든 사용자에게 적용됩니다.",
     "Name" : "이름",
     "Reset to default" : "기본값으로 초기화",
+    "Web link" : "웹 링크",
+    "https://…" : "https://…",
     "Slogan" : "슬로건",
     "Color" : "색",
     "Logo" : "로고",
@@ -26,6 +39,13 @@ OC.L10N.register(
     "Login image" : "로그인 그림",
     "Upload new login background" : "새 로그인 배경 업로드",
     "Remove background image" : "배경 그림 삭제",
+    "Advanced options" : "고급 설정",
+    "Legal notice link" : "법적 고지 링크",
+    "Privacy policy link" : "개인 정보 취급 방침 링크",
+    "Header logo" : "머리글 로고",
+    "Upload new header logo" : "새 머리글 로고 업로드",
+    "Favicon" : "파비콘",
+    "Upload new favicon" : "새 파비콘 업로드",
     "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "업로드한 로고와 색으로부터 자동으로 파비콘을 생성하려면 PHP Imagemagick 확장 기능 및 SVG 형식 그림 지원을 설치하십시오."
 },
 "nplurals=1; plural=0;");
