@@ -6,7 +6,7 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Vis dine seneste feriebilledes og videoer som i biografen, vis et glimt af din seneste roman direkte fra din Nextcloud, vis din bedste GIF i din samling gennem forhåndsvisning af dine favoritfiler og meget mere!",
     "Error loading {name}" : "Fejl ved indlæsning af {name}",
     "Your browser does not support the video tag." : "Din browser understøtter ikke visning af video-filer",
-    "Share" : "Del",
-    "View" : "Vis"
+    "View" : "Vis",
+    "Share" : "Del"
 },
 "nplurals=2; plural=(n != 1);");
