@@ -6,7 +6,8 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeige Deine letzten Urlaubsfotos und -videos wie im Film, gib einen Einblick in Deinen neuesten Roman direkt aus deiner Nextcloud, wähle die besten GIF-Dateien aus Deiner Sammlung dank der direkten Voransicht Deiner favorisierten Dateien und viel mehr!",
     "Error loading {name}" : "Fehler beim Laden {name}",
     "Your browser does not support the video tag." : "Dein Browser unterstützt das Video-Tag nicht. ",
-    "Share" : "Teilen",
-    "View" : "Ansicht"
+    "Open sidebar" : "Seitenleiste öffnen",
+    "View" : "Ansicht",
+    "Share" : "Teilen"
 },
 "nplurals=2; plural=(n != 1);");
