@@ -6,7 +6,7 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Muestra tus últimas fotos y vídeos de vacaciones como en las películas, ofrece un vistazo a tu última novela directamente desde tu Nextcloud, escoge el mejor GIF de tu colección gracias a la previsualización directa de tus archivos favoritos y mucho más.",
     "Error loading {name}" : "Error al cargar {name}",
     "Your browser does not support the video tag." : "Tu navegador no soporta la etiqueta video.",
-    "Share" : "Compartir",
-    "View" : "Ver"
+    "View" : "Ver",
+    "Share" : "Compartir"
 },
 "nplurals=2; plural=(n != 1);");
