@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Viewer" : "Ikuslea",
     "Your browser does not support the video tag." : "Zure nabigatzaileak ez du euskarririk video etiketarentzat",
-    "Share" : "Elkarbanatu",
-    "View" : "Ikusi"
+    "View" : "Ikusi",
+    "Share" : "Elkarbanatu"
 },
 "nplurals=2; plural=(n != 1);");
