@@ -6,7 +6,8 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mutassa meg a kedvenc nyaralási fényképeit és videót mint a filmekben, mutassa meg a legfrissebb novellája részletét a Nextcloudban, válassza ki a legjobb GIF-képet a gyűjteményéből a kedvenc fájljainak közvetlen előnézetének, és a számos egyéb funkciónak köszönhetően.",
     "Error loading {name}" : "Hiba a(z) {name} betöltésekor",
     "Your browser does not support the video tag." : "A böngészője nem támogatja a video címkét.",
-    "Share" : "Megosztás",
-    "View" : "Megtekintés"
+    "Open sidebar" : "Oldalsáv megnyitása",
+    "View" : "Megtekintés",
+    "Share" : "Megosztás"
 },
 "nplurals=2; plural=(n != 1);");
