@@ -6,7 +6,7 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Rodykite savo paskiausių atostogų nuotraukas ir vaizdo įrašus, visai kaip filmuose, rodykite ištrauką iš savo naujausios novelės tiesiai iš savo Nextcloud, pasirinkite geriausią savo kolekcijos GIF, naudodami tiesioginę savo mėgstamų failų peržiūrą ir žymiai daugiau!",
     "Error loading {name}" : "Klaida įkeliant {name}",
     "Your browser does not support the video tag." : "Jūsų naršyklė nepalaiko vaizdo įrašo žymės.",
-    "Share" : "Bendrinti",
-    "View" : "Rodyti"
+    "View" : "Rodyti",
+    "Share" : "Bendrinti"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
