@@ -6,7 +6,7 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Toon je laatste vakantie foto's en videos als in de film, toon een deel van je laatste boek direct uit uw nextcloud, kies de beste GIF uit jouw collectie dankzij de directe voorvertoning van je favoriete bestanden en nog veel meer!",
     "Error loading {name}" : "Fout bij laden van {name}",
     "Your browser does not support the video tag." : "Je browser ondersteund de video tag niet.",
-    "Share" : "Delen",
-    "View" : "Bekijken"
+    "View" : "Bekijken",
+    "Share" : "Delen"
 },
 "nplurals=2; plural=(n != 1);");
