@@ -6,7 +6,8 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokaż najnowsze zdjęcia i filmy z wakacji. Pokaż swoją najnowszą przygodę bezpośrednio z Nextcloud. Wybierz najlepszy GIF ze swojej kolekcji. I to wszystko dzięki bezpośredniemu podglądowi ulubionych plików i wielu innych!",
     "Error loading {name}" : "Błąd podczas ładowania {name}",
     "Your browser does not support the video tag." : "Twoja przeglądarka nie obsługuje etykiety wideo.",
-    "Share" : "Udostępnij",
-    "View" : "Podgląd"
+    "Open sidebar" : "Otwórz pasek boczny",
+    "View" : "Podgląd",
+    "Share" : "Udostępnij"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
