@@ -6,7 +6,8 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mostre suas fotos e vídeos das férias mais recentes como nos filmes. Mostre um vislumbre do seu mais recente romance diretamente a partir do nextcloud. Escolha o melhor GIF da sua coleção, graças à pré-visualização direta dos seus arquivos favoritos e muito mais!",
     "Error loading {name}" : "Erro ao carregar {name}",
     "Your browser does not support the video tag." : "Seu navegador não suporta a etiqueta de vídeo.",
-    "Share" : "Compartilhar",
-    "View" : "Visualizar"
+    "Open sidebar" : "Abrir barra lateral",
+    "View" : "Visualizar",
+    "Share" : "Compartilhar"
 },
 "nplurals=2; plural=(n > 1);");
