@@ -6,7 +6,8 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Вы можете показать свои последние праздничные фотографии и видео, прямо как в фильмах! Вы можете показать свой последний роман прямо из вашего Nextcloud! Вы можете выбрать лучший GIF из вашей коллекции благодаря непосредственному предварительному просмотру ваших избранных файлов и многое другое!",
     "Error loading {name}" : "Ошибка при загрузке {name}",
     "Your browser does not support the video tag." : "Ваш браузер не поддерживает метку видео.",
-    "Share" : "Общий доступ",
-    "View" : "Просмотр"
+    "Open sidebar" : "Открыть боковую панель",
+    "View" : "Просмотр",
+    "Share" : "Общий доступ"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
