@@ -5,7 +5,7 @@ OC.L10N.register(
     "Simple file viewer with slideshow for media" : "Enostaven pregledovalnik datotek z možnostjo predstavitve",
     "Error loading {name}" : "Prišlo je do napake med nalaganjem {name}",
     "Your browser does not support the video tag." : "Spletni brskalnik ne podpira oznak videa.",
-    "Share" : "Souporaba",
-    "View" : "Poglej"
+    "View" : "Poglej",
+    "Share" : "Souporaba"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
