@@ -1,16 +1,6 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "Short rule description" : "Short rule description",
-    "Add rule" : "Add rule",
-    "Reset" : "Reset",
-    "Save" : "Save",
-    "Saving…" : "Saving…",
-    "Group list is empty" : "Group list is empty",
-    "Unable to retrieve the group list" : "Unable to retrieve the group list",
-    "Saved" : "Saved",
-    "Saving failed:" : "Saving failed:",
-    "Add rule group" : "Add rule group",
     "File MIME type" : "File MIME type",
     "is" : "is",
     "is not" : "is not",
@@ -50,6 +40,16 @@ OC.L10N.register(
     "User group membership" : "User group membership",
     "is member of" : "is member of",
     "is not member of" : "is not member of",
+    "Short rule description" : "Short rule description",
+    "Add rule" : "Add rule",
+    "Reset" : "Reset",
+    "Save" : "Save",
+    "Saving…" : "Saving…",
+    "Group list is empty" : "Group list is empty",
+    "Unable to retrieve the group list" : "Unable to retrieve the group list",
+    "Saved" : "Saved",
+    "Saving failed:" : "Saving failed:",
+    "Add rule group" : "Add rule group",
     "The given operator is invalid" : "The given operator is invalid",
     "The given regular expression is invalid" : "The given regular expression is invalid",
     "The given file size is invalid" : "The given file size is invalid",
@@ -68,9 +68,9 @@ OC.L10N.register(
     "Check %s does not exist" : "Check %s does not exist",
     "Check %s is invalid" : "Check %s is invalid",
     "Check #%s does not exist" : "Check #%s does not exist",
-    "Workflow" : "Workflow",
     "Files workflow engine" : "Files workflow engine",
     "Open documentation" : "Open documentation",
-    "Loading…" : "Loading…"
+    "Loading…" : "Loading…",
+    "Workflow" : "Workflow"
 },
 "nplurals=2; plural=(n != 1);");
