@@ -1,16 +1,6 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "Short rule description" : "Breve descrición da regra",
-    "Add rule" : "Engadir unha regra",
-    "Reset" : "Restabelecer",
-    "Save" : "Gardar",
-    "Saving…" : "Gardando…",
-    "Group list is empty" : "A lista de grupos está baleira",
-    "Unable to retrieve the group list" : "Non é posíbel recuperar a lista de grupos",
-    "Saved" : "Gardado",
-    "Saving failed:" : "Produciuse un fallo ao gardar:",
-    "Add rule group" : "Engadir unha regra de grupo",
     "File MIME type" : "Tipo MIME do ficheiro",
     "is" : "é",
     "is not" : "non é",
@@ -50,6 +40,16 @@ OC.L10N.register(
     "User group membership" : "Pertencia a un grupo de usuarios",
     "is member of" : "é membro de",
     "is not member of" : "non é membro de",
+    "Short rule description" : "Breve descrición da regra",
+    "Add rule" : "Engadir unha regra",
+    "Reset" : "Restabelecer",
+    "Save" : "Gardar",
+    "Saving…" : "Gardando…",
+    "Group list is empty" : "A lista de grupos está baleira",
+    "Unable to retrieve the group list" : "Non é posíbel recuperar a lista de grupos",
+    "Saved" : "Gardado",
+    "Saving failed:" : "Produciuse un fallo ao gardar:",
+    "Add rule group" : "Engadir unha regra de grupo",
     "The given operator is invalid" : "O operador indicado é incorrecto",
     "The given regular expression is invalid" : "A expresión regular indicada é incorrecta",
     "The given file size is invalid" : "O tamaño do ficheiro indicado é incorrecto",
@@ -68,9 +68,10 @@ OC.L10N.register(
     "Check %s does not exist" : "Non existe a proba %s",
     "Check %s is invalid" : "A proba %s é incorrecta",
     "Check #%s does not exist" : "Non existe a proba num. %s ",
-    "Workflow" : "Fluxo de traballo",
+    "Tag management" : "Xestión de etiquetas",
     "Files workflow engine" : "Motor de fluxo de traballo de ficheiros",
     "Open documentation" : "Documentación aberta",
-    "Loading…" : "Cargando…"
+    "Loading…" : "Cargando…",
+    "Workflow" : "Fluxo de traballo"
 },
 "nplurals=2; plural=(n != 1);");
