@@ -1,16 +1,6 @@
 OC.L10N.register(
     "workflowengine",
     {
-    "Short rule description" : "Kort regelbeskrivning",
-    "Add rule" : "Lägg till regel",
-    "Reset" : "Återställ",
-    "Save" : "Spara",
-    "Saving…" : "Sparar...",
-    "Group list is empty" : "Grupplistan är tom",
-    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
-    "Saved" : "Sparad",
-    "Saving failed:" : "Gick ej att spara: ",
-    "Add rule group" : "Lägg till regelgrupp",
     "File MIME type" : "Filens MIME-typ",
     "is" : "är",
     "is not" : "är inte",
@@ -50,6 +40,16 @@ OC.L10N.register(
     "User group membership" : "Användargruppsmedlemskap",
     "is member of" : "är medlem i",
     "is not member of" : "är inte medlem i",
+    "Short rule description" : "Kort regelbeskrivning",
+    "Add rule" : "Lägg till regel",
+    "Reset" : "Återställ",
+    "Save" : "Spara",
+    "Saving…" : "Sparar...",
+    "Group list is empty" : "Grupplistan är tom",
+    "Unable to retrieve the group list" : "Kan inte hämta grupplistan",
+    "Saved" : "Sparad",
+    "Saving failed:" : "Gick ej att spara: ",
+    "Add rule group" : "Lägg till regelgrupp",
     "The given operator is invalid" : "Den valda operatören är felaktig",
     "The given regular expression is invalid" : "Det valda vanliga uttrycket är felaktigt",
     "The given file size is invalid" : "Den valda filstorleken är felaktig",
@@ -68,8 +68,9 @@ OC.L10N.register(
     "Check %s does not exist" : "Kontroll av %s existerar inte",
     "Check %s is invalid" : "Kontroll av %s är ogiltig",
     "Check #%s does not exist" : "Kontroll av #%s existerar inte",
-    "Workflow" : "Arbetsflöde",
+    "Tag management" : "Tagghantering",
     "Open documentation" : "Öppna dokumentation",
-    "Loading…" : "Laddar..."
+    "Loading…" : "Laddar...",
+    "Workflow" : "Arbetsflöde"
 },
 "nplurals=2; plural=(n != 1);");
