@@ -913,9 +913,13 @@ function initCore() {
 	}
 
 	// css variables fallback for IE
-	if (msie > 0 || trident > 0) {
+	if (msie > 0 || trident > 0 || edge > 0) {
+		console.info('Legacy browser detected, applying css vars polyfill')
 		cssVars({
-			watch: true
+			watch: true,
+			//  set edge < 16 as incompatible
+			onlyLegacy: !(/Edge\/([0-9]{2})\./i.test(navigator.userAgent)
+				&& parseInt(/Edge\/([0-9]{2})\./i.exec(navigator.userAgent)[1]) < 16)
 		});
 	}
 
@@ -1311,7 +1315,6 @@ function initCore() {
 
 $(document).ready(initCore);
 
-/**
 // fallback to hashchange when no history support
 if (window.history.pushState) {
 	window.onpopstate = _.bind(OC.Util.History._onPopState, OC.Util.History);
