@@ -59,151 +59,6 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekongrua)",
     "Following apps have been disabled: %s" : "Jenaj aplikaĵoj estis malŝaltataj: %s",
     "Already up to date" : "Jam aktuala",
-    ": " : ": ",
-    "Dismiss" : "Forsendi",
-    "Connection to server lost" : "Konekto al servilo perdita",
-    "No" : "Ne",
-    "Yes" : "Jes",
-    "No files in here" : "Neniu dosiero ĉi tie",
-    "New folder" : "Nova dosierujo",
-    "No more subfolders in here" : "Ne plu estas subdosierujo ĉi tie.",
-    "Name" : "Nomo",
-    "Size" : "Grando",
-    "Modified" : "Modifita",
-    "{newName} already exists" : "{newName} jam ekzistas",
-    "Choose" : "Elekti",
-    "Copy" : "Kopii",
-    "Move" : "Movi",
-    "Error loading file picker template: {error}" : "Eraro dum ŝargo de ŝablono pri dosier-elektilo: {error}",
-    "OK" : "Akcepti",
-    "Error loading message template: {error}" : "Eraro dum ŝargo de mesaĝa ŝablono: {eraro}",
-    "read-only" : "nurlega",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosierkonflikto","{count} dosierkonfliktoj"],
-    "One file conflict" : "Unu dosierkonflikto",
-    "New Files" : "Novaj dosieroj",
-    "Already existing files" : "Jam ekzistantaj dosieroj",
-    "Which files do you want to keep?" : "Kiujn dosierojn vi volas konservi?",
-    "If you select both versions, the copied file will have a number added to its name." : "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
-    "Cancel" : "Nuligi",
-    "Continue" : "Daŭrigi",
-    "(all selected)" : "(ĉiuj elektitaj)",
-    "({count} selected)" : "({count} elektitaj)",
-    "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
-    "Pending" : "Pritraktota",
-    "Copy to {folder}" : "Kopii al {folder}",
-    "Move to {folder}" : "Movi al {folder}",
-    "Saving..." : "Konservante...",
-    "seconds ago" : "sekundoj antaŭe",
-    "Settings" : "Agordo",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
-    "Authentication required" : "Aŭtentiĝo nepras",
-    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas, ke vi konfirmas vian pasvorton",
-    "Confirm" : "Konfirmi",
-    "Password" : "Pasvorto",
-    "Failed to authenticate, try again" : "Malsukcesis aŭtentigi, provu ree",
-    "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
-    "Search contacts …" : "Serĉi kontaktojn…",
-    "No contacts found" : "Neniu kontakto troviĝis",
-    "Show all contacts …" : "Montri ĉiujn kontaktojn",
-    "Loading your contacts …" : "Ŝargante viajn kontaktojn...",
-    "Looking for {term} …" : "Serĉo de {term}…",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "La ligilo por restarigi vian pasvorton estis sendita al via retpoŝtadreso. Se vi ne ricevas ĝin baldaŭ, vidu vian spamujon.<br>Se ĝi ne estas tie, pridemandu vian administranton.",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Viaj dosieroj estas ĉifritaj. Ne estos eble rehavi viajn datumojn post la restarigo de via pasvorto.<br />Se vi ne tute certas pri krio fari, bonvolu pridemandi vian administranton, antaŭ ol daŭrigi. <br />Ĉu vi ja volas daŭrigi?",
-    "I know what I'm doing" : "Mi scias, kion mi faras",
-    "Password can not be changed. Please contact your administrator." : "Pasvorto ne eblas esti ŝanĝita. Bonvolu kontakti vian administranton.",
-    "Reset password" : "Restarigi pasvorton",
-    "Sending email …" : "Sendante retpoŝton...",
-    "Logging in …" : "Ensaluti...",
-    "New in" : "Nova en",
-    "View changelog" : "Vidi ŝanĝoprotokolon",
-    "No action available" : "Neniu ago disponebla",
-    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
-    "Error" : "Eraro",
-    "Error while sharing" : "Eraro dum kunhavigo",
-    "Error removing share" : "Eraro dum forigo de kunhavigo",
-    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
-    "Shared with you and {circle} by {owner}" : "Kunhavigita kun vi kaj {circle} de {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Kunhavigita kun vi kaj la konversacio {conversation} de {owner}",
-    "Shared with you in a conversation by {owner}" : "Kunhavigita kun vi en konversacio de {owner}",
-    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
-    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
-    "Choose a password for the public link or press the \"Enter\" key" : "Elektu pasvorton por la publika ligilo aŭ premu la enigan klavon",
-    "Copied!" : "Kopiita!",
-    "Copy link" : "Kopii ligilon",
-    "Not supported!" : "Ne subtenite!",
-    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
-    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
-    "Unable to create a link share" : "Ne eblis krei kunhavo-ligilon",
-    "Unable to toggle this option" : "Ne eblis baskuligi tiun opcion",
-    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
-    "Link" : "Ligilo",
-    "Hide download" : "Kaŝi elŝuton",
-    "Password protection enforced" : "Pasvorta protekto efektiva",
-    "Password protect" : "Protekti per pasvorto",
-    "Allow editing" : "Permesi redakton",
-    "Email link to person" : "Retpoŝti la ligilon",
-    "Send" : "Sendi",
-    "Allow upload and editing" : "Permesi alŝuton kaj redakton",
-    "Read only" : "Nurlega",
-    "File drop (upload only)" : "Demeti dosieron (nur alŝuto)",
-    "Expiration date enforced" : "Limdato efektiva",
-    "Set expiration date" : "Agordi limdaton",
-    "Expiration" : "Eksvalidiĝo",
-    "Expiration date" : "Limdato",
-    "Note to recipient" : "Noto al ricevonto",
-    "Unshare" : "Malkunhavigi",
-    "Delete share link" : "Forigi kunhavo-ligilon",
-    "Add another link" : "Aldoni plian ligilon",
-    "Password protection for links is mandatory" : "Pasvorta protekto de ligiloj estas deviga",
-    "Share to {name}" : "Kunhavigi al {name}",
-    "Share link" : "Kunhavigi ligilon",
-    "New share link" : "Nova kunhavo-ligilo",
-    "Created on {time}" : "Kreita je {time}",
-    "Password protect by Talk" : "Pasvorta protekto pere de „Talk“",
-    "Could not unshare" : "Ne eblis malkunhavigi",
-    "Choose a password for the mail share" : "Elektu pasvorton por la retpoŝta kunhavigo",
-    "group" : "grupo",
-    "remote" : "fora",
-    "remote group" : "fora grupo",
-    "email" : "retpoŝtadreso",
-    "conversation" : "konversacio",
-    "shared by {sharer}" : "kunhavigita de {sharer}",
-    "Can reshare" : "Eblas rekunhavigi",
-    "Can edit" : "Povas redakti",
-    "Can create" : "Povas krei",
-    "Can change" : "Eblas ŝanĝi",
-    "Can delete" : "Povas forigi",
-    "Access control" : "Alirkontrolo",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} kunhavigis per ligilo",
-    "Share details could not be loaded for this item." : "Kunhavaj detaloj pri ĉi tiu ero ne ŝargeblis.",
-    "Search globally" : "Serĉi ĉie",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Aŭtomata kompletigo bezonas almenaŭ {count} signon","Aŭtomata kompletigo bezonas almenaŭ {count} signojn"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Eble mankas rezultoj: bv. pliprecizigi vian serĉon por vidi pli da rezultoj.",
-    "No users or groups found for {search}" : "Neniu uzanto aŭ grupo troviĝis por {search}",
-    "No users found for {search}" : "Neniu uzanto troviĝis por {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Eraro okazis („{message}“). Bonvolu provi ree.",
-    "An error occurred. Please try again" : "Eraro okazis. Bonvolu provi ree",
-    "Home" : "Hejmo",
-    "Work" : "Laboro",
-    "Other" : "Alia",
-    "{sharee} (remote group)" : "{sharee} (fora grupo)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Kunhavigi",
-    "Name or email address..." : "Nomo aŭ retpoŝtadreso...",
-    "Name or federated cloud ID..." : "Namo aŭ federnuba identigilo...",
-    "Name, federated cloud ID or email address..." : "Nomo, federnuba identigilo aŭ retpoŝtadreso...",
-    "Name..." : "Nomo...",
-    "Shared" : "Kunhavata",
-    "Shared with" : "Kunhavigita kun",
-    "Shared by" : "Kunhavigita de",
-    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
-    "restricted" : "limigita",
-    "invisible" : "nevidebla",
-    "({scope})" : "({scope})",
-    "Delete" : "Forigi",
-    "Rename" : "Alinomi",
-    "Collaborative tags" : "Kunlaboraj etikedoj",
-    "No tags found" : "Neniu etikedo troviĝis ",
     "Very weak password" : "Tre malforta pasvorto",
     "Weak password" : "Malforta pasvorto",
     "So-so password" : "Mezbona pasvorto",
@@ -255,6 +110,94 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "La HTTP-kapo „{header}“ ne egalas al „{val1}“, „{val2}“, „{val3}“, „{val4}“ aŭ „{val5}“. Tio povas nepermesite diskonigi referencantojn. Legu la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C-rekomendon ↗</a>.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "La HTTP-kapo „Strict-Transport-Security“ (angle por severa sekurigo de transporto, HSTS) ne egalas almenaŭ „{seconds}“ sekundojn. Por pli da sekureco, oni rekomendas ebligi HSTS-kapon kiel priskribita en la <a href=\"{docUrl}\" rel=\"noreferrer noopener\">praktikaj konsiloj pri sekurigo ↗</a>.",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Vi atingas tiun retejon per HTTP. Ni tre rekomendas agordi vian retservilon tiel, ke HTTPS uziĝu anstataŭe; vidu la <a href=\"{docUrl}\">praktikajn konsilojn pri sekurigo ↗</a>.",
+    "Shared" : "Kunhavata",
+    "Shared with" : "Kunhavigita kun",
+    "Shared by" : "Kunhavigita de",
+    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
+    "Choose a password for the public link or press the \"Enter\" key" : "Elektu pasvorton por la publika ligilo aŭ premu la enigan klavon",
+    "Copied!" : "Kopiita!",
+    "Copy link" : "Kopii ligilon",
+    "Not supported!" : "Ne subtenite!",
+    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
+    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
+    "Copy" : "Kopii",
+    "Unable to create a link share" : "Ne eblis krei kunhavo-ligilon",
+    "Unable to toggle this option" : "Ne eblis baskuligi tiun opcion",
+    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
+    "Link" : "Ligilo",
+    "Hide download" : "Kaŝi elŝuton",
+    "Password protection enforced" : "Pasvorta protekto efektiva",
+    "Password protect" : "Protekti per pasvorto",
+    "Password" : "Pasvorto",
+    "Allow editing" : "Permesi redakton",
+    "Email link to person" : "Retpoŝti la ligilon",
+    "Send" : "Sendi",
+    "Allow upload and editing" : "Permesi alŝuton kaj redakton",
+    "Read only" : "Nurlega",
+    "File drop (upload only)" : "Demeti dosieron (nur alŝuto)",
+    "Expiration date enforced" : "Limdato efektiva",
+    "Set expiration date" : "Agordi limdaton",
+    "Expiration" : "Eksvalidiĝo",
+    "Expiration date" : "Limdato",
+    "Note to recipient" : "Noto al ricevonto",
+    "Unshare" : "Malkunhavigi",
+    "Delete share link" : "Forigi kunhavo-ligilon",
+    "Add another link" : "Aldoni plian ligilon",
+    "Password protection for links is mandatory" : "Pasvorta protekto de ligiloj estas deviga",
+    "Share to {name}" : "Kunhavigi al {name}",
+    "Share link" : "Kunhavigi ligilon",
+    "New share link" : "Nova kunhavo-ligilo",
+    "Created on {time}" : "Kreita je {time}",
+    "Password protect by Talk" : "Pasvorta protekto pere de „Talk“",
+    "Could not unshare" : "Ne eblis malkunhavigi",
+    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
+    "Shared with you and {circle} by {owner}" : "Kunhavigita kun vi kaj {circle} de {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Kunhavigita kun vi kaj la konversacio {conversation} de {owner}",
+    "Shared with you in a conversation by {owner}" : "Kunhavigita kun vi en konversacio de {owner}",
+    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
+    "Choose a password for the mail share" : "Elektu pasvorton por la retpoŝta kunhavigo",
+    "group" : "grupo",
+    "remote" : "fora",
+    "remote group" : "fora grupo",
+    "email" : "retpoŝtadreso",
+    "conversation" : "konversacio",
+    "shared by {sharer}" : "kunhavigita de {sharer}",
+    "Can reshare" : "Eblas rekunhavigi",
+    "Can edit" : "Povas redakti",
+    "Can create" : "Povas krei",
+    "Can change" : "Eblas ŝanĝi",
+    "Can delete" : "Povas forigi",
+    "Access control" : "Alirkontrolo",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} kunhavigis per ligilo",
+    "Error while sharing" : "Eraro dum kunhavigo",
+    "Share details could not be loaded for this item." : "Kunhavaj detaloj pri ĉi tiu ero ne ŝargeblis.",
+    "Search globally" : "Serĉi ĉie",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Aŭtomata kompletigo bezonas almenaŭ {count} signon","Aŭtomata kompletigo bezonas almenaŭ {count} signojn"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Eble mankas rezultoj: bv. pliprecizigi vian serĉon por vidi pli da rezultoj.",
+    "No users or groups found for {search}" : "Neniu uzanto aŭ grupo troviĝis por {search}",
+    "No users found for {search}" : "Neniu uzanto troviĝis por {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Eraro okazis („{message}“). Bonvolu provi ree.",
+    "An error occurred. Please try again" : "Eraro okazis. Bonvolu provi ree",
+    "Home" : "Hejmo",
+    "Work" : "Laboro",
+    "Other" : "Alia",
+    "{sharee} (remote group)" : "{sharee} (fora grupo)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Kunhavigi",
+    "Name or email address..." : "Nomo aŭ retpoŝtadreso...",
+    "Name or federated cloud ID..." : "Namo aŭ federnuba identigilo...",
+    "Name, federated cloud ID or email address..." : "Nomo, federnuba identigilo aŭ retpoŝtadreso...",
+    "Name..." : "Nomo...",
+    "Error" : "Eraro",
+    "Error removing share" : "Eraro dum forigo de kunhavigo",
+    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
+    "restricted" : "limigita",
+    "invisible" : "nevidebla",
+    "({scope})" : "({scope})",
+    "Delete" : "Forigi",
+    "Rename" : "Alinomi",
+    "Collaborative tags" : "Kunlaboraj etikedoj",
+    "No tags found" : "Neniu etikedo troviĝis ",
     "unknown text" : "nekonata teksto",
     "Hello world!" : "Saluton, mondo!",
     "sunny" : "suna",
@@ -274,6 +217,68 @@ OC.L10N.register(
     "Searching other places" : "Serĉante en aliaj lokoj",
     "No search results in other folders for {tag}{filter}{endtag}" : "Neniu serĉ-rezultoj en aliaj dosierujoj por {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} serĉ-rezulto en alia dosierujo","{count} serĉ-rezultoj en aliaj dosierujoj"],
+    "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
+    "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
+    "An internal error occurred." : "Interna servileraro okazis.",
+    "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
+    "Username or email" : "Uzantnomo aŭ retpoŝtadreso",
+    "Log in" : "Ensaluti",
+    "Logging in …" : "Ensaluti...",
+    "Wrong username or password." : "Neĝusta uzantnomo aŭ pasvorto.",
+    "User disabled" : "Uzanto malvalidigita",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
+    "Reset password" : "Restarigi pasvorton",
+    "Password can not be changed. Please contact your administrator." : "Pasvorto ne eblas esti ŝanĝita. Bonvolu kontakti vian administranton.",
+    "Back to login" : "Antaŭen al ensaluto",
+    "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
+    "Settings" : "Agordo",
+    "Could not load your contacts" : "Ne eblis ŝargi viajn kontaktojn",
+    "Search contacts …" : "Serĉi kontaktojn…",
+    "No contacts found" : "Neniu kontakto troviĝis",
+    "Show all contacts …" : "Montri ĉiujn kontaktojn",
+    "Loading your contacts …" : "Ŝargante viajn kontaktojn...",
+    "Looking for {term} …" : "Serĉo de {term}…",
+    "No" : "Ne",
+    "Yes" : "Jes",
+    "No files in here" : "Neniu dosiero ĉi tie",
+    "New folder" : "Nova dosierujo",
+    "No more subfolders in here" : "Ne plu estas subdosierujo ĉi tie.",
+    "Name" : "Nomo",
+    "Size" : "Grando",
+    "Modified" : "Modifita",
+    "{newName} already exists" : "{newName} jam ekzistas",
+    "Choose" : "Elekti",
+    "Move" : "Movi",
+    "Error loading file picker template: {error}" : "Eraro dum ŝargo de ŝablono pri dosier-elektilo: {error}",
+    "OK" : "Akcepti",
+    "Error loading message template: {error}" : "Eraro dum ŝargo de mesaĝa ŝablono: {eraro}",
+    "read-only" : "nurlega",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosierkonflikto","{count} dosierkonfliktoj"],
+    "One file conflict" : "Unu dosierkonflikto",
+    "New Files" : "Novaj dosieroj",
+    "Already existing files" : "Jam ekzistantaj dosieroj",
+    "Which files do you want to keep?" : "Kiujn dosierojn vi volas konservi?",
+    "If you select both versions, the copied file will have a number added to its name." : "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
+    "Cancel" : "Nuligi",
+    "Continue" : "Daŭrigi",
+    "(all selected)" : "(ĉiuj elektitaj)",
+    "({count} selected)" : "({count} elektitaj)",
+    "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
+    "Pending" : "Pritraktota",
+    "Copy to {folder}" : "Kopii al {folder}",
+    "Move to {folder}" : "Movi al {folder}",
+    "Saving..." : "Konservante...",
+    "Authentication required" : "Aŭtentiĝo nepras",
+    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas, ke vi konfirmas vian pasvorton",
+    "Confirm" : "Konfirmi",
+    "Failed to authenticate, try again" : "Malsukcesis aŭtentigi, provu ree",
+    "seconds ago" : "sekundoj antaŭe",
+    "Connection to server lost" : "Konekto al servilo perdita",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemo dum ŝargo de paĝo, reŝargo en %n sekundo","Problemo dum ŝargo de paĝo, reŝargo en %n sekundoj"],
+    "New in" : "Nova en",
+    "View changelog" : "Vidi ŝanĝoprotokolon",
+    "No action available" : "Neniu ago disponebla",
+    "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
     "Personal" : "Persona",
     "Users" : "Uzantoj",
     "Apps" : "Aplikaĵoj",
@@ -336,17 +341,6 @@ OC.L10N.register(
     "Contacts menu" : "Menuo de kontaktoj",
     "Settings menu" : "Menuo de agordo",
     "Confirm your password" : "Konfirmu vian pasvorton",
-    "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
-    "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
-    "An internal error occurred." : "Interna servileraro okazis.",
-    "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
-    "Username or email" : "Uzantnomo aŭ retpoŝtadreso",
-    "Log in" : "Ensaluti",
-    "Wrong username or password." : "Neĝusta uzantnomo aŭ pasvorto.",
-    "User disabled" : "Uzanto malvalidigita",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
-    "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
-    "Back to login" : "Antaŭen al ensaluto",
     "Connect to your account" : "Konekti al via konto",
     "Please log in before granting %1$s access to your %2$s account." : "Bv. unue ensaluti por doni al %1$s aliron al via konto %2$s.",
     "App token" : "Aplikaĵa ĵetono",
@@ -364,9 +358,13 @@ OC.L10N.register(
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Plibonigita sekurigo estas ebligita por via konto. Elektu duan fazon por aŭtentigo:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ne eblis ŝargi almenaŭ unu el viaj ebligitaj metodoj pri dufaza aŭtentigo. Bv. kontakti vian administranton.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Kontakti vian administranton por helpo.",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Bv. daŭrigi por agordi ĝin.",
+    "Set up two-factor authentication" : "Agordi dufazan aŭtentigon",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Uzu unu el viaj rezervkodoj por ensaluti, aŭ kontaktu vian administranton por helpo.",
     "Use backup code" : "Uzi rezervkodon",
     "Cancel log in" : "Nuligi ensaluton",
+    "Setup two-factor authentication" : "Agordi dufazan aŭtentigon",
+    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Plibonigita sekurigo estas devigata por via konto. Elektu provizanton agordotan:",
     "Error while validating your second factor" : "Eraro dum validigo de via dua fazo",
     "Access through untrusted domain" : "Aliro tra nefidinda domajno",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bv. kontakti vian administranton. Se vi estas administranto, modifu la agordon „trusted_domains“ (fidindaj domajnoj en la angla) en la dosiero config/config.php (estas ekzemplo en config.sample.php).",
@@ -391,7 +389,11 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktu vian administranton, se tiu ĉi mesaĝo daŭras aŭ aperas neatendite.",
     "Updated \"%s\" to %s" : "Ĝisdatiĝis „%s“ al %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Estis problemoj kun kontrolo de la koda integreco. Pli da informoj...</a> ",
+    "Dismiss" : "Forsendi",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "La ligilo por restarigi vian pasvorton estis sendita al via retpoŝtadreso. Se vi ne ricevas ĝin baldaŭ, vidu vian spamujon.<br>Se ĝi ne estas tie, pridemandu vian administranton.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Viaj dosieroj estas ĉifritaj. Ne estos eble rehavi viajn datumojn post la restarigo de via pasvorto.<br />Se vi ne tute certas pri krio fari, bonvolu pridemandi vian administranton, antaŭ ol daŭrigi. <br />Ĉu vi ja volas daŭrigi?",
+    "I know what I'm doing" : "Mi scias, kion mi faras",
+    "Sending email …" : "Sendante retpoŝton...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} versio {version} estas instalita. Pro stabileco kaj rendimento, oni rekomendas ĝisdatigi {name} al pli freŝa versio.",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom ne legeblas de PHP, kio estas tre malrekomendinde pro sekurigaj kialoj. Pli da informoj troveblas en la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentaron</a>.",
     "Copy URL" : "Kopii retadreson",
@@ -414,6 +416,7 @@ OC.L10N.register(
     "Further information how to configure this can be found in the %sdocumentation%s." : "Pliaj informoj pri agordo de tio troveblas en la %sdokumentaro%s.",
     "%s will be updated to version %s" : "%s ĝisdatiĝos al versio %s",
     "This page will refresh itself when the %s instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo %s redisponeblos.",
-    "Thank you for your patience." : "Dankon pro via pacienco."
+    "Thank you for your patience." : "Dankon pro via pacienco.",
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "La ligilo por restarigi vian pasvorton estis sendita al via retpoŝtadreso. Se vi ne ricevas ĝin baldaŭ, vidu vian spamujon.<br>Se ĝi ne estas tie, pridemandu vian administranton."
 },
 "nplurals=2; plural=(n != 1);");
