@@ -14,6 +14,7 @@ OC.L10N.register(
     "No crop data provided" : "Leikkaustietoa ei annettu",
     "No valid crop data provided" : "Kelvollisia leikkaustietoja ei määritetty",
     "Crop is not square" : "Leikkaus ei ole neliö",
+    "Could not complete login" : "Kirjautumista ei voitu suorittaa loppuun",
     "Password reset is disabled" : "Salasanan palautus poistettu käytöstä",
     "Couldn't reset password because the token is invalid" : "Salasanaa ei voitu palauttaa, koska valtuutus on virheellinen",
     "Couldn't reset password because the token is expired" : "Salasanaa ei voitu palauttaa, koska valtuutus on vanhentunut",
@@ -25,8 +26,14 @@ OC.L10N.register(
     "Reset your password" : "Palauta salasanasi",
     "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
     "Couldn't send reset email. Please make sure your username is correct." : "Palautussähköpostin lähettäminen ei onnistunut. Varmista, että käyttäjätunnuksesi on oikein.",
+    "Some of your link shares have been removed" : "Jotkin linkkijakosi on poistettu",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Tietoturvaongelman vuoksi jouduimme poistaa joitakin linkkijakojasi. Lue lisätietoja linkin kautta.",
     "Preparing update" : "Valmistellaan päivitystä",
     "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Korjausvaihe:",
+    "Repair info:" : "Korjaustiedot:",
+    "Repair warning:" : "Korjausvaroitus:",
+    "Repair error:" : "Korjausvirhe:",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Käytä komentorivipäivitintä, koska automaattinen päivitys on estetty config.php-asetustiedostossa.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Tarkistetaan taulua %s",
     "Turned on maintenance mode" : "Siirrytty huoltotilaan",
@@ -50,137 +57,6 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (ei yhteensopiva)",
     "Following apps have been disabled: %s" : "Seuraavat sovellukset on poistettu käytöstä: %s",
     "Already up to date" : "Kaikki on jo ajan tasalla",
-    "Dismiss" : "Hylkää",
-    "Connection to server lost" : "Yhteys palvelimelle katkesi",
-    "No" : "Ei",
-    "Yes" : "Kyllä",
-    "No files in here" : "Täällä ei ole tiedostoja",
-    "New folder" : "Uusi kansio",
-    "No more subfolders in here" : "Täällä ei ole enempää alikansioita",
-    "{newName} already exists" : "{newName} on jo olemassa",
-    "Choose" : "Valitse",
-    "Copy" : "Kopioi",
-    "Move" : "Siirrä",
-    "Error loading file picker template: {error}" : "Virhe ladatessa tiedostopohjia: {error}",
-    "OK" : "OK",
-    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
-    "read-only" : "vain luku",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tiedoston ristiriita","{count} tiedoston ristiriita"],
-    "One file conflict" : "Yhden tiedoston ristiriita",
-    "New Files" : "Uudet tiedostot",
-    "Already existing files" : "Jo olemassa olevat tiedostot",
-    "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
-    "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
-    "Cancel" : "Peruuta",
-    "Continue" : "Jatka",
-    "(all selected)" : "(kaikki valittu)",
-    "({count} selected)" : "({count} valittu)",
-    "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
-    "Pending" : "Odottaa",
-    "Copy to {folder}" : "Kopioi kansioon {folder}",
-    "Move to {folder}" : "Siirrä kansioon {folder}",
-    "Saving..." : "Tallennetaan...",
-    "seconds ago" : "sekunteja sitten",
-    "Settings" : "Asetukset",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
-    "Authentication required" : "Tunnistautuminen vaaditaan",
-    "This action requires you to confirm your password" : "Toiminto vaatii vahvistamista salasanallasi",
-    "Confirm" : "Vahvista",
-    "Password" : "Salasana",
-    "Failed to authenticate, try again" : "Varmennus epäonnistui, yritä uudelleen",
-    "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
-    "Search contacts …" : "Etsi yhteystietoja…",
-    "No contacts found" : "Yhteystietoja ei löytynyt",
-    "Show all contacts …" : "Näytä kaikki yhteystiedot…",
-    "Loading your contacts …" : "Ladataan yhteystietojasi…",
-    "Looking for {term} …" : "Etsii {term} …",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tiedostosi ovat salattuja. Salasanan palauttamisen jälkeen niitä ei ole mahdollista palauttaa.<br />Jos et ole varma, mitä tehdä, ole yhteydessä ylläpitäjään ennen kuin jatkat.<br />Haluatko varmasti jatkaa?",
-    "I know what I'm doing" : "Tiedän mitä teen",
-    "Password can not be changed. Please contact your administrator." : "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
-    "Reset password" : "Palauta salasana",
-    "Sending email …" : "Lähetetään sähköpostia ...",
-    "Logging in …" : "Kirjaudutaan sisään...",
-    "New in" : "Uutta versiossa",
-    "View changelog" : "Katso muutosloki",
-    "No action available" : "Toimintoa ei saatavilla",
-    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
-    "Error" : "Virhe",
-    "Error while sharing" : "Virhe jaettaessa",
-    "Error removing share" : "Virhe jakoa poistaessa",
-    "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
-    "Shared with you by {owner}" : "Jaettu kanssasi käyttäjältä {owner}",
-    "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
-    "Choose a password for the public link or press the \"Enter\" key" : "Valitse salasana julkiselle linkille tai paina \"Enter\" näppäintä",
-    "Copied!" : "Kopioitu!",
-    "Copy link" : "Kopioi linkki",
-    "Not supported!" : "Ei tuettu!",
-    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
-    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
-    "Unable to create a link share" : "Linkkijaon tekeminen ei onnistunut",
-    "Resharing is not allowed" : "Jakaminen uudelleen ei ole sallittu",
-    "Link" : "Linkki",
-    "Hide download" : "Piilota lataus",
-    "Password protection enforced" : "Salasanasuojaus pakotettu",
-    "Password protect" : "Suojaa salasanalla",
-    "Allow editing" : "Salli muokkaus",
-    "Email link to person" : "Lähetä linkki sähköpostitse",
-    "Send" : "Lähetä",
-    "Allow upload and editing" : "Salli lähetys ja muokkaus",
-    "Read only" : "Vain luku",
-    "File drop (upload only)" : "Tiedostojen pudotus (Vain lähetys)",
-    "Expiration date enforced" : "Vanhenemispäivä pakotettu",
-    "Set expiration date" : "Aseta vanhenemispäivä",
-    "Expiration" : "Vanheneminen",
-    "Expiration date" : "Vanhenemispäivä",
-    "Unshare" : "Lopeta jakaminen",
-    "Delete share link" : "Poista jakolinkki",
-    "Add another link" : "Lisää toinen linkki",
-    "Password protection for links is mandatory" : "Linkkien salasanasuojaus on pakollista",
-    "Share to {name}" : "Jaa henkilölle {name}",
-    "Share link" : "Jaa linkki",
-    "New share link" : "Uusi jakolinkki",
-    "Created on {time}" : "Luotu {time}",
-    "Could not unshare" : "Jakamisen lopettaminen epäonnistui",
-    "Choose a password for the mail share" : "Valitse salasana sähköpostijaolle",
-    "group" : "ryhmä",
-    "remote" : "etä",
-    "remote group" : "etäryhmä",
-    "email" : "sähköposti",
-    "conversation" : "keskustelu",
-    "shared by {sharer}" : "jakanut {sharer}",
-    "Can reshare" : "Voi uudelleenjakaa",
-    "Can edit" : "Voi muokata",
-    "Can create" : "Voi luoda",
-    "Can change" : "Voi vaihtaa",
-    "Can delete" : "Voi poistaa",
-    "Access control" : "Pääsynhallinta",
-    "Share details could not be loaded for this item." : "Tämän kohteen jakamistietoja ei voitu ladata.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Vähintään {count} kirjain vaaditaan automaattiseen täydentämiseen","Vähintään {count} kirjainta vaaditaan automaattiseen täydentämiseen"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Lista on ehkä vajaa - uudelleen määritä hakutermisi nähdäksesi lisää tuloksia.",
-    "No users or groups found for {search}" : "Haulla {search} ei löytynyt käyttäjiä tai ryhmiä",
-    "No users found for {search}" : "Haulla {search} ei löytynyt käyttäjiä",
-    "An error occurred (\"{message}\"). Please try again" : "Tapahtui virhe (\"{message}\"). Yritä uudestaan",
-    "An error occurred. Please try again" : "Tapahtui virhe, yritä uudelleen",
-    "Home" : "Koti",
-    "Work" : "Työ",
-    "Other" : "Muu",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Jaa",
-    "Name or email address..." : "Nimi tai sähköpostiosoite...",
-    "Name or federated cloud ID..." : "Nimi tai federoidun pilven tunniste...",
-    "Name, federated cloud ID or email address..." : "Nimi, federoidun pilven tunniste tai sähköpostiosoite...",
-    "Name..." : "Nimi...",
-    "Shared" : "Jaettu",
-    "Shared with" : "Jaettu",
-    "Shared by" : "Jaettu",
-    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
-    "restricted" : "rajoitettu",
-    "invisible" : "näkymätön",
-    "({scope})" : "({scope})",
-    "Delete" : "Poista",
-    "Rename" : "Nimeä uudelleen",
-    "Collaborative tags" : "Yhteistyölliset tunnisteet",
-    "No tags found" : "Tunnisteita ei löytynyt",
     "Very weak password" : "Erittäin heikko salasana",
     "Weak password" : "Heikko salasana",
     "So-so password" : "Kohtalainen salasana",
@@ -207,6 +83,85 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Data-hakemisto ja tiedostot ovat luultavasti käytettävissä suoraan Internetistä. .htaccess-tiedosto ei toimi oikein. Suosittelemme määrittämään HTTP-palvelimen asetukset siten, ettei data-hakemisto ole suoraan käytettävissä Internetistä tai siirtämään data-hakemiston HTTP-palvelimen juurihakemiston ulkopuolelle.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Kyseessä on mahdollinen tietoturvaan tai -suojaan liittyvä riski, joten on suositeltavaa muuttaa asetuksen arvoa.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-header \"{header}\" ei ole määritetty vastaamaan arvoa \"{expected}\". Jotkin toiminnot eivät vättämättä toimi oikein, joten on suositeltavaa muuttaa asetuksen arvoa.",
+    "Shared" : "Jaettu",
+    "Shared with" : "Jaettu",
+    "Shared by" : "Jaettu",
+    "Choose a password for the public link" : "Valitse salasana julkiselle linkille",
+    "Choose a password for the public link or press the \"Enter\" key" : "Valitse salasana julkiselle linkille tai paina \"Enter\" näppäintä",
+    "Copied!" : "Kopioitu!",
+    "Copy link" : "Kopioi linkki",
+    "Not supported!" : "Ei tuettu!",
+    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
+    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
+    "Copy" : "Kopioi",
+    "Unable to create a link share" : "Linkkijaon tekeminen ei onnistunut",
+    "Resharing is not allowed" : "Jakaminen uudelleen ei ole sallittu",
+    "Link" : "Linkki",
+    "Hide download" : "Piilota lataus",
+    "Password protection enforced" : "Salasanasuojaus pakotettu",
+    "Password protect" : "Suojaa salasanalla",
+    "Password" : "Salasana",
+    "Allow editing" : "Salli muokkaus",
+    "Email link to person" : "Lähetä linkki sähköpostitse",
+    "Send" : "Lähetä",
+    "Allow upload and editing" : "Salli lähetys ja muokkaus",
+    "Read only" : "Vain luku",
+    "File drop (upload only)" : "Tiedostojen pudotus (Vain lähetys)",
+    "Expiration date enforced" : "Vanhenemispäivä pakotettu",
+    "Set expiration date" : "Aseta vanhenemispäivä",
+    "Expiration" : "Vanheneminen",
+    "Expiration date" : "Vanhenemispäivä",
+    "Unshare" : "Lopeta jakaminen",
+    "Delete share link" : "Poista jakolinkki",
+    "Add another link" : "Lisää toinen linkki",
+    "Password protection for links is mandatory" : "Linkkien salasanasuojaus on pakollista",
+    "Share to {name}" : "Jaa henkilölle {name}",
+    "Share link" : "Jaa linkki",
+    "New share link" : "Uusi jakolinkki",
+    "Created on {time}" : "Luotu {time}",
+    "Could not unshare" : "Jakamisen lopettaminen epäonnistui",
+    "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
+    "Shared with you by {owner}" : "Jaettu kanssasi käyttäjältä {owner}",
+    "Choose a password for the mail share" : "Valitse salasana sähköpostijaolle",
+    "group" : "ryhmä",
+    "remote" : "etä",
+    "remote group" : "etäryhmä",
+    "email" : "sähköposti",
+    "conversation" : "keskustelu",
+    "shared by {sharer}" : "jakanut {sharer}",
+    "Can reshare" : "Voi uudelleenjakaa",
+    "Can edit" : "Voi muokata",
+    "Can create" : "Voi luoda",
+    "Can change" : "Voi vaihtaa",
+    "Can delete" : "Voi poistaa",
+    "Access control" : "Pääsynhallinta",
+    "Error while sharing" : "Virhe jaettaessa",
+    "Share details could not be loaded for this item." : "Tämän kohteen jakamistietoja ei voitu ladata.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Vähintään {count} kirjain vaaditaan automaattiseen täydentämiseen","Vähintään {count} kirjainta vaaditaan automaattiseen täydentämiseen"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Lista on ehkä vajaa - uudelleen määritä hakutermisi nähdäksesi lisää tuloksia.",
+    "No users or groups found for {search}" : "Haulla {search} ei löytynyt käyttäjiä tai ryhmiä",
+    "No users found for {search}" : "Haulla {search} ei löytynyt käyttäjiä",
+    "An error occurred (\"{message}\"). Please try again" : "Tapahtui virhe (\"{message}\"). Yritä uudestaan",
+    "An error occurred. Please try again" : "Tapahtui virhe, yritä uudelleen",
+    "Home" : "Koti",
+    "Work" : "Työ",
+    "Other" : "Muu",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Jaa",
+    "Name or email address..." : "Nimi tai sähköpostiosoite...",
+    "Name or federated cloud ID..." : "Nimi tai federoidun pilven tunniste...",
+    "Name, federated cloud ID or email address..." : "Nimi, federoidun pilven tunniste tai sähköpostiosoite...",
+    "Name..." : "Nimi...",
+    "Error" : "Virhe",
+    "Error removing share" : "Virhe jakoa poistaessa",
+    "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
+    "restricted" : "rajoitettu",
+    "invisible" : "näkymätön",
+    "({scope})" : "({scope})",
+    "Delete" : "Poista",
+    "Rename" : "Nimeä uudelleen",
+    "Collaborative tags" : "Yhteistyölliset tunnisteet",
+    "No tags found" : "Tunnisteita ei löytynyt",
     "unknown text" : "tuntematon teksti",
     "Hello world!" : "Hei maailma!",
     "sunny" : "aurinkoinen",
@@ -226,6 +181,76 @@ OC.L10N.register(
     "Searching other places" : "Etsitään muista paikoista",
     "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hakutulos muussa kansiossa","{count} hakutulosta muissa kansioissa"],
+    "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
+    "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
+    "An internal error occurred." : "Tapahtui sisäinen virhe.",
+    "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
+    "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
+    "Username or\temail" : "Käyttäjätunnus tai\tsähköposti",
+    "Log in" : "Kirjaudu sisään",
+    "Logging in …" : "Kirjaudutaan sisään...",
+    "Wrong username or password." : "Väärä käyttäjätunnus tai salasana.",
+    "User disabled" : "Käyttäjä poistettu käytöstä",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30:n sekunnin päästä.",
+    "Reset password" : "Palauta salasana",
+    "Password can not be changed. Please contact your administrator." : "Salasanan vaihtaminen ei onnistunut. Ota yhteys ylläpitäjään.",
+    "Back to login" : "Palaa kirjautumiseen",
+    "Forgot password?" : "Unohditko salasanasi?",
+    "Settings" : "Asetukset",
+    "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
+    "Search contacts …" : "Etsi yhteystietoja…",
+    "No contacts found" : "Yhteystietoja ei löytynyt",
+    "Show all contacts …" : "Näytä kaikki yhteystiedot…",
+    "Loading your contacts …" : "Ladataan yhteystietojasi…",
+    "Looking for {term} …" : "Etsii {term} …",
+    "No" : "Ei",
+    "Yes" : "Kyllä",
+    "No files in here" : "Täällä ei ole tiedostoja",
+    "New folder" : "Uusi kansio",
+    "No more subfolders in here" : "Täällä ei ole enempää alikansioita",
+    "Name" : "Nimi",
+    "Size" : "Koko",
+    "Modified" : "Muokattu",
+    "{newName} already exists" : "{newName} on jo olemassa",
+    "Choose" : "Valitse",
+    "Move" : "Siirrä",
+    "Error loading file picker template: {error}" : "Virhe ladatessa tiedostopohjia: {error}",
+    "OK" : "OK",
+    "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
+    "read-only" : "vain luku",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tiedoston ristiriita","{count} tiedoston ristiriita"],
+    "One file conflict" : "Yhden tiedoston ristiriita",
+    "New Files" : "Uudet tiedostot",
+    "Already existing files" : "Jo olemassa olevat tiedostot",
+    "Which files do you want to keep?" : "Mitkä tiedostot haluat säilyttää?",
+    "If you select both versions, the copied file will have a number added to its name." : "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
+    "Cancel" : "Peruuta",
+    "Continue" : "Jatka",
+    "(all selected)" : "(kaikki valittu)",
+    "({count} selected)" : "({count} valittu)",
+    "Error loading file exists template" : "Virhe ladatessa mallipohjaa",
+    "Pending" : "Odottaa",
+    "Copy to {folder}" : "Kopioi kansioon {folder}",
+    "Move to {folder}" : "Siirrä kansioon {folder}",
+    "Saving..." : "Tallennetaan...",
+    "Authentication required" : "Tunnistautuminen vaaditaan",
+    "This action requires you to confirm your password" : "Toiminto vaatii vahvistamista salasanallasi",
+    "Confirm" : "Vahvista",
+    "Failed to authenticate, try again" : "Varmennus epäonnistui, yritä uudelleen",
+    "seconds ago" : "sekunteja sitten",
+    "Connection to server lost" : "Yhteys palvelimelle katkesi",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
+    "Add to a project" : "Lisää projektiin",
+    "Show details" : "Näytä tiedot",
+    "Hide details" : "Piilota tiedot",
+    "Rename project" : "Nimeä projekti uudelleen",
+    "Failed to rename the project" : "Projektin nimeäminen uudelleen epäonnistui",
+    "Failed to create a project" : "Projektin luominen epäonnistui",
+    "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
+    "New in" : "Uutta versiossa",
+    "View changelog" : "Katso muutosloki",
+    "No action available" : "Toimintoa ei saatavilla",
+    "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
     "Personal" : "Henkilökohtainen",
     "Users" : "Käyttäjät",
     "Apps" : "Sovellukset",
@@ -280,17 +305,6 @@ OC.L10N.register(
     "Contacts menu" : "Yhteystietovalikko",
     "Settings menu" : "Asetusvalikko",
     "Confirm your password" : "Vahvista salasanasi",
-    "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
-    "Please contact your administrator." : "Ota yhteys ylläpitäjään.",
-    "An internal error occurred." : "Tapahtui sisäinen virhe.",
-    "Please try again or contact your administrator." : "Yritä uudestaan tai ota yhteys ylläpitäjään.",
-    "Username or email" : "Käyttäjätunnus tai sähköpostiosoite",
-    "Log in" : "Kirjaudu sisään",
-    "Wrong username or password." : "Väärä käyttäjätunnus tai salasana.",
-    "User disabled" : "Käyttäjä poistettu käytöstä",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Useita virheellisiä kirjautumisyrityksiä havaittiin IP-osoitteestasi. Siksi seuraava yritys sallitaan vasta 30:n sekunnin päästä.",
-    "Forgot password?" : "Unohditko salasanasi?",
-    "Back to login" : "Palaa kirjautumiseen",
     "Connect to your account" : "Yhdistä tiliisi",
     "App token" : "Sovellusvaltuutus",
     "Grant access" : "Myönnä pääsy",
@@ -303,8 +317,10 @@ OC.L10N.register(
     "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tilisi tietoturvatasoa on korotettu. Käytä kaksivaiheista tunnistautumista:",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
+    "Set up two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
     "Use backup code" : "Käytä varakoodia",
     "Cancel log in" : "Peru kirjautuminen",
+    "Setup two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
     "Error while validating your second factor" : "Tunnistuksen toisen vaiheen tarkistus epäonnistui",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ota yhteys ylläpitoon, tai jos olet tämän palvelun ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tiedostossa config/config.sample.php.",
     "App update required" : "Sovelluksen päivittäminen vaaditaan",
@@ -327,7 +343,11 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ota yhteys järjestelmän ylläpitäjään, jos tämä viesti ilmenee uudelleen tai odottamatta.",
     "Updated \"%s\" to %s" : "Päivitetty \"%s\" versioon %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Eheystarkistus tuotti ongelmia. Lisätietoja…</a>",
+    "Dismiss" : "Hylkää",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Linkki salasanan palauttamista varten on lähetetty sähköpostiisi. Jos et saa sähköpostiviestiä kohtuullisessa ajassa, tarkista roskapostikansiot.<br>Jos et saa sähköpostiviestiä, ota yhteys paikalliseen ylläpitäjään.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Tiedostosi ovat salattuja. Salasanan palauttamisen jälkeen niitä ei ole mahdollista palauttaa.<br />Jos et ole varma, mitä tehdä, ole yhteydessä ylläpitäjään ennen kuin jatkat.<br />Haluatko varmasti jatkaa?",
+    "I know what I'm doing" : "Tiedän mitä teen",
+    "Sending email …" : "Lähetetään sähköpostia ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} versiota {version} on asennettu. Vakauteen ja suorituskykyyn liittyvistä syistä suosittelemme, että {name} päivitetään uudempaan versioon.",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom ei ole PHP:n luettavissa. Tämä ei ole suositeltavaa tietoturvasyistä. Lisätietoja <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">ohjeissa</a>.",
     "Copy URL" : "Kopioi osoite",
