@@ -28,6 +28,7 @@ OC.L10N.register(
     "Reset your password" : "Endurstilltu lykilorðið þitt",
     "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
     "Couldn't send reset email. Please make sure your username is correct." : "Gat ekki sent endurstillingu í tölvupósti. Gakktu úr skugga um að notandanafn þitt sé rétt.",
+    "Some of your link shares have been removed" : "Sumir tenglar þnir  sameignir hafa verið fjarlægðir",
     "Preparing update" : "Undirbý uppfærslu",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Þrep viðgerðar:",
@@ -57,150 +58,6 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (ósamhæft)",
     "Following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
     "Already up to date" : "Allt uppfært nú þegar",
-    "Dismiss" : "Hafna",
-    "Connection to server lost" : "Tenging við miðlara rofnaði",
-    "No" : "Nei",
-    "Yes" : "Já",
-    "No files in here" : "Engar skrár hér",
-    "New folder" : "Ný mappa",
-    "No more subfolders in here" : "Engar fleiri undirmöppur hér",
-    "Name" : "Nafn",
-    "Size" : "Stærð",
-    "Modified" : "Breytt",
-    "{newName} already exists" : "{newName} er þegar til",
-    "Choose" : "Veldu",
-    "Copy" : "Afrita",
-    "Move" : "Færa",
-    "Error loading file picker template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skráaveljara: {error}",
-    "OK" : "Í lagi",
-    "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
-    "read-only" : "skrifvarið",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} árekstur skráa","{count} árekstrar skráa"],
-    "One file conflict" : "Einn árekstur skráa",
-    "New Files" : "Nýjar skrár",
-    "Already existing files" : "Skrá er nú þegar til",
-    "Which files do you want to keep?" : "Hvaða skrám vilt þú vilt halda eftir?",
-    "If you select both versions, the copied file will have a number added to its name." : "Ef þú velur báðar útgáfur, þá mun verða bætt tölustaf aftan við heiti afrituðu skrárinnar.",
-    "Cancel" : "Hætta við",
-    "Continue" : "Halda áfram",
-    "(all selected)" : "(allt valið)",
-    "({count} selected)" : "({count} valið)",
-    "Error loading file exists template" : "Villa við að hlaða inn sniðmáti fyrir skrá-er-til",
-    "Pending" : "Í bið",
-    "Copy to {folder}" : "Afrita í {folder}",
-    "Move to {folder}" : "Færa í {folder}",
-    "Saving..." : "Er að vista ...",
-    "seconds ago" : "sekúndum síðan",
-    "Settings" : "Stillingar",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndu","Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndur"],
-    "Authentication required" : "Auðkenningar krafist",
-    "This action requires you to confirm your password" : "Þessi aðgerð krefst þess að þú staðfestir lykilorðið þitt",
-    "Confirm" : "Staðfesta",
-    "Password" : "Lykilorð",
-    "Failed to authenticate, try again" : "Tókst ekki að auðkenna, prófaðu aftur",
-    "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
-    "Search contacts …" : "Leita í tengiliðum ",
-    "No contacts found" : "Engir tengiliðir fundust",
-    "Show all contacts …" : "Birta alla tengiliði ...",
-    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
-    "Looking for {term} …" : "Leita að {term} …",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt.<br />Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. <br />Viltu halda áfram?",
-    "I know what I'm doing" : "Ég veit hvað ég er að gera",
-    "Password can not be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
-    "Reset password" : "Endursetja lykilorð",
-    "Sending email …" : "Sendi tölvupóst ...",
-    "Logging in …" : "Skrái inn …",
-    "New in" : "Nýtt í",
-    "View changelog" : "Skoða breytingaannál",
-    "No action available" : "Engin aðgerð tiltæk",
-    "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
-    "Error" : "Villa",
-    "Error while sharing" : "Villa við deilingu",
-    "Error removing share" : "Villa við að fjarlægja sameign",
-    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
-    "Shared with you and {circle} by {owner}" : "Deilt með þér og {circle} af {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Deilt með þér og samtalinu {conversation} af {owner}",
-    "Shared with you in a conversation by {owner}" : "Deilt með þér í samtali af {owner}",
-    "Shared with you by {owner}" : "Deilt með þér af {owner}",
-    "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
-    "Choose a password for the public link or press the \"Enter\" key" : "Veldu þér lykilorð fyrir opinbera tengilinn eða ýttu á \"Ente\" lykilinn",
-    "Copied!" : "Afritað!",
-    "Copy link" : "Afrita tengil",
-    "Not supported!" : "Óstutt!",
-    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
-    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
-    "Unable to create a link share" : "Gat ekki búið til sameignartengil",
-    "Unable to toggle this option" : "Tekst ekki að víxla þessum valkosti af/á",
-    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
-    "Link" : "Tengill",
-    "Hide download" : "Fela niðurhal",
-    "Password protection enforced" : "Gerði verndun með lykilorði nauðsynlega",
-    "Password protect" : "Verja með lykilorði",
-    "Allow editing" : "Leyfa breytingar",
-    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
-    "Send" : "Senda",
-    "Allow upload and editing" : "Leyfa innsendingu og breytingar",
-    "Read only" : "Skrifvarið",
-    "File drop (upload only)" : "Slepping skráa (einungis innsending)",
-    "Expiration date enforced" : "Gerði gildistíma nauðsynlegan",
-    "Set expiration date" : "Setja gildistíma",
-    "Expiration" : "Rennur út",
-    "Expiration date" : "Gildir til",
-    "Note to recipient" : "Minnispunktur til viðtakanda",
-    "Unshare" : "Hætta deilingu",
-    "Delete share link" : "Eyða tengli á sameign",
-    "Add another link" : "Bæta við öðrum tengli",
-    "Password protection for links is mandatory" : "Verndun tengla með lykilorði er skylda",
-    "Share to {name}" : "Deila til {name}",
-    "Share link" : "Deila tengli",
-    "New share link" : "Nýr tengill á sameign",
-    "Created on {time}" : "Búið til {time}",
-    "Password protect by Talk" : "Verja með lykilorði í gegnum Talk",
-    "Could not unshare" : "Gat ekki hætt deilingu",
-    "Choose a password for the mail share" : "Veldu lykilorð fyrir póstsameign",
-    "group" : "hópur",
-    "remote" : "fjartengt",
-    "remote group" : "fjartengdur hópur",
-    "email" : "tölvupóstur",
-    "conversation" : "samtal",
-    "shared by {sharer}" : "deilt af {sharer}",
-    "Can reshare" : "Getur endurdeilt",
-    "Can edit" : "Getur breytt",
-    "Can create" : "Getur búið til",
-    "Can change" : "Getur skipt um",
-    "Can delete" : "Getur eytt",
-    "Access control" : "Aðgangsstýring",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} deildi með tengli",
-    "Share details could not be loaded for this item." : "Ekki tókst að hlaða inn upplýsingum um sameign varðandi þetta atriði.",
-    "Search globally" : "Leita allstaðar",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Það þarf a.m.k. {count} staf til að sjálfvirk útfylling virki","Það þarf a.m.k. {count} stafi til að sjálfvirk útfylling virki"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Þessi listi gæti verið stytt útgáfa - þrengdu leitarskilyrðin til að sjá fleiri niðurstöður.",
-    "No users or groups found for {search}" : "Engir notendur eða hópar fundust í {search}",
-    "No users found for {search}" : "Engir notendur fundust með {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Villa kom upp (\"{message}\"). Endilega reyndu aftur",
-    "An error occurred. Please try again" : "Villa kom upp. Endilega reyndu aftur",
-    "Home" : "Heima",
-    "Work" : "Vinna",
-    "Other" : "Annað",
-    "{sharee} (remote group)" : "{sharee} (fjartengdur hópur)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Deila",
-    "Name or email address..." : "Nafn eða tölvupóstfang...",
-    "Name or federated cloud ID..." : "Nafn eða skýjasambandsauðkenni (Federated Cloud ID)...",
-    "Name, federated cloud ID or email address..." : "Nafn, skýjasambandsauðkenni eða tölvupóstfang...",
-    "Name..." : "Nafn...",
-    "Shared" : "Deilt",
-    "Shared with" : "Deilt með",
-    "Shared by" : "Deilt af",
-    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
-    "restricted" : "takmarkaður aðgangur",
-    "invisible" : "ósýnilegt",
-    "({scope})" : "({scope})",
-    "Delete" : "Eyða",
-    "Rename" : "Endurnefna",
-    "Collaborative tags" : "Samstarfsmerkingar",
-    "No tags found" : "Engin merki fundust",
     "Very weak password" : "Mjög veikt lykilorð",
     "Weak password" : "Veikt lykilorð",
     "So-so password" : "Miðlungs lykilorð",
@@ -247,6 +104,94 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP-hausinn \"{header}\" er ekki stilltur á \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" eða \"{val5}\". Þetta getur lekið upplýsingum um kerfið. Skoðaðu hvað <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C mælir með ↗</a>.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP-hausinn er ekki stilltur á að minnsa kosti \"{seconds}\" sekúndur. Fyrir aukið öryggi mælum við með því að virkja HSTS eins og lýst er í <a href=\"{docUrl}\" rel=\"noreferrer noopener\">öryggisleiðbeiningum ↗ </a>.",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : " Þú ert að tengjast þessu vefsvæði með HTTP. Við mælum eindregið með að þú stillir þjóninn á að krefjast HTTPS í staðinn eins og lýst er í <a href=\"{docUrl}\">öryggisleiðbeiningunum okkar ↗</a>.",
+    "Shared" : "Deilt",
+    "Shared with" : "Deilt með",
+    "Shared by" : "Deilt af",
+    "Choose a password for the public link" : "Veldu þér lykilorð fyrir almenningstengil",
+    "Choose a password for the public link or press the \"Enter\" key" : "Veldu þér lykilorð fyrir opinbera tengilinn eða ýttu á \"Ente\" lykilinn",
+    "Copied!" : "Afritað!",
+    "Copy link" : "Afrita tengil",
+    "Not supported!" : "Óstutt!",
+    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
+    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
+    "Copy" : "Afrita",
+    "Unable to create a link share" : "Gat ekki búið til sameignartengil",
+    "Unable to toggle this option" : "Tekst ekki að víxla þessum valkosti af/á",
+    "Resharing is not allowed" : "Endurdeiling er ekki leyfð",
+    "Link" : "Tengill",
+    "Hide download" : "Fela niðurhal",
+    "Password protection enforced" : "Gerði verndun með lykilorði nauðsynlega",
+    "Password protect" : "Verja með lykilorði",
+    "Password" : "Lykilorð",
+    "Allow editing" : "Leyfa breytingar",
+    "Email link to person" : "Senda veftengil í tölvupósti til notanda",
+    "Send" : "Senda",
+    "Allow upload and editing" : "Leyfa innsendingu og breytingar",
+    "Read only" : "Skrifvarið",
+    "File drop (upload only)" : "Slepping skráa (einungis innsending)",
+    "Expiration date enforced" : "Gerði gildistíma nauðsynlegan",
+    "Set expiration date" : "Setja gildistíma",
+    "Expiration" : "Rennur út",
+    "Expiration date" : "Gildir til",
+    "Note to recipient" : "Minnispunktur til viðtakanda",
+    "Unshare" : "Hætta deilingu",
+    "Delete share link" : "Eyða tengli á sameign",
+    "Add another link" : "Bæta við öðrum tengli",
+    "Password protection for links is mandatory" : "Verndun tengla með lykilorði er skylda",
+    "Share to {name}" : "Deila til {name}",
+    "Share link" : "Deila tengli",
+    "New share link" : "Nýr tengill á sameign",
+    "Created on {time}" : "Búið til {time}",
+    "Password protect by Talk" : "Verja með lykilorði í gegnum Talk",
+    "Could not unshare" : "Gat ekki hætt deilingu",
+    "Shared with you and the group {group} by {owner}" : "Deilt með þér og hópnum {group} af {owner}",
+    "Shared with you and {circle} by {owner}" : "Deilt með þér og {circle} af {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Deilt með þér og samtalinu {conversation} af {owner}",
+    "Shared with you in a conversation by {owner}" : "Deilt með þér í samtali af {owner}",
+    "Shared with you by {owner}" : "Deilt með þér af {owner}",
+    "Choose a password for the mail share" : "Veldu lykilorð fyrir póstsameign",
+    "group" : "hópur",
+    "remote" : "fjartengt",
+    "remote group" : "fjartengdur hópur",
+    "email" : "tölvupóstur",
+    "conversation" : "samtal",
+    "shared by {sharer}" : "deilt af {sharer}",
+    "Can reshare" : "Getur endurdeilt",
+    "Can edit" : "Getur breytt",
+    "Can create" : "Getur búið til",
+    "Can change" : "Getur skipt um",
+    "Can delete" : "Getur eytt",
+    "Access control" : "Aðgangsstýring",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} deildi með tengli",
+    "Error while sharing" : "Villa við deilingu",
+    "Share details could not be loaded for this item." : "Ekki tókst að hlaða inn upplýsingum um sameign varðandi þetta atriði.",
+    "Search globally" : "Leita allstaðar",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Það þarf a.m.k. {count} staf til að sjálfvirk útfylling virki","Það þarf a.m.k. {count} stafi til að sjálfvirk útfylling virki"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Þessi listi gæti verið stytt útgáfa - þrengdu leitarskilyrðin til að sjá fleiri niðurstöður.",
+    "No users or groups found for {search}" : "Engir notendur eða hópar fundust í {search}",
+    "No users found for {search}" : "Engir notendur fundust með {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Villa kom upp (\"{message}\"). Endilega reyndu aftur",
+    "An error occurred. Please try again" : "Villa kom upp. Endilega reyndu aftur",
+    "Home" : "Heima",
+    "Work" : "Vinna",
+    "Other" : "Annað",
+    "{sharee} (remote group)" : "{sharee} (fjartengdur hópur)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Deila",
+    "Name or email address..." : "Nafn eða tölvupóstfang...",
+    "Name or federated cloud ID..." : "Nafn eða skýjasambandsauðkenni (Federated Cloud ID)...",
+    "Name, federated cloud ID or email address..." : "Nafn, skýjasambandsauðkenni eða tölvupóstfang...",
+    "Name..." : "Nafn...",
+    "Error" : "Villa",
+    "Error removing share" : "Villa við að fjarlægja sameign",
+    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
+    "restricted" : "takmarkaður aðgangur",
+    "invisible" : "ósýnilegt",
+    "({scope})" : "({scope})",
+    "Delete" : "Eyða",
+    "Rename" : "Endurnefna",
+    "Collaborative tags" : "Samstarfsmerkingar",
+    "No tags found" : "Engin merki fundust",
     "unknown text" : "óþekktur texti",
     "Hello world!" : "Halló heimur!",
     "sunny" : "sólríkt",
@@ -266,6 +211,78 @@ OC.L10N.register(
     "Searching other places" : "Leitað á öðrum stöðum",
     "No search results in other folders for {tag}{filter}{endtag}" : "Engar leitarniðurstöður í öðrum möppum fyrir {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} leitarniðurstöður í annarri möppu","{count} leitarniðurstöður í öðrum möppum"],
+    "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
+    "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
+    "An internal error occurred." : "Innri villa kom upp.",
+    "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
+    "Username or email" : "Notandanafn eða tölvupóstur",
+    "Username or\temail" : "Notandanafn eða\ttölvupóstur",
+    "Log in" : "Skrá inn",
+    "Logging in …" : "Skrái inn …",
+    "Wrong username or password." : "Rangt notandanafn eða lykilorð.",
+    "User disabled" : "Notandi óvirkur",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
+    "Reset password" : "Endursetja lykilorð",
+    "If it is not there ask your local administrator." : "Ef hann er ekki þar, spurðu þá kerfisstjórann þinn. ",
+    "Password can not be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
+    "Back to login" : "Til baka í innskráningu",
+    "Forgot password?" : "Gleymdirðu lykilorði?",
+    "Settings" : "Stillingar",
+    "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
+    "Search contacts …" : "Leita í tengiliðum ",
+    "No contacts found" : "Engir tengiliðir fundust",
+    "Show all contacts …" : "Birta alla tengiliði ...",
+    "Install the Contacts app" : "Setja upp tengiliðaforritið",
+    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
+    "Looking for {term} …" : "Leita að {term} …",
+    "No" : "Nei",
+    "Yes" : "Já",
+    "No files in here" : "Engar skrár hér",
+    "New folder" : "Ný mappa",
+    "No more subfolders in here" : "Engar fleiri undirmöppur hér",
+    "Name" : "Nafn",
+    "Size" : "Stærð",
+    "Modified" : "Breytt",
+    "{newName} already exists" : "{newName} er þegar til",
+    "Choose" : "Veldu",
+    "Move" : "Færa",
+    "Error loading file picker template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skráaveljara: {error}",
+    "OK" : "Í lagi",
+    "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
+    "read-only" : "skrifvarið",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} árekstur skráa","{count} árekstrar skráa"],
+    "One file conflict" : "Einn árekstur skráa",
+    "New Files" : "Nýjar skrár",
+    "Already existing files" : "Skrá er nú þegar til",
+    "Which files do you want to keep?" : "Hvaða skrám vilt þú vilt halda eftir?",
+    "If you select both versions, the copied file will have a number added to its name." : "Ef þú velur báðar útgáfur, þá mun verða bætt tölustaf aftan við heiti afrituðu skrárinnar.",
+    "Cancel" : "Hætta við",
+    "Continue" : "Halda áfram",
+    "(all selected)" : "(allt valið)",
+    "({count} selected)" : "({count} valið)",
+    "Error loading file exists template" : "Villa við að hlaða inn sniðmáti fyrir skrá-er-til",
+    "Pending" : "Í bið",
+    "Copy to {folder}" : "Afrita í {folder}",
+    "Move to {folder}" : "Færa í {folder}",
+    "Saving..." : "Er að vista ...",
+    "Authentication required" : "Auðkenningar krafist",
+    "This action requires you to confirm your password" : "Þessi aðgerð krefst þess að þú staðfestir lykilorðið þitt",
+    "Confirm" : "Staðfesta",
+    "Failed to authenticate, try again" : "Tókst ekki að auðkenna, prófaðu aftur",
+    "seconds ago" : "sekúndum síðan",
+    "Connection to server lost" : "Tenging við miðlara rofnaði",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndu","Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndur"],
+    "Add to a project" : "Bæta við verkefni",
+    "Show details" : "Birta nánari upplýsingar",
+    "Hide details" : "Fela nánari upplýsingar",
+    "Rename project" : "Endurnefna verkefni",
+    "Failed to rename the project" : "Mistókst að endurnefna verkefnið",
+    "Failed to create a project" : "Mistókst að útbúa verkefni",
+    "Failed to add the item to the project" : "Mistókst að bæta atriðinu í verkefnið",
+    "New in" : "Nýtt í",
+    "View changelog" : "Skoða breytingaannál",
+    "No action available" : "Engin aðgerð tiltæk",
+    "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
     "Personal" : "Einka",
     "Users" : "Notendur",
     "Apps" : "Forrit",
@@ -326,17 +343,6 @@ OC.L10N.register(
     "Contacts menu" : "Tengiliðavalmynd",
     "Settings menu" : "Stillingavalmynd",
     "Confirm your password" : "Staðfestu lykilorðið þitt",
-    "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
-    "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
-    "An internal error occurred." : "Innri villa kom upp.",
-    "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
-    "Username or email" : "Notandanafn eða tölvupóstur",
-    "Log in" : "Skrá inn",
-    "Wrong username or password." : "Rangt notandanafn eða lykilorð.",
-    "User disabled" : "Notandi óvirkur",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Við urðum vör við margar misheppnaðar innskráningar í röð frá IP-vistfanginu þínu. Þar með verður næsta innskráning tafin (throttled) um 30 sekúndur.",
-    "Forgot password?" : "Gleymdirðu lykilorði?",
-    "Back to login" : "Til baka í innskráningu",
     "Connect to your account" : "Tengdu við notandaaðganginn þinn",
     "Please log in before granting %1$s access to your %2$s account." : "Skráði þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
     "App token" : "Teikn forrits",
@@ -354,9 +360,13 @@ OC.L10N.register(
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu aukaþrep til auðkenningar:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Gat ekki hlaðið inn a.m.k. einni af virkum tveggja-þrepa auðkenningaraðferðunum þínum. Hafðu samband við kerfisstjóra.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnum þínum. Hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
+    "Set up two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tveggja-þátta auðkenningar er krafist, en er ekki búið að setja upp á aðgangnu þínum. Notaðu einn af öryggisafritunarkóðunum þínum til að skrá þig inn, eða hafðu samband við kerfisstjóra til að fá aðstoð varðandi þetta.",
     "Use backup code" : "Nota öryggisafritskóða",
     "Cancel log in" : "Hætta við innskráningu",
+    "Setup two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
+    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu hvaða auðkenningarveitu eigi að nota til auðkenningar:",
     "Error while validating your second factor" : "Villa við að sannreyna seinna þrepið",
     "Access through untrusted domain" : "Tenging frá ótreystu léni",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Hafðu samband við kerfisstjóra. Ef þú ert stjórnandi, stilltu \"trusted_domains\" setninguna í config/config.php. Dæmi um stillingar má sjá í config/config.sample.php.",
@@ -381,7 +391,11 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
     "Updated \"%s\" to %s" : "Uppfærði \"%s\" í %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Það komu upp vandamál með athugun á áreiðanleika kóða. Nánari upplýsingar…</a>",
+    "Dismiss" : "Hafna",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Skrárnar þínar eru dulritaðar. Það er engin leið til að fá gögnin þín til baka eftir lykilorðið þitt er endurstillt.<br />Ef þú ert ekki viss hvað eigi að gera, skaltu hafa samband við kerfisstjórann áður en þú heldur áfram. <br />Viltu halda áfram?",
+    "I know what I'm doing" : "Ég veit hvað ég er að gera",
+    "Sending email …" : "Sendi tölvupóst ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} eldra en útgáfa {version} er uppsett, en vegna stöðugleika og afkasta mælum við með að útgáfa {name} verði sett upp.",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom er ekki lesanlegt af PHP sem er mjög óráðlegt af öryggisástæðum. Hægt er að finna nánari upplýsingar um þetta í <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">hjálparskjölum</a> okkar.",
     "Copy URL" : "Afrita slóð",
@@ -404,6 +418,7 @@ OC.L10N.register(
     "Further information how to configure this can be found in the %sdocumentation%s." : "Frekari upplýsingar um hvernig hægt er að stilla þetta má finna í %shjálparskjölunum%s.",
     "%s will be updated to version %s" : "%s verður uppfært í útgáfu %s.",
     "This page will refresh itself when the %s instance is available again." : "Þessi síða mun uppfæra sig þegar %s er í boði á ný.",
-    "Thank you for your patience." : "Þakka þér fyrir biðlundina."
+    "Thank you for your patience." : "Þakka þér fyrir biðlundina.",
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Tengillinn til að endurstilla lykilorðið þitt hefur verið sendur á netfangið þitt. Ef þú færð ekki póstinn innan hæfilegs tíma, athugaðu þá ruslpóstmöppuna.<br>Ef hann er ekki þar, spurðu þá kerfisstjórann þinn."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
