@@ -57,70 +57,22 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nesuderinama programinė įranga)",
     "Following apps have been disabled: %s" : "Šie įskiepiai buvo išjungti: %s",
     "Already up to date" : "Naudojama naujausia versija",
-    "Dismiss" : "Atmesti",
-    "Connection to server lost" : "Ryšys su serveriu nutrūko",
-    "No" : "Ne",
-    "Yes" : "Taip",
-    "No files in here" : "Čia failų nėra",
-    "New folder" : "Naujas aplankas",
-    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
-    "Name" : "Pavadinimas",
-    "Size" : "Dydis",
-    "Modified" : "Pakeista",
-    "{newName} already exists" : "{newName} jau yra",
-    "Choose" : "Pasirinkti",
-    "Copy" : "Kopijuoti",
-    "Move" : "Perkelti",
-    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
-    "OK" : "Gerai",
-    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
-    "read-only" : "tik skaitymui",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failas konfliktuoja","{count} failai konfliktuoja","{count} nesuderinami rinkmenų pakeitimai","{count} nesuderinami rinkmenų pakeitimai"],
-    "One file conflict" : "Nesuderinamas failas",
-    "New Files" : "Nauji failai",
-    "Already existing files" : "Jau esami failai",
-    "Which files do you want to keep?" : "Kuriuos failus norite pasilikti?",
-    "If you select both versions, the copied file will have a number added to its name." : "Jei pasiliekate abi versijas, prie nukopijuoto failo pavadinimo bus pridėtas skaičius.",
-    "Cancel" : "Atsisakyti",
-    "Continue" : "Tęsti",
-    "(all selected)" : "(visi pažymėti)",
-    "({count} selected)" : "({count} pažymėtų)",
-    "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
-    "Pending" : "Vykdoma",
-    "Copy to {folder}" : "Kopijuoti į {folder}",
-    "Move to {folder}" : "Perkelti į {folder}",
-    "Saving..." : "Įrašoma...",
-    "seconds ago" : "prieš keletą sekundžių",
-    "Settings" : "Nustatymai",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių"],
-    "Authentication required" : "Reikalingas tapatybės nustatymas",
-    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
-    "Confirm" : "Patvirtinti",
-    "Password" : "Slaptažodis",
-    "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
-    "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
-    "Search contacts …" : "Ieškoti adresatų…",
-    "No contacts found" : "Adresatų nerasta",
-    "Show all contacts …" : "Rodyti visus adresatus...",
-    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
-    "Looking for {term} …" : "Ieškoma {term} ...",
-    "I know what I'm doing" : "Aš žinau ką darau",
-    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas. Susisiekite su savo administratoriumi.",
-    "Reset password" : "Atstatyti slaptažodį",
-    "Sending email …" : "Siunčiamas el. laiškas ...",
-    "Logging in …" : "Prisijungiama …",
-    "New in" : "Nauja",
-    "View changelog" : "Rodyti keitinių žurnalą",
-    "No action available" : "Jokie veiksmai negalimi",
-    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
-    "Error" : "Klaida",
-    "Error while sharing" : "Klaida bendrinant",
-    "Error removing share" : "Klaida šalinant viešinį",
-    "Shared with you and the group {group} by {owner}" : "{owner} pasidalino su jumis ir grupe {group}",
-    "Shared with you and {circle} by {owner}" : "{owner} pasidalino su jumis ir {circle}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokabliu {conversation}",
-    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
-    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
+    "Very weak password" : "Labai silpnas slaptažodis",
+    "Weak password" : "Silpnas slaptažodis",
+    "So-so password" : "Neblogas slaptažodis",
+    "Good password" : "Geras slaptažodis",
+    "Strong password" : "Stiprus slaptažodis",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
+    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Jūsų svetainės serveris nėra sukonfiguruotas atpažinti \"{url}\". Daugiau informacijos rasite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijoje</a>.",
+    "Last background job execution ran {relativeTime}. Something seems wrong." : "Paskutinis foninis užduočių vykdymas buvo paleistas {relativeTime}. Atrodo, kad kažkas nutiko.",
+    "Check the background job settings" : "Peržiūrėkite fone veikiančių užduočių nustatymus",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Kai kurie failai nepraėjo vientisumo patikrinimo. Tolimesnę informaciją apie tai, kaip išspręsti šią problemą, galima rasti <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijoje</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Neteisingų failų sąrašas…</a> / <a href=\"{rescanEndpoint}\">Peržiūrėti iš naujo…</a>)",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
+    "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
+    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
+    "Shared" : "Bendrinama",
+    "Shared with" : "Bendrinama su",
+    "Shared by" : "Bendrina",
     "Choose a password for the public link" : "Viešos nuorodos slaptažodis",
     "Choose a password for the public link or press the \"Enter\" key" : "Įrašykite slaptažodį viešai nuorodai ir spustelėkite „Enter“ klavišą",
     "Copied!" : "Nukopijuota!",
@@ -128,6 +80,7 @@ OC.L10N.register(
     "Not supported!" : "Nepalaikoma!",
     "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
     "Press Ctrl-C to copy." : "Norėdami nukopijuoti, paspauskite Ctrl-C.",
+    "Copy" : "Kopijuoti",
     "Unable to create a link share" : "Nepavyko sukurti dalinimosi nuorodos",
     "Unable to toggle this option" : "Nepavyko perjungti pasirinkimo",
     "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
@@ -135,6 +88,7 @@ OC.L10N.register(
     "Hide download" : "Slėpti atsisiuntimo galimybę",
     "Password protection enforced" : "Aktyvuota apsauga slaptažodžiu",
     "Password protect" : "Apsaugotas slaptažodžiu",
+    "Password" : "Slaptažodis",
     "Allow editing" : "Leisti redaguoti",
     "Email link to person" : "Nusiųsti nuorodą paštu",
     "Send" : "Siųsti",
@@ -156,6 +110,11 @@ OC.L10N.register(
     "Created on {time}" : "Sukurta {time}",
     "Password protect by Talk" : "„Talk“ apsauga slaptažodžiu",
     "Could not unshare" : "Nepavyko nustoti bendrinti",
+    "Shared with you and the group {group} by {owner}" : "{owner} pasidalino su jumis ir grupe {group}",
+    "Shared with you and {circle} by {owner}" : "{owner} pasidalino su jumis ir {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} pasidalino su jumis ir pokabliu {conversation}",
+    "Shared with you in a conversation by {owner}" : "{owner} pasidalino su jumis pokalbyje",
+    "Shared with you by {owner}" : "{owner} pasidalino su jumis",
     "Choose a password for the mail share" : "Pasirinkite slaptažodį pasidalinimui per elektroninį paštą",
     "group" : "grupė",
     "remote" : "nuotolinis",
@@ -170,6 +129,7 @@ OC.L10N.register(
     "Can delete" : "Galima trinti",
     "Access control" : "Prieigos valdymas",
     "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} pasidalino nuoroda",
+    "Error while sharing" : "Klaida bendrinant",
     "Share details could not be loaded for this item." : "Dalinimosi detalės negali būti atskleistos šiai bylai",
     "Search globally" : "Ieškoti visur",
     "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius","Norint pasinaudoti automatinio užpildymo paslauga, reikia suvesti bent {count} simbolius"],
@@ -188,9 +148,8 @@ OC.L10N.register(
     "Name or federated cloud ID..." : "Vardas ar federacinės debesijos ID...",
     "Name, federated cloud ID or email address..." : "Vardas, federacinės debesijos ID arba el. pašto adresas...",
     "Name..." : "Vardas...",
-    "Shared" : "Bendrinama",
-    "Shared with" : "Bendrinama su",
-    "Shared by" : "Bendrina",
+    "Error" : "Klaida",
+    "Error removing share" : "Klaida šalinant viešinį",
     "Non-existing tag #{tag}" : "Neegzistuojanti žymė #{tag}",
     "restricted" : "apribota",
     "invisible" : "nematoma",
@@ -199,17 +158,6 @@ OC.L10N.register(
     "Rename" : "Pervadinti",
     "Collaborative tags" : "Bendradarbiavimo žymės",
     "No tags found" : "Nerasta jokių žymių",
-    "Very weak password" : "Labai silpnas slaptažodis",
-    "Weak password" : "Silpnas slaptažodis",
-    "So-so password" : "Neblogas slaptažodis",
-    "Good password" : "Geras slaptažodis",
-    "Strong password" : "Stiprus slaptažodis",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
-    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Jūsų svetainės serveris nėra sukonfiguruotas atpažinti \"{url}\". Daugiau informacijos rasite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentacijoje</a>.",
-    "Last background job execution ran {relativeTime}. Something seems wrong." : "Paskutinis foninis užduočių vykdymas buvo paleistas {relativeTime}. Atrodo, kad kažkas nutiko.",
-    "Check the background job settings" : "Peržiūrėkite fone veikiančių užduočių nustatymus",
-    "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
-    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
     "unknown text" : "nežinomas tekstas",
     "Hello world!" : "Sveikas, pasauli!",
     "sunny" : "saulėta",
@@ -228,6 +176,72 @@ OC.L10N.register(
     "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Atnaujinimas buvo sėkmingas. Po %n sekundės būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundžių būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundžių būsite nukreipti į Nextcloud.","Atnaujinimas buvo sėkmingas. Po %n sekundės būsite nukreipti į Nextcloud."],
     "Searching other places" : "Ieškoma kitose vietose",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} paieškos rezultatas kitame aplanke","{count} paieškos rezultatai kitame aplanke","{count} paieškos rezultatų kitame aplanke","{count} paieškos rezultatas kitame aplanke"],
+    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
+    "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
+    "An internal error occurred." : "Įvyko vidinė klaida.",
+    "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
+    "Username or email" : "Naudotojo vardas ar el. paštas",
+    "Username or\temail" : "Naudotojo vardas ar\tel. paštas",
+    "Log in" : "Prisijungti",
+    "Logging in …" : "Prisijungiama …",
+    "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
+    "User disabled" : "Naudotojas išjungtas",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Aptikome kelis nepavykusius prisijungimus iš jūsų IP adreso. Dėl to prisijungimo dažnis yra apribotas iki 30 sekundžių.",
+    "Reset password" : "Atstatyti slaptažodį",
+    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas. Susisiekite su savo administratoriumi.",
+    "Back to login" : "Grįžti prie prisijungimo",
+    "Forgot password?" : "Pamiršote slaptažodį?",
+    "Settings" : "Nustatymai",
+    "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
+    "Search contacts …" : "Ieškoti adresatų…",
+    "No contacts found" : "Adresatų nerasta",
+    "Show all contacts …" : "Rodyti visus adresatus...",
+    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
+    "Looking for {term} …" : "Ieškoma {term} ...",
+    "No" : "Ne",
+    "Yes" : "Taip",
+    "No files in here" : "Čia failų nėra",
+    "New folder" : "Naujas aplankas",
+    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
+    "Name" : "Pavadinimas",
+    "Size" : "Dydis",
+    "Modified" : "Pakeista",
+    "{newName} already exists" : "{newName} jau yra",
+    "Choose" : "Pasirinkti",
+    "Move" : "Perkelti",
+    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
+    "OK" : "Gerai",
+    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
+    "read-only" : "tik skaitymui",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failas konfliktuoja","{count} failai konfliktuoja","{count} nesuderinami rinkmenų pakeitimai","{count} nesuderinami rinkmenų pakeitimai"],
+    "One file conflict" : "Nesuderinamas failas",
+    "New Files" : "Nauji failai",
+    "Already existing files" : "Jau esami failai",
+    "Which files do you want to keep?" : "Kuriuos failus norite pasilikti?",
+    "If you select both versions, the copied file will have a number added to its name." : "Jei pasiliekate abi versijas, prie nukopijuoto failo pavadinimo bus pridėtas skaičius.",
+    "Cancel" : "Atsisakyti",
+    "Continue" : "Tęsti",
+    "(all selected)" : "(visi pažymėti)",
+    "({count} selected)" : "({count} pažymėtų)",
+    "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
+    "Pending" : "Vykdoma",
+    "Copy to {folder}" : "Kopijuoti į {folder}",
+    "Move to {folder}" : "Perkelti į {folder}",
+    "Saving..." : "Įrašoma...",
+    "Authentication required" : "Reikalingas tapatybės nustatymas",
+    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
+    "Confirm" : "Patvirtinti",
+    "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
+    "seconds ago" : "prieš keletą sekundžių",
+    "Connection to server lost" : "Ryšys su serveriu nutrūko",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių"],
+    "Rename project" : "Pervadinti projektą",
+    "Failed to rename the project" : "Nepavyko pervadinti projekto",
+    "Failed to create a project" : "Nepavyko sukurti projekto",
+    "New in" : "Nauja",
+    "View changelog" : "Rodyti keitinių žurnalą",
+    "No action available" : "Jokie veiksmai negalimi",
+    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
     "Personal" : "Asmeniniai",
     "Users" : "Naudotojai",
     "Apps" : "Programėlės",
@@ -286,17 +300,6 @@ OC.L10N.register(
     "Contacts menu" : "Adresatų meniu",
     "Settings menu" : "Nustatymų meniu",
     "Confirm your password" : "Patvirtinkite savo slaptažodį",
-    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
-    "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
-    "An internal error occurred." : "Įvyko vidinė klaida.",
-    "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
-    "Username or email" : "Naudotojo vardas ar el. paštas",
-    "Log in" : "Prisijungti",
-    "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
-    "User disabled" : "Naudotojas išjungtas",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Aptikome kelis nepavykusius prisijungimus iš jūsų IP adreso. Dėl to prisijungimo dažnis yra apribotas iki 30 sekundžių.",
-    "Forgot password?" : "Pamiršote slaptažodį?",
-    "Back to login" : "Grįžti prie prisijungimo",
     "Connect to your account" : "Prisijunkite prie paskyros",
     "Please log in before granting %1$s access to your %2$s account." : "Prisijunkite norėdami suteikti %1$s prie jūsų %2$s paskyros.",
     "App token" : "Išorinės sistemos įskiepio kodas",
@@ -335,7 +338,10 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi jei šis pranešimas nedingsta arba jei jis pasirodė netikėtai.",
     "Updated \"%s\" to %s" : "Atnaujinta \"%s\" į %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Buvo problemų su kodo vientisumo patikrinimu. Daugiau informacijos…</a>",
+    "Dismiss" : "Atmesti",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Slaptažodžio atkūrimo nuoroda buvo išsiųsta nurodytu elektroninio pašto adresu. Jei greitu laiku negausite laiško, patikrinkite \"šlamšto\" skyrių elektroniniame pašte. <br> Jei laiško vis tiek nerandate, susiekite su sistemos administratoriumi.",
+    "I know what I'm doing" : "Aš žinau ką darau",
+    "Sending email …" : "Siunčiamas el. laiškas ...",
     "Copy URL" : "Kopijuoti URL",
     "Enable" : "Įjungti",
     "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} pasidalino per nuorodą",
