@@ -50,14 +50,133 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nesaderīgs)",
     "Following apps have been disabled: %s" : "Sekojošas programmas tika atslēgtas: %s",
     "Already up to date" : "Jau ir jaunākā",
-    "Dismiss" : "Atmest",
-    "Connection to server lost" : "Zaudēts savienojums ar serveri",
+    "Very weak password" : "Ļoti vāja parole",
+    "Weak password" : "Vāja parole",
+    "So-so password" : "Normāla parole",
+    "Good password" : "Laba parole",
+    "Strong password" : "Lieliska parole",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsu serveris nav pareizi uzstādīts lai atļautu failu sinhronizēšanu jo WebDAV interfeiss šķiet salūzis.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nešķiet pareizi uzstādīts lai veiktu sistēmas vides mainīgo vaicājumus. Tests ar getenv(\"PATH\") atgriež tikai tukšu atbildi.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Lūdzu pārbaudiet <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Instalācijas dokumentāciju </a> priekš PHP konfigurācijas piezīmēm un PHP konfigurācijai jūsu serverī, itsevisķi izmantojot php-fpm.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ir iespējots tikai lasāma konfigurācija. Tas neatļauj iestatīt un mainīt dažas konfigurācijas caur tīmekļa interfeisu. Šī datne būs manuāli jāpārveido par rakstāmu, pirms katra atjauninājuma instalēšanas.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsu datubāze neiet ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt problēmas kad vairākas darbības tiek veiktas pararēli.",
+    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Trūkst PHP modulis “fileinfo”. Mēs iesakām to aktivēt, lai pēc iespējas labāk noteiktu MIME tipus.",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Transakciju datņu slēgšana ir izslēgta, tas var radīt problēmas ar race kondīcijām. Iespējo \"filelocking.enabled\" config.php datnē, lai novērstu šīs problēmas. Skatiet <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentāciju</a>priekš papildus informācijas.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nebija iespējams paveikt cron darbu izmantojot CLI. Sekojošās tehniskās kļūdas ir uzradušās:",
+    "Last background job execution ran {relativeTime}. Something seems wrong." : "Pēdējā fona darba palaišana aizņēma {relativeTime}. Kaut kas škiet nepareizi.",
+    "Check the background job settings" : "Pārmainīt fona darbu iestatījumus",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Šim serverim nav interneta savienojuma. Tas nozīmē, ka daži līdzekļi, piemēram, ārējo atmiņas montāžas vai trešās puses lietojumprogrammu paziņojumi par atjauninājumiem nedarbosies. Attāli piekļūt datnēm un nosūtīt paziņojumu uz e-pastu, iespējams nedarbosies. Mēs ierosinām, izveidot interneta savienojumu ar šo serveri, ja vēlaties, lai visas funkcijas darbotos.",
+    "Error occurred while checking server setup" : "Radās kļūda, pārbaudot servera ",
+    "Shared" : "Koplietots",
+    "Shared with" : "Koplietots ar",
+    "Shared by" : "Koplietoja",
+    "Choose a password for the public link" : "Izvēlies paroli publiskai saitei",
+    "Choose a password for the public link or press the \"Enter\" key" : "Izvēlies paroli publiskai saitei vai nospiediet \"Enter\" taustiņu",
+    "Copied!" : "Nokopēts!",
+    "Copy link" : "Kopēt saiti",
+    "Not supported!" : "Nav atbalstīts!",
+    "Press ⌘-C to copy." : "Spiet ⌘-C lai kopētu.",
+    "Press Ctrl-C to copy." : "Spiet Ctrl-C lai kopētu.",
+    "Copy" : "Kopēt",
+    "Resharing is not allowed" : "Atkārtota dalīšanās nav atļauta",
+    "Link" : "Saite",
+    "Password protect" : "Aizsargāt ar paroli",
+    "Password" : "Parole",
+    "Allow editing" : "Atļaut rediģēt",
+    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
+    "Send" : "Sūtīt",
+    "Allow upload and editing" : "Atļaut augšupielādi un rediģēšanu",
+    "Read only" : "Tikai lasāms",
+    "File drop (upload only)" : "Datņu mešana (tikai augšupielādei)",
+    "Set expiration date" : "Iestatiet termiņa datumu",
+    "Expiration" : "Termiņš",
+    "Expiration date" : "Termiņa datums",
+    "Unshare" : "Pārtraukt koplietošanu",
+    "Share to {name}" : "Dalīties ar {name}",
+    "Share link" : "Koplietot saiti",
+    "Password protect by Talk" : "Aizsargāts ar paroli no Talk",
+    "Could not unshare" : "Nevarēja pārtraukt koplietošanu",
+    "Shared with you and the group {group} by {owner}" : "{owner} koplietoja ar jums un grupu {group}",
+    "Shared with you and {circle} by {owner}" : " {owner} koplietoja ar tevi un {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Dalīts ar tevi un sarunu {conversation} no {owner}",
+    "Shared with you by {owner}" : "{owner} koplietoja ar jums",
+    "group" : "grupa",
+    "remote" : "attālināti",
+    "email" : "e-pasts",
+    "conversation" : "saruna",
+    "shared by {sharer}" : "Koplietoja {sharer}",
+    "Can reshare" : "Var atkārtoti kopīgot",
+    "Can edit" : "Var rediģēt",
+    "Can create" : "Var izveidot",
+    "Can change" : "Var mainīt",
+    "Can delete" : "Var dzēst",
+    "Access control" : "Piekļuves vadība",
+    "Error while sharing" : "Kļūda, daloties",
+    "Share details could not be loaded for this item." : "Šim nevarēja ielādēt koplietošanas detaļas.",
+    "No users or groups found for {search}" : "Pēc  {search} netika atrasts neviens lietotājs vai grupa",
+    "No users found for {search}" : "Pēc  {search} netika atrasts neviens lietotājs",
+    "An error occurred. Please try again" : "Notika kļūda. Mēģini vēlreiz.",
+    "Other" : "Cits",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Koplietot",
+    "Name or email address..." : "Vārds vai e-pasta adrese...",
+    "Name or federated cloud ID..." : "Vārds vai federated cloud ID",
+    "Name, federated cloud ID or email address..." : "Vārds, federated cloud ID vai e-pasta adrese...",
+    "Name..." : "Vārds...",
+    "Error" : "Kļūda",
+    "Error removing share" : "Kļūda, noņemot koplietošanu",
+    "Non-existing tag #{tag}" : "Neeksistējošs tags #{tag}",
+    "restricted" : "ierobežots",
+    "invisible" : "Neredzams",
+    "({scope})" : "({scope})",
+    "Delete" : "Dzēst",
+    "Rename" : "Pārsaukt",
+    "Collaborative tags" : "Sadarbības atzīmes",
+    "No tags found" : "Netika atrasta neviena atzīme",
+    "unknown text" : "nezināms teksts",
+    "Hello world!" : "Sveika, pasaule!",
+    "sunny" : "saulains",
+    "Hello {name}, the weather is {weather}" : "Sveiks {name}, laiks ir {weather}",
+    "Hello {name}" : "Sveiks {name}",
+    "new" : "jauns",
+    "_download %n file_::_download %n files_" : ["lejupielādēt %n failus","lejupielādēt %n failus","lejupielādēt %n failus"],
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Notiek atjaunināšana, šīs lapas atstāšana var pārtraukt procesu dažās vidēs.",
+    "Update to {version}" : "Atjaunināts uz {version}",
+    "An error occurred." : "Radās kļūda.",
+    "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjauninājums nebija veiksmīgs. Plašāku informāciju skatiet <a href=\"{url}\">mūsu foruma rakstā</a> par šo problēmu.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjauninājums nebija veiksmīgs. Lūdzu ziņojiet šo ķļūdu <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienā</a>.",
+    "Continue to Nextcloud" : "Turpināt ar Nextcloud",
+    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundēm.","Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundes.","Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundēm."],
+    "Searching other places" : "Meklēt citās vietās",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Nav nekas atrasts citā mapēs {tag}{filter}{endtag}",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} meklēšanas rezultāti citās mapēs","{count} meklēšanas rezultāti citās mapēs","{count} meklēšanas rezultāti citās mapēs"],
+    "Server side authentication failed!" : "Servera autentifikācija neizdevās!",
+    "Please contact your administrator." : "Lūdzu, sazinieties ar administratoru.",
+    "An internal error occurred." : "Radās iekšēja kļūda.",
+    "Please try again or contact your administrator." : "Lūdzu, mēģiniet vēlreiz vai sazinieties ar administratoru.",
+    "Username or email" : "Lietotājvārds vai e-pasts",
+    "Log in" : "Pieteikties",
+    "Logging in …" : "Notiek pieteikšanās …",
+    "Wrong username or password." : "Nepareizs lietotājvārds vai parole.",
+    "User disabled" : "Lietotājs deaktivizēts",
+    "Reset password" : "Mainīt paroli",
+    "Password can not be changed. Please contact your administrator." : "Paroli, nevar nomainīt. Lūdzu kontaktēties ar savu administratoru.",
+    "Back to login" : "Atpakaļ uz pieteikšanos",
+    "Forgot password?" : "Aizmirsi paroli?",
+    "Settings" : "Iestatījumi",
+    "Could not load your contacts" : "Nevarēja ielādēt visas jūsu kontaktpersonas",
+    "Search contacts …" : "Meklēt kontaktpersonu",
+    "No contacts found" : "Nav atrasta ne viena kontaktpersona",
+    "Show all contacts …" : "Rādīt visas kontaktpersonas",
+    "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
+    "Looking for {term} …" : "Meklē {term} …",
     "No" : "Nē",
     "Yes" : "Jā",
     "No files in here" : "Šeit nav datņu",
     "No more subfolders in here" : "Šeit nav vairāk apakšmapju",
+    "Size" : "Izmērs",
     "Choose" : "Izvēlieties",
-    "Copy" : "Kopēt",
     "Move" : "Pārvietot",
     "Error loading file picker template: {error}" : "Kļūda ielādējot izvēlēto veidni: {error}",
     "OK" : "Labi",
@@ -78,126 +197,17 @@ OC.L10N.register(
     "Copy to {folder}" : "Kopēt uz {folder}",
     "Move to {folder}" : "Pārvietot uz {folder}",
     "Saving..." : "Saglabā...",
-    "seconds ago" : "sekundes atpakaļ",
-    "Settings" : "Iestatījumi",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm"],
     "Authentication required" : "Nepieciešama autentifikācija",
     "This action requires you to confirm your password" : "Lai veiktu šo darbību, jums jāievada sava parole.",
     "Confirm" : "Apstiprināt",
-    "Password" : "Parole",
     "Failed to authenticate, try again" : "Neizdevās autentificēt, mēģiniet vēlreiz",
-    "Could not load your contacts" : "Nevarēja ielādēt visas jūsu kontaktpersonas",
-    "Search contacts …" : "Meklēt kontaktpersonu",
-    "No contacts found" : "Nav atrasta ne viena kontaktpersona",
-    "Show all contacts …" : "Rādīt visas kontaktpersonas",
-    "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
-    "Looking for {term} …" : "Meklē {term} …",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Jūsu datnes ir šifrētas. Atiestatot paroli, jums zudīs iespēja tos atšifrēt. <br />Ja neessat pārliecināts, ko darīt, sazinieties ar savu administratoru. <br />Vai tiešām vēlaties turpināt?",
-    "I know what I'm doing" : "Es zinu ko es daru",
-    "Password can not be changed. Please contact your administrator." : "Paroli, nevar nomainīt. Lūdzu kontaktēties ar savu administratoru.",
-    "Reset password" : "Mainīt paroli",
-    "Sending email …" : "Sūta e-pastu ...",
-    "Logging in …" : "Notiek pieteikšanās …",
+    "seconds ago" : "sekundes atpakaļ",
+    "Connection to server lost" : "Zaudēts savienojums ar serveri",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm"],
+    "Hide details" : "Slēpt detaļas",
     "View changelog" : "Skatīt izmaiņu sarakstu",
     "No action available" : "Nav pieejamu darbību",
     "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
-    "Error" : "Kļūda",
-    "Error while sharing" : "Kļūda, daloties",
-    "Error removing share" : "Kļūda, noņemot koplietošanu",
-    "Shared with you and the group {group} by {owner}" : "{owner} koplietoja ar jums un grupu {group}",
-    "Shared with you and {circle} by {owner}" : " {owner} koplietoja ar tevi un {circle}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Dalīts ar tevi un sarunu {conversation} no {owner}",
-    "Shared with you by {owner}" : "{owner} koplietoja ar jums",
-    "Choose a password for the public link" : "Izvēlies paroli publiskai saitei",
-    "Choose a password for the public link or press the \"Enter\" key" : "Izvēlies paroli publiskai saitei vai nospiediet \"Enter\" taustiņu",
-    "Copied!" : "Nokopēts!",
-    "Not supported!" : "Nav atbalstīts!",
-    "Press ⌘-C to copy." : "Spiet ⌘-C lai kopētu.",
-    "Press Ctrl-C to copy." : "Spiet Ctrl-C lai kopētu.",
-    "Resharing is not allowed" : "Atkārtota dalīšanās nav atļauta",
-    "Link" : "Saite",
-    "Password protect" : "Aizsargāt ar paroli",
-    "Allow editing" : "Atļaut rediģēt",
-    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
-    "Send" : "Sūtīt",
-    "Allow upload and editing" : "Atļaut augšupielādi un rediģēšanu",
-    "Read only" : "Tikai lasāms",
-    "File drop (upload only)" : "Datņu mešana (tikai augšupielādei)",
-    "Set expiration date" : "Iestatiet termiņa datumu",
-    "Expiration" : "Termiņš",
-    "Expiration date" : "Termiņa datums",
-    "Unshare" : "Pārtraukt koplietošanu",
-    "Share to {name}" : "Dalīties ar {name}",
-    "Share link" : "Koplietot saiti",
-    "Password protect by Talk" : "Aizsargāts ar paroli no Talk",
-    "Could not unshare" : "Nevarēja pārtraukt koplietošanu",
-    "group" : "grupa",
-    "remote" : "attālināti",
-    "email" : "e-pasts",
-    "conversation" : "saruna",
-    "shared by {sharer}" : "Koplietoja {sharer}",
-    "Can reshare" : "Var atkārtoti kopīgot",
-    "Can edit" : "Var rediģēt",
-    "Can create" : "Var izveidot",
-    "Can change" : "Var mainīt",
-    "Can delete" : "Var dzēst",
-    "Access control" : "Piekļuves vadība",
-    "Share details could not be loaded for this item." : "Šim nevarēja ielādēt koplietošanas detaļas.",
-    "No users or groups found for {search}" : "Pēc  {search} netika atrasts neviens lietotājs vai grupa",
-    "No users found for {search}" : "Pēc  {search} netika atrasts neviens lietotājs",
-    "An error occurred. Please try again" : "Notika kļūda. Mēģini vēlreiz.",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Koplietot",
-    "Name or email address..." : "Vārds vai e-pasta adrese...",
-    "Name or federated cloud ID..." : "Vārds vai federated cloud ID",
-    "Name, federated cloud ID or email address..." : "Vārds, federated cloud ID vai e-pasta adrese...",
-    "Name..." : "Vārds...",
-    "Shared" : "Koplietots",
-    "Shared with" : "Koplietots ar",
-    "Shared by" : "Koplietoja",
-    "Non-existing tag #{tag}" : "Neeksistējošs tags #{tag}",
-    "restricted" : "ierobežots",
-    "invisible" : "Neredzams",
-    "({scope})" : "({scope})",
-    "Delete" : "Dzēst",
-    "Rename" : "Pārsaukt",
-    "Collaborative tags" : "Sadarbības atzīmes",
-    "No tags found" : "Netika atrasta neviena atzīme",
-    "Very weak password" : "Ļoti vāja parole",
-    "Weak password" : "Vāja parole",
-    "So-so password" : "Normāla parole",
-    "Good password" : "Laba parole",
-    "Strong password" : "Lieliska parole",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsu serveris nav pareizi uzstādīts lai atļautu failu sinhronizēšanu jo WebDAV interfeiss šķiet salūzis.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nešķiet pareizi uzstādīts lai veiktu sistēmas vides mainīgo vaicājumus. Tests ar getenv(\"PATH\") atgriež tikai tukšu atbildi.",
-    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Lūdzu pārbaudiet <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Instalācijas dokumentāciju </a> priekš PHP konfigurācijas piezīmēm un PHP konfigurācijai jūsu serverī, itsevisķi izmantojot php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ir iespējots tikai lasāma konfigurācija. Tas neatļauj iestatīt un mainīt dažas konfigurācijas caur tīmekļa interfeisu. Šī datne būs manuāli jāpārveido par rakstāmu, pirms katra atjauninājuma instalēšanas.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsu datubāze neiet ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt problēmas kad vairākas darbības tiek veiktas pararēli.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Trūkst PHP modulis “fileinfo”. Mēs iesakām to aktivēt, lai pēc iespējas labāk noteiktu MIME tipus.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Transakciju datņu slēgšana ir izslēgta, tas var radīt problēmas ar race kondīcijām. Iespējo \"filelocking.enabled\" config.php datnē, lai novērstu šīs problēmas. Skatiet <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentāciju</a>priekš papildus informācijas.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nebija iespējams paveikt cron darbu izmantojot CLI. Sekojošās tehniskās kļūdas ir uzradušās:",
-    "Last background job execution ran {relativeTime}. Something seems wrong." : "Pēdējā fona darba palaišana aizņēma {relativeTime}. Kaut kas škiet nepareizi.",
-    "Check the background job settings" : "Pārmainīt fona darbu iestatījumus",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Šim serverim nav interneta savienojuma. Tas nozīmē, ka daži līdzekļi, piemēram, ārējo atmiņas montāžas vai trešās puses lietojumprogrammu paziņojumi par atjauninājumiem nedarbosies. Attāli piekļūt datnēm un nosūtīt paziņojumu uz e-pastu, iespējams nedarbosies. Mēs ierosinām, izveidot interneta savienojumu ar šo serveri, ja vēlaties, lai visas funkcijas darbotos.",
-    "Error occurred while checking server setup" : "Radās kļūda, pārbaudot servera ",
-    "unknown text" : "nezināms teksts",
-    "Hello world!" : "Sveika, pasaule!",
-    "sunny" : "saulains",
-    "Hello {name}, the weather is {weather}" : "Sveiks {name}, laiks ir {weather}",
-    "Hello {name}" : "Sveiks {name}",
-    "new" : "jauns",
-    "_download %n file_::_download %n files_" : ["lejupielādēt %n failus","lejupielādēt %n failus","lejupielādēt %n failus"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Notiek atjaunināšana, šīs lapas atstāšana var pārtraukt procesu dažās vidēs.",
-    "Update to {version}" : "Atjaunināts uz {version}",
-    "An error occurred." : "Radās kļūda.",
-    "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjauninājums nebija veiksmīgs. Plašāku informāciju skatiet <a href=\"{url}\">mūsu foruma rakstā</a> par šo problēmu.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjauninājums nebija veiksmīgs. Lūdzu ziņojiet šo ķļūdu <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienā</a>.",
-    "Continue to Nextcloud" : "Turpināt ar Nextcloud",
-    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundēm.","Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundes.","Atjaunināšana ir bijusi veiksmīga. Novirzīsim jūs uz Nextcloud pēc %n sekundēm."],
-    "Searching other places" : "Meklēt citās vietās",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Nav nekas atrasts citā mapēs {tag}{filter}{endtag}",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} meklēšanas rezultāti citās mapēs","{count} meklēšanas rezultāti citās mapēs","{count} meklēšanas rezultāti citās mapēs"],
     "Personal" : "Personīgi",
     "Users" : "Lietotāji",
     "Apps" : "Programmas",
@@ -240,17 +250,10 @@ OC.L10N.register(
     "See the documentation" : "Skatiet dokumentāciju",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Šai programmai nepieciešams JavaScript. Lūdzu {linkstart}ieslēdziet JavasScript{linkend} un pārlādējiet lapu.",
     "More apps" : "Vairāk programmu",
+    "More" : "Vairāk",
     "Search" : "Meklēt",
     "Contacts" : "Kontakti",
     "Confirm your password" : "Apstipriniet paroli",
-    "Server side authentication failed!" : "Servera autentifikācija neizdevās!",
-    "Please contact your administrator." : "Lūdzu, sazinieties ar administratoru.",
-    "An internal error occurred." : "Radās iekšēja kļūda.",
-    "Please try again or contact your administrator." : "Lūdzu, mēģiniet vēlreiz vai sazinieties ar administratoru.",
-    "Username or email" : "Lietotājvārds vai e-pasts",
-    "Log in" : "Pieteikties",
-    "Forgot password?" : "Aizmirsi paroli?",
-    "Back to login" : "Atpakaļ uz pieteikšanos",
     "App token" : "Programmas pilnvara",
     "Grant access" : "Piešķirt pieeju",
     "New password" : "Jauna parole",
@@ -274,11 +277,16 @@ OC.L10N.register(
     "Please use the command line updater because you have a big instance with more than 50 users." : "Lūdzu, izmantojiet komandrindas atjauninātāju, jo jums ir vairāk nekā 50 lietotāji.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Es zinu ka ja es turpināšu atjauninājumu caur tīmekļa atjauninātāju ir risks ka pieprasījumam būs noliedze , kas var radīt  datu zudumu, bet man ir dublējumkopija un es zinu kā atjaunot instanci neveiksmes gadijumā.",
     "Upgrade via web on my own risk" : "Atjaunināt caur tīmekļa atjauninātāju uz mana paša risku.",
+    "Maintenance mode" : "Uzturēšanas režīms",
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s serveris pašlaik darbojas uzturēšanas režīmā, tas var ilgt kādu laiku.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Sazinieties ar sistēmas administratoru, ja šis ziņojums tiek rādīts.. vai parādījās negaidīti",
     "Updated \"%s\" to %s" : "Atjaunināts \"%s\" uz %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Programmatūras koda pārbaude atgrieza kļūdas. Sīkāk…</a>",
+    "Dismiss" : "Atmest",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Saite paroles atiestatīšanai nosūtīta uz jūsu e-pastu. Ja tuvākajā laikā to nesaņemat, pārbaudiet pastkastes mēstuļu sadaļu. <br> Ja arī tur to neatrodat, sazinieties ar savu administratoru.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Jūsu datnes ir šifrētas. Atiestatot paroli, jums zudīs iespēja tos atšifrēt. <br />Ja neessat pārliecināts, ko darīt, sazinieties ar savu administratoru. <br />Vai tiešām vēlaties turpināt?",
+    "I know what I'm doing" : "Es zinu ko es daru",
+    "Sending email …" : "Sūta e-pastu ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} zem versijas {version} ir instalēts, stabilitātes un ātruma nolūkos ir ieteicams atjaunināt {name} versiju.",
     "Enable" : "Iespējot",
     "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} koplietots ar saiti",
