@@ -5,7 +5,7 @@ OC.L10N.register(
     "File is too big" : "O ficheiro é demasiado grande",
     "The selected file is not an image." : "O ficheiro selecionado não é uma imagem.",
     "The selected file cannot be read." : "O ficheiro selecionado não pode ser lido.",
-    "Invalid file provided" : "Inválido ficheiro fornecido",
+    "Invalid file provided" : "Fornecido ficheiro inválido",
     "No image or file provided" : "Imagem ou ficheiro não fornecido",
     "Unknown filetype" : "Tipo de ficheiro desconhecido",
     "Invalid image" : "Imagem inválida",
@@ -16,17 +16,17 @@ OC.L10N.register(
     "Crop is not square" : "O recorte não é quadrado",
     "State token does not match" : "O token de estado não corresponde",
     "Password reset is disabled" : "A reposição da senha está desativada",
-    "Couldn't reset password because the token is invalid" : "Não foi possível repor a senha porque a senha é inválida",
-    "Couldn't reset password because the token is expired" : "Não foi possível repor a senha porque a senha expirou",
+    "Couldn't reset password because the token is invalid" : "Não foi possível repor a palavra-passe porque a senha é inválida",
+    "Couldn't reset password because the token is expired" : "Não foi possível repor a palavra-passe porque a senha expirou",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição porque não existe nenhum endereço de e-mail associado para este utilizador. Por favor, contacte o seu administrador.",
-    "%s password reset" : "%s reposição da senha",
+    "%s password reset" : "%s reposição de palavra-passe",
     "Password reset" : "Reposição da senha",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Clique no seguinte botão para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Clique na seguinte hiperligação para repor a sua senha. Se não solicitou a reposição da senha, ignore este e-mail.",
     "Reset your password" : "Repor a senha",
     "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar a mensagem de reposição. Por favor, contacte o seu administrador.",
     "Couldn't send reset email. Please make sure your username is correct." : "Não foi possível enviar a mensagem de reposição. Por favor, confirme se o seu nome de utilizador está correto.",
-    "Preparing update" : "A preparar atualização",
+    "Preparing update" : "A preparar a atualização",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor, utilize o atualizador de linha de comando porque a atualização automática está desativada em config.php.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: a verificar a tabela %s",
@@ -41,7 +41,7 @@ OC.L10N.register(
     "Checking for update of app \"%s\" in appstore" : "A procurar por atualizações da aplicação \"%s\" na appstore",
     "Update app \"%s\" from appstore" : "Atualizar app \"%s\" da appstore",
     "Checked for update of app \"%s\" in appstore" : "Actualização pra a aplicação \"%s\" procuradas na loja.",
-    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados para %s pode ser atualizado (isto pode demorar algum tempo dependendo do tamanho da base de dados)",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "A verificar se o esquema da base de dados para %s pode ser atualizado (isto pode demorar algum tempo, dependendo do tamanho da base de dados)",
     "Checked database schema update for apps" : "Atualização do esquema da base de dados para as aplicações verificada.",
     "Updated \"%1$s\" to %2$s" : "Atualizar \"%1$s\" para %2$s",
     "Set log level to debug" : "Definir nível de registo para depurar",
@@ -51,150 +51,11 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatível)",
     "Following apps have been disabled: %s" : "Foram desativadas as seguintes aplicações: %s",
     "Already up to date" : "Já está atualizado",
-    "Dismiss" : "Dispensar",
-    "Connection to server lost" : "Ligação perdida ao servidor",
-    "No" : "Não",
-    "Yes" : "Sim",
-    "No files in here" : "Sem ficheiros aqui",
-    "New folder" : "Nova pasta",
-    "No more subfolders in here" : "Atualmente não há sub-pastas aqui",
-    "{newName} already exists" : "{newName} já existe",
-    "Choose" : "Escolher",
-    "Copy" : "Copiar",
-    "Move" : "Mover",
-    "Error loading file picker template: {error}" : "Ocorreu um erro ao carregar o modelo de seleção de ficheiro: {error}",
-    "OK" : "Confirmar",
-    "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
-    "read-only" : "só de leitura",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiro"],
-    "One file conflict" : "Um conflito de ficheiro",
-    "New Files" : "Novos Ficheiros",
-    "Already existing files" : "Ficheiros já existentes",
-    "Which files do you want to keep?" : "Quais os ficheiros que pretende manter?",
-    "If you select both versions, the copied file will have a number added to its name." : "Se selecionar ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
-    "Cancel" : "Cancelar",
-    "Continue" : "Continuar",
-    "(all selected)" : "(todos selecionados)",
-    "({count} selected)" : "({count} selecionados)",
-    "Error loading file exists template" : "Ocorreu um erro ao carregar o ficheiro do modelo existente",
-    "Pending" : "Pendente",
-    "Copy to {folder}" : "Copiar para {folder}",
-    "Move to {folder}" : "Mover para {folder}",
-    "Saving..." : "A guardar...",
-    "seconds ago" : "segundos atrás",
-    "Settings" : "Configurações",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos"],
-    "Authentication required" : "Autenticação necessária",
-    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
-    "Confirm" : "Confirmar",
-    "Password" : "Senha",
-    "Failed to authenticate, try again" : "Falha ao autenticar. Tente outra vez.",
-    "Could not load your contacts" : "Não foi possível carregar os seus contactos",
-    "Search contacts …" : "Pesquisar contactos ...",
-    "No contacts found" : "Não foram encontrados contactos",
-    "Show all contacts …" : "Mostrar todos os contactos ...",
-    "Loading your contacts …" : "A carregar os seus contactos",
-    "Looking for {term} …" : "Procurando por {term} …",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Os seus ficheiros estão encriptados. Não haverá forma de recuperar os dados depois de alterar a senha.<br />Se não tiver a certeza do que fazer, por favor, contacte o administrador antes de continuar. <br />Deseja mesmo continuar?",
-    "I know what I'm doing" : "Eu sei o que eu estou a fazer",
-    "Password can not be changed. Please contact your administrator." : "A senha não pode ser alterada. Por favor, contacte o seu administrador.",
-    "Reset password" : "Repor senha",
-    "Sending email …" : "A enviar e-mail ...",
-    "Logging in …" : "A entrar...",
-    "New in" : "Novo em",
-    "View changelog" : "Ver Registo de alterações",
-    "No action available" : "Nenhuma acção disponível",
-    "Error fetching contact actions" : "Erro ao obter acções dos contactos",
-    "Error" : "Erro",
-    "Error while sharing" : "Erro ao partilhar",
-    "Error removing share" : "Erro ao remover partilha",
-    "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
-    "Shared with you and {circle} by {owner}" : "Partilhado consigo e com {circle} por {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Partilhado consigo e com a conversação {conversation} por {owner}",
-    "Shared with you in a conversation by {owner}" : "Partilhado consigo numa conversação por {owner}",
-    "Shared with you by {owner}" : "Partilhado consigo por {owner}",
-    "Choose a password for the public link" : "Defina a senha para a hiperligação pública",
-    "Choose a password for the public link or press the \"Enter\" key" : "Defina a senha para a hiperligação pública ou prima a tecla \"Enter\"",
-    "Copied!" : "Copiado!",
-    "Copy link" : "Copiar hiperligação",
-    "Not supported!" : "Não suportado!",
-    "Press ⌘-C to copy." : "Prima ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Prima Ctrl-C para copiar.",
-    "Unable to create a link share" : "Impossível criar a hiperligação de partilha",
-    "Unable to toggle this option" : "Impossível comutar esta opção",
-    "Resharing is not allowed" : "Não é permitido voltar a partilhar",
-    "Link" : "Hiperligação",
-    "Hide download" : "Esconder descarregar",
-    "Password protection enforced" : "Imposta protecção por palavra-passe",
-    "Password protect" : "Proteger com senha",
-    "Allow editing" : "Permitir edição",
-    "Email link to person" : "Enviar hiperligação por mensagem para a pessoa",
-    "Send" : "Enviar",
-    "Allow upload and editing" : "Permitir enviar e editar",
-    "Read only" : "Só de leitura",
-    "File drop (upload only)" : "Arrastar ficheiro (apenas envio)",
-    "Expiration date enforced" : "Imposta data de expiração",
-    "Set expiration date" : "Definir a data de expiração",
-    "Expiration" : "Expiração",
-    "Expiration date" : "Data de expiração",
-    "Note to recipient" : "Nota para o receptor",
-    "Unshare" : "Cancelar partilha",
-    "Delete share link" : "Apagar hiperligação de partilha",
-    "Add another link" : "Adicionar outra hiperligação",
-    "Password protection for links is mandatory" : "Protecção por palavra-passe é obrigatória para hiperligações",
-    "Share to {name}" : "Partilhar com {name}",
-    "Share link" : "Partilhar hiperligação",
-    "New share link" : "Nova hiperligação de partilha",
-    "Created on {time}" : "Criado em {time}",
-    "Password protect by Talk" : "Protegido por palavra-passe por Talk",
-    "Could not unshare" : "Não foi possível cancelar a partilha",
-    "Choose a password for the mail share" : "Escolher senha para a partilha de email",
-    "group" : "grupo",
-    "remote" : "remoto",
-    "remote group" : "grupo remoto",
-    "email" : "email",
-    "conversation" : "conversação",
-    "shared by {sharer}" : "partilhado por {sharer}",
-    "Can reshare" : "Pode partilhar de novo",
-    "Can edit" : "Pode editar",
-    "Can create" : "Pode criar",
-    "Can change" : "Pode alterar",
-    "Can delete" : "Pode apagar",
-    "Access control" : "Controlo de acesso",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} partilhado via hiperligação",
-    "Share details could not be loaded for this item." : "Não foi possível carregar os detalhes de partilha para este item.",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Pelo menos {count} caracteres para conclusão automática","At least {count} characters are needed for autocompletion"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista pode estar talvez truncada - por favor refine o termo de pesquisa para ver mais resultados.",
-    "No users or groups found for {search}" : "Não foram encontrados nenhuns utilizadores ou grupos para {search}",
-    "No users found for {search}" : "Não foram encontrados utilizadores para {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Ocorreu um erro (\"{message}\"). Por favor, tente de novo. ",
-    "An error occurred. Please try again" : "Ocorreu um erro. Por favor, tente de novo.",
-    "Home" : "Início",
-    "Work" : "Emprego",
-    "Other" : "Outro",
-    "{sharee} (remote group)" : "{sharee} (grupo remoto)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Partilhar",
-    "Name or email address..." : "Nome ou endereço de email...",
-    "Name or federated cloud ID..." : "Nome ou Id. da nuvem federada...",
-    "Name, federated cloud ID or email address..." : "Nome, Id. da nuvem federada ou endereço de e-mail...",
-    "Name..." : "Nome...",
-    "Shared" : "Partilhado",
-    "Shared with" : "Partilhado com ",
-    "Shared by" : "Partilhado por",
-    "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
-    "restricted" : "limitado",
-    "invisible" : "invisível",
-    "({scope})" : "({scope})",
-    "Delete" : "Apagar",
-    "Rename" : "Renomear",
-    "Collaborative tags" : "Etiquetas colaborativas",
-    "No tags found" : "Etiquetas não encontradas",
-    "Very weak password" : "Senha muito fraca",
-    "Weak password" : "Senha fraca",
-    "So-so password" : "Senha aceitável",
-    "Good password" : "Senha boa",
-    "Strong password" : "Senha forte",
+    "Very weak password" : "Palavra-passe muito fraca",
+    "Weak password" : "Palavra-passe fraca",
+    "So-so password" : "Palavra-passe aceitável",
+    "Good password" : "Palavra-passe boa",
+    "Strong password" : "Palavra-passe forte",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiros, porque a interface WebDAV parece estar com problemas.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "O seu servidor web não está configurado corretamente para resolver \"{url}\". Mais informação pode ser encontrada na nossa <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentação</a>.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "O seu servidor Web não está configurado corretamente para entregar de ficheiros .woff2. Isto é um problema típico da configuração Ngix. Para o Nextcloud 15 serão necessários ajustes de forma a também permitir a entrega de ficheiros .woff2. Compare a sua configuração Ngix com a configuração recomendada na nossa <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a>.",
@@ -233,6 +94,93 @@ OC.L10N.register(
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{header}\" não está definido como \"{expected}\". Isto é um potencial risco de segurança ou privacidade, pelo que se recomenda que ajuste esta opção em conformidade.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "O cabeçalho HTTP \"{header}\" não está definido como \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". Isto pode revelar informações do endereço de proveniência. Veja a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">Recomendação W3C</a>.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "O cabeçalho HTTP \"Strict-Transport-Security\" não está definido para, pelo menos, \"{segundos}\" segundos. Para segurança melhorada, recomenda-se que active o HSTS tal como descrito em <a href=\"{docUrl}\" rel=\"noreferrer noopener\">dicas de segurança</a>.",
+    "Shared" : "Partilhado",
+    "Shared with" : "Partilhado com ",
+    "Shared by" : "Partilhado por",
+    "Choose a password for the public link" : "Escolha a palavra-passe para a hiperligação pública",
+    "Choose a password for the public link or press the \"Enter\" key" : "Defina a senha para a hiperligação pública ou prima a tecla \"Enter\"",
+    "Copied!" : "Copiado!",
+    "Copy link" : "Copiar hiperligação",
+    "Not supported!" : "Não suportado!",
+    "Press ⌘-C to copy." : "Prima ⌘-C para copiar.",
+    "Press Ctrl-C to copy." : "Prima Ctrl-C para copiar.",
+    "Copy" : "Copiar",
+    "Unable to create a link share" : "Impossível criar a hiperligação de partilha",
+    "Unable to toggle this option" : "Impossível comutar esta opção",
+    "Resharing is not allowed" : "Não é permitido voltar a partilhar",
+    "Link" : "Hiperligação",
+    "Hide download" : "Ocultar transferência",
+    "Password protection enforced" : "Imposta protecção por palavra-passe",
+    "Password protect" : "Proteger com palavra-passe",
+    "Password" : "Palavra-passe",
+    "Allow editing" : "Permitir edição",
+    "Email link to person" : "Enviar hiperligação por mensagem para a pessoa",
+    "Send" : "Enviar",
+    "Allow upload and editing" : "Permitir enviar e editar",
+    "Read only" : "Só de leitura",
+    "File drop (upload only)" : "Arrastar ficheiro (apenas envio)",
+    "Expiration date enforced" : "Imposta data de expiração",
+    "Set expiration date" : "Definir a data de expiração",
+    "Expiration" : "Expiração",
+    "Expiration date" : "Data de expiração",
+    "Note to recipient" : "Nota para o receptor",
+    "Unshare" : "Cancelar partilha",
+    "Delete share link" : "Apagar hiperligação de partilha",
+    "Add another link" : "Adicionar outra hiperligação",
+    "Password protection for links is mandatory" : "Protecção por palavra-passe é obrigatória para hiperligações",
+    "Share to {name}" : "Partilhar com {name}",
+    "Share link" : "Partilhar hiperligação",
+    "New share link" : "Nova hiperligação de partilha",
+    "Created on {time}" : "Criado em {time}",
+    "Password protect by Talk" : "Protegido por palavra-passe por Talk",
+    "Could not unshare" : "Não foi possível cancelar a partilha",
+    "Shared with you and the group {group} by {owner}" : "Partilhado consigo e com o grupo {group} por {owner}",
+    "Shared with you and {circle} by {owner}" : "Partilhado consigo e com {circle} por {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Partilhado consigo e com a conversação {conversation} por {owner}",
+    "Shared with you in a conversation by {owner}" : "Partilhado consigo numa conversação por {owner}",
+    "Shared with you by {owner}" : "Partilhado consigo por {owner}",
+    "Choose a password for the mail share" : "Escolher senha para a partilha de email",
+    "group" : "grupo",
+    "remote" : "remoto",
+    "remote group" : "grupo remoto",
+    "email" : "email",
+    "conversation" : "conversação",
+    "shared by {sharer}" : "partilhado por {sharer}",
+    "Can reshare" : "Pode partilhar de novo",
+    "Can edit" : "Pode editar",
+    "Can create" : "Pode criar",
+    "Can change" : "Pode alterar",
+    "Can delete" : "Pode apagar",
+    "Access control" : "Controlo de acesso",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} partilhado via hiperligação",
+    "Error while sharing" : "Erro ao partilhar",
+    "Share details could not be loaded for this item." : "Não foi possível carregar os detalhes de partilha para este item.",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Pelo menos {count} caracteres para conclusão automática","At least {count} characters are needed for autocompletion"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista pode estar talvez truncada - por favor refine o termo de pesquisa para ver mais resultados.",
+    "No users or groups found for {search}" : "Não foram encontrados nenhuns utilizadores ou grupos para {search}",
+    "No users found for {search}" : "Não foram encontrados utilizadores para {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Ocorreu um erro (\"{message}\"). Por favor, tente de novo. ",
+    "An error occurred. Please try again" : "Ocorreu um erro. Por favor, tente de novo.",
+    "Home" : "Início",
+    "Work" : "Emprego",
+    "Other" : "Outro",
+    "{sharee} (remote group)" : "{sharee} (grupo remoto)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Partilhar",
+    "Name or email address..." : "Nome ou endereço de email...",
+    "Name or federated cloud ID..." : "Nome ou Id. da nuvem federada...",
+    "Name, federated cloud ID or email address..." : "Nome, Id. da nuvem federada ou endereço de e-mail...",
+    "Name..." : "Nome...",
+    "Error" : "Erro",
+    "Error removing share" : "Erro ao remover a partilha",
+    "Non-existing tag #{tag}" : "Etiqueta não existente #{tag}",
+    "restricted" : "limitado",
+    "invisible" : "invisível",
+    "({scope})" : "({scope})",
+    "Delete" : "Apagar",
+    "Rename" : "Renomear",
+    "Collaborative tags" : "Etiquetas colaborativas",
+    "No tags found" : "Etiquetas não encontradas",
     "unknown text" : "texto desconhecido",
     "Hello world!" : "Olá, mundo!",
     "sunny" : "soalheiro",
@@ -252,6 +200,64 @@ OC.L10N.register(
     "Searching other places" : "A pesquisar noutros lugares",
     "No search results in other folders for {tag}{filter}{endtag}" : "Nenhum resultado encontrado noutras pastas para {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de pesquisa noutra pasta","{count} resultados de pesquisa noutras pastas"],
+    "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
+    "Please contact your administrator." : "Por favor, contacte o seu administrador.",
+    "An internal error occurred." : "Ocorreu um erro interno.",
+    "Please try again or contact your administrator." : "Por favor, tente de novo ou contacte o seu administrador.",
+    "Username or email" : "Utilizador ou e-mail",
+    "Log in" : "Iniciar Sessão",
+    "Logging in …" : "A entrar...",
+    "User disabled" : "Utilizador desativado",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos múltiplas tentativas falhadas de login do seu IP. Por esse motivo, o seu próximo login será adiado por, até, 30 segundos. ",
+    "Reset password" : "Repor palavra-passe",
+    "Password can not be changed. Please contact your administrator." : "A palavra-passe não pode ser alterada. Por favor, contacte o seu administrador.",
+    "Back to login" : "Voltar à entrada",
+    "Forgot password?" : "Senha esquecida?",
+    "Settings" : "Definições",
+    "Could not load your contacts" : "Não foi possível carregar os seus contactos",
+    "Search contacts …" : "Pesquisar contactos ...",
+    "No contacts found" : "Não foram encontrados contactos",
+    "Show all contacts …" : "Mostrar todos os contactos ...",
+    "Loading your contacts …" : "A carregar os seus contactos",
+    "Looking for {term} …" : "Procurando por {term} …",
+    "No" : "Não",
+    "Yes" : "Sim",
+    "No files in here" : "Sem ficheiros aqui",
+    "New folder" : "Nova pasta",
+    "No more subfolders in here" : "Atualmente não há sub-pastas aqui",
+    "{newName} already exists" : "{newName} já existe",
+    "Choose" : "Escolher",
+    "Move" : "Mover",
+    "Error loading file picker template: {error}" : "Ocorreu um erro ao carregar o modelo de seleção de ficheiro: {error}",
+    "OK" : "Confirmar",
+    "Error loading message template: {error}" : "Ocorreu um erro ao carregar o modelo: {error}",
+    "read-only" : "só de leitura",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflito de ficheiro","{count} conflitos de ficheiro"],
+    "One file conflict" : "Um conflito de ficheiro",
+    "New Files" : "Novos Ficheiros",
+    "Already existing files" : "Ficheiros já existentes",
+    "Which files do you want to keep?" : "Quais os ficheiros que pretende manter?",
+    "If you select both versions, the copied file will have a number added to its name." : "Se selecionar ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
+    "Cancel" : "Cancelar",
+    "Continue" : "Continuar",
+    "(all selected)" : "(todos selecionados)",
+    "({count} selected)" : "({count} selecionados)",
+    "Error loading file exists template" : "Ocorreu um erro ao carregar o ficheiro do modelo existente",
+    "Pending" : "Pendente",
+    "Copy to {folder}" : "Copiar para {folder}",
+    "Move to {folder}" : "Mover para {folder}",
+    "Saving..." : "A guardar...",
+    "Authentication required" : "Autenticação necessária",
+    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
+    "Confirm" : "Confirmar",
+    "Failed to authenticate, try again" : "Falha ao autenticar. Tente outra vez.",
+    "seconds ago" : "segundos atrás",
+    "Connection to server lost" : "Ligação perdida ao servidor",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar dentro de %n segundos","Problema ao carregar a página. A recarregar dentro de %n segundos"],
+    "New in" : "Novo em",
+    "View changelog" : "Ver Registo de alterações",
+    "No action available" : "Nenhuma acção disponível",
+    "Error fetching contact actions" : "Erro ao obter acções dos contactos",
     "Personal" : "Pessoal",
     "Users" : "Utilizadores",
     "Apps" : "Aplicações",
@@ -283,15 +289,15 @@ OC.L10N.register(
     "Data folder" : "Pasta de dados",
     "Configure the database" : "Configure a base de dados",
     "Only %s is available." : "Só está disponível %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Instale e active módulos PHP adicionais para escolher outros tipos de base de dados.",
+    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
     "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
     "Database user" : "Utilizador da base de dados",
-    "Database password" : "Senha da base de dados",
+    "Database password" : "Palavra-passe da base de dados",
     "Database name" : "Nome da base de dados",
     "Database tablespace" : "Tablespace da base de dados",
     "Database host" : "Anfitrião da base de dados",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor, especifique o número da porta com o nome do anfitrião (por exemplo, localhost:5432).",
-    "Performance warning" : "Aviso de Desempenho",
+    "Performance warning" : "Aviso de desempenho",
     "Finish setup" : "Terminar configuração",
     "Finishing …" : "A terminar...",
     "Need help?" : "Precisa de ajuda?",
@@ -309,16 +315,6 @@ OC.L10N.register(
     "Contacts menu" : "Menu de contactos",
     "Settings menu" : "Menu de configurações",
     "Confirm your password" : "Confirmar senha",
-    "Server side authentication failed!" : "Autenticação do lado do servidor falhou!",
-    "Please contact your administrator." : "Por favor, contacte o seu administrador.",
-    "An internal error occurred." : "Ocorreu um erro interno.",
-    "Please try again or contact your administrator." : "Por favor, tente de novo ou contacte o seu administrador.",
-    "Username or email" : "Utilizador ou e-mail",
-    "Log in" : "Iniciar Sessão",
-    "User disabled" : "Utilizador desativado",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos múltiplas tentativas falhadas de login do seu IP. Por esse motivo, o seu próximo login será adiado por, até, 30 segundos. ",
-    "Forgot password?" : "Senha esquecida?",
-    "Back to login" : "Voltar à entrada",
     "Connect to your account" : "Ligar à sua conta",
     "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
     "App token" : "Token da aplicação",
@@ -326,8 +322,8 @@ OC.L10N.register(
     "Alternative log in using app token" : "Autenticação alternativa usando token da aplicação",
     "Account access" : "Acesso a conta",
     "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir a %1$s aceder à sua conta conta %2$s. ",
-    "New password" : "Nova senha",
-    "New Password" : "Nova senha",
+    "New password" : "Nova palavra-passe",
+    "New Password" : "Nova Palavra-passe",
     "This share is password-protected" : "Esta partilha é protegida por senha",
     "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
     "Two-factor authentication" : "Autenticação de dois factores",
@@ -346,7 +342,7 @@ OC.L10N.register(
     "The theme %s has been disabled." : "O tema %s foi desativado.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que foi efetuada uma cópia de segurança da base de dados, pasta de configuração e de dados antes de prosseguir.",
     "Start update" : "Iniciar atualização",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos expirados com instalações maiores, em vez disso, pode executar o seguinte comando a partir da diretoria de instalação:",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos limites com instalações maiores, pode executar o seguinte comando na diretoria de instalação:",
     "Detailed logs" : "Registos detalhados",
     "Update needed" : "É necessário atualizar",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Por favor use o actualizador da linha de comandos porque tem uma instância grande com mais de 50 utilizadores.",
@@ -359,7 +355,11 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
     "Updated \"%s\" to %s" : "Atualizado \"%s\" para %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Existiram alguns problemas com a verificação de integridade do código. Mais informação…</a>",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "A hiperligação para reiniciar a sua senha foi enviada para o seu correio eletrónico. Se não a receber dentro de um tempo aceitável, verifique as suas pastas de spam/lixo.<br> Se não a encontrar, pergunte ao seu administrador local.",
+    "Dismiss" : "Dispensar",
+    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "A hiperligação para reiniciar a sua palavra-passe foi enviada para o seu e-mail. Se não a receber dentro de um tempo aceitável, verifique as suas pastas de spam/lixo.<br> Se não a encontrar, pergunte ao seu administrador local.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Os seus ficheiros estão encriptados. Não haverá forma de recuperar os dados depois de alterar a senha.<br />Se não tiver a certeza do que fazer, por favor, contacte o administrador antes de continuar. <br />Deseja mesmo continuar?",
+    "I know what I'm doing" : "Eu sei o que eu estou a fazer",
+    "Sending email …" : "A enviar e-mail ...",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} abaixo da versão {version} está instalado. Por motivos de estabilidade e desempenho, recomendamos que atualize {name} para uma versão mais recente.",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom não é legível pelo PHP, o que é altamente desencorajado por motivos de segurança. Pode ser encontrada mais informação na <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentação</a>.",
     "Copy URL" : "Copiar URL",
@@ -372,9 +372,9 @@ OC.L10N.register(
     "The specified document has not been found on the server." : "O documento especificado não foi encontrado no servidor.",
     "You can click here to return to %s." : "Pode clicar aqui para voltar para %s.",
     "SQLite will be used as database." : "SQLite será usado como base de dados.",
-    "For larger installations we recommend to choose a different database backend." : "Para instalações maiores, nós recomendamos que escolha uma interface de base de dados diferente.",
+    "For larger installations we recommend to choose a different database backend." : "Para instalações maiores, nós recomendamos que escolha uma interface da base de dados diferente.",
     "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "O uso de SQLite é desencorajado especialmente se estiver a pensar em dar uso ao cliente desktop para sincronizar os seus ficheiros no seu computador.",
-    "Wrong password." : "Senha errada.",
+    "Wrong password." : "Palavra-passe errada.",
     "Please log in before granting %s access to your %s account." : "Por favor, autentique-se antes de permitir o acesso de %s à sua conta %s.",
     "You are about to grant %s access to your %s account." : "Está prestes a permitir a %s aceder à sua conta %s.",
     "Redirecting …" : "A redirecionar...",
