@@ -12,10 +12,10 @@ OC.L10N.register(
     "An error occurred. Please contact your admin." : "Prišlo je do napake. Stopite v stik s skrbnikom sistema.",
     "No temporary profile picture available, try again" : "Na voljo ni nobene začasne slike za profil. Poskusite znova.",
     "No crop data provided" : "Ni podanih podatkov obreza",
-    "No valid crop data provided" : "Navedeni so neveljavni podatki obrez slike",
+    "No valid crop data provided" : "Podani so neveljavni podatki za obrez slike ",
     "Crop is not square" : "Obrez ni pravokoten",
     "Could not complete login" : "Prijave ni mogoče dokončati",
-    "Password reset is disabled" : "Ponastavitev gesla je izključena",
+    "Password reset is disabled" : "Ponastavitev gesla je onemogočena",
     "Couldn't reset password because the token is invalid" : "Zaradi neustreznega žetona ni mogoče ponastaviti gesla.",
     "Couldn't reset password because the token is expired" : "Ni mogoče ponastaviti gesla, ker je žeton potekel.",
     "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev gesla, ker ni navedenega elektronskega naslova. Stopite v stik s skrbnikom sistema.",
@@ -51,63 +51,15 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (neskladno)",
     "Following apps have been disabled: %s" : "Onemogočeni so programi: %s",
     "Already up to date" : "Sistem je že posodobljen",
-    "Dismiss" : "Opusti",
-    "Connection to server lost" : "Povezava s strežnikom spodletela",
-    "No" : "Ne",
-    "Yes" : "Da",
-    "No files in here" : "Tukaj ni datotek",
-    "Name" : "Ime",
-    "Size" : "Velikost",
-    "Modified" : "Spremenjeno",
-    "{newName} already exists" : "{newName} že obstaja",
-    "Choose" : "Izbor",
-    "Copy" : "Kopiraj",
-    "Move" : "Premakni",
-    "Error loading file picker template: {error}" : "Napaka nalaganja predloge izbirnika datotek: {error}",
-    "OK" : "V redu",
-    "Error loading message template: {error}" : "Napaka nalaganja predloge sporočil: {error}",
-    "read-only" : "le za branje",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"],
-    "One file conflict" : "En spor datotek",
-    "New Files" : "Nove datoteke",
-    "Already existing files" : "Obstoječe datoteke",
-    "Which files do you want to keep?" : "Katare datoteke želite ohraniti?",
-    "If you select both versions, the copied file will have a number added to its name." : "Če izberete obe različici, bo k imenu kopirane datoteke dodana številka.",
-    "Cancel" : "Prekliči",
-    "Continue" : "Nadaljuj",
-    "(all selected)" : "(vse izbrano)",
-    "({count} selected)" : "({count} izbranih)",
-    "Error loading file exists template" : "Napaka nalaganja predloge obstoječih datotek",
-    "Pending" : "Na čakanju",
-    "Copy to {folder}" : "Kopiraj v {folder}",
-    "Move to {folder}" : "Premakni v {folder}",
-    "Saving..." : "Poteka shranjevanje ...",
-    "seconds ago" : "pred nekaj sekundami",
-    "Settings" : "Nastavitve",
-    "Authentication required" : "Opravilo zahteva overitev!",
-    "This action requires you to confirm your password" : "Opravilo zahteva potrditev z vpisom skrbniškega gesla.",
-    "Confirm" : "Potrdi",
-    "Password" : "Geslo",
-    "Failed to authenticate, try again" : "Napaka pri preverjanju prisotnosti, poskusi znova",
-    "Could not load your contacts" : "Stikov ni mogoče naložiti",
-    "Search contacts …" : "Poišči med stiki ...",
-    "No contacts found" : "Ni najdenih stikov",
-    "Show all contacts …" : "Prikaži vse stike ...",
-    "Loading your contacts …" : "Poteka nalaganje stikov ...",
-    "Looking for {term} …" : "Poteka iskanje {term} …",
-    "I know what I'm doing" : "Vem, kaj delam!",
-    "Password can not be changed. Please contact your administrator." : "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
-    "Reset password" : "Ponastavi geslo",
-    "Sending email …" : "Pošiljanje e-pošte ...",
-    "Logging in …" : "Prijava...",
-    "View changelog" : "Ogled dnevnika sprememb",
-    "No action available" : "Ni razpoložljivih dejanj",
-    "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
-    "Error" : "Napaka",
-    "Error while sharing" : "Napaka med omogočanjem souporabe",
-    "Error removing share" : "Napaka odstranjevanja souporabe",
-    "Shared with you and the group {group} by {owner}" : "{owner} omogoči souporabo z vami in s skupino {group}.",
-    "Shared with you by {owner}" : "{owner} vam omogoči souporabo",
+    "Very weak password" : "Zelo šibko geslo",
+    "Weak password" : "Šibko geslo",
+    "So-so password" : "Slabo geslo",
+    "Good password" : "Dobro geslo",
+    "Strong password" : "Odlično geslo",
+    "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
+    "Shared" : "V souporabi",
+    "Shared with" : "V skupni rabi z",
+    "Shared by" : "V souporabi od",
     "Choose a password for the public link" : "Izberite geslo za javno povezavo",
     "Choose a password for the public link or press the \"Enter\" key" : "Izberite geslo za javno povezavo ali pritisnite \"Enter\"",
     "Copied!" : "Naslov je kopiran!",
@@ -115,9 +67,11 @@ OC.L10N.register(
     "Not supported!" : "Ni podprto!",
     "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
     "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje.",
+    "Copy" : "Kopiraj",
     "Resharing is not allowed" : "Nadaljnja souporaba ni dovoljena",
     "Link" : "Povezava",
     "Password protect" : "Zaščiti z geslom",
+    "Password" : "Geslo",
     "Allow editing" : "Dovoli urejanje",
     "Email link to person" : "Posreduj povezavo po elektronski pošti",
     "Send" : "Pošlji",
@@ -133,6 +87,8 @@ OC.L10N.register(
     "Share to {name}" : "Deli z {name}",
     "Share link" : "Povezava do mape souporabe",
     "Could not unshare" : "Ni mogoče preklicati souporabe",
+    "Shared with you and the group {group} by {owner}" : "{owner} omogoči souporabo z vami in s skupino {group}.",
+    "Shared with you by {owner}" : "{owner} vam omogoči souporabo",
     "group" : "skupina",
     "remote" : "oddaljeno",
     "remote group" : "oddaljena skupina",
@@ -145,6 +101,7 @@ OC.L10N.register(
     "Can change" : "Lahko spremeni",
     "Can delete" : "Lahko izbriše",
     "Access control" : "Nadzor dostopa",
+    "Error while sharing" : "Napaka med omogočanjem souporabe",
     "Share details could not be loaded for this item." : "Podrobnosti souporabe za te predmet ni mogoče naložiti.",
     "No users or groups found for {search}" : "Ni najdenih uporabnikov ali skupin za {search}",
     "No users found for {search}" : "Ni uporabnikov, skladnih z iskalnim nizom {search}",
@@ -155,9 +112,8 @@ OC.L10N.register(
     "Name or federated cloud ID..." : "Ime ali ID oblaka...",
     "Name, federated cloud ID or email address..." : "Ime, ID oblaka ali e-poštni naslov...",
     "Name..." : "Ime ...",
-    "Shared" : "V souporabi",
-    "Shared with" : "V skupni rabi z",
-    "Shared by" : "V souporabi od",
+    "Error" : "Napaka",
+    "Error removing share" : "Napaka odstranjevanja souporabe",
     "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
     "restricted" : "omejeno",
     "invisible" : "nevidno",
@@ -166,12 +122,6 @@ OC.L10N.register(
     "Rename" : "Preimenuj",
     "Collaborative tags" : "Oznake sodelovanja",
     "No tags found" : "Ni najdenih oznak",
-    "Very weak password" : "Zelo šibko geslo",
-    "Weak password" : "Šibko geslo",
-    "So-so password" : "Slabo geslo",
-    "Good password" : "Dobro geslo",
-    "Strong password" : "Odlično geslo",
-    "Error occurred while checking server setup" : "Prišlo je do napake med preverjanjem nastavitev strežnika",
     "unknown text" : "neznano besedilo",
     "Hello world!" : "Pozdravljen svet!",
     "sunny" : "sončno",
@@ -182,12 +132,66 @@ OC.L10N.register(
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Posodobitev je v teku. Če zapustiš to stran, lahko, v določenih okoljih, prekineš proces",
     "Update to {version}" : "Posodobi na {version}",
     "An error occurred." : "Prišlo je do napake.",
-    "Please reload the page." : "Stran je treba ponovno naložiti",
+    "Please reload the page." : "Stran je treba osvežiti.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
     "Continue to Nextcloud" : "Nadaljuj na Nextcloud",
     "Searching other places" : "Poteka iskanje na drugih mestih",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} rezultat v drugih mapah","{count} rezultata v drugih mapah","{count} rezultatov v drugih mapah","{count} rezultatov v drugih mapah"],
+    "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
+    "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
+    "An internal error occurred." : "Prišlo je do notranje napake.",
+    "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
+    "Username or email" : "Uporabniško ime ali elektronski naslov",
+    "Log in" : "Prijava",
+    "Logging in …" : "Prijava...",
+    "Reset password" : "Ponastavi geslo",
+    "Password can not be changed. Please contact your administrator." : "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
+    "Forgot password?" : "Ali ste pozabili geslo?",
+    "Settings" : "Nastavitve",
+    "Could not load your contacts" : "Stikov ni mogoče naložiti",
+    "Search contacts …" : "Poišči med stiki ...",
+    "No contacts found" : "Ni najdenih stikov",
+    "Show all contacts …" : "Prikaži vse stike ...",
+    "Loading your contacts …" : "Poteka nalaganje stikov ...",
+    "Looking for {term} …" : "Poteka iskanje {term} …",
+    "No" : "Ne",
+    "Yes" : "Da",
+    "No files in here" : "Tukaj ni datotek",
+    "Name" : "Ime",
+    "Size" : "Velikost",
+    "Modified" : "Spremenjeno",
+    "{newName} already exists" : "{newName} že obstaja",
+    "Choose" : "Izbor",
+    "Move" : "Premakni",
+    "Error loading file picker template: {error}" : "Napaka nalaganja predloge izbirnika datotek: {error}",
+    "OK" : "V redu",
+    "Error loading message template: {error}" : "Napaka nalaganja predloge sporočil: {error}",
+    "read-only" : "le za branje",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"],
+    "One file conflict" : "En spor datotek",
+    "New Files" : "Nove datoteke",
+    "Already existing files" : "Obstoječe datoteke",
+    "Which files do you want to keep?" : "Katere datoteke želite ohraniti?",
+    "If you select both versions, the copied file will have a number added to its name." : "Če izberete obe različici, bo k imenu kopirane datoteke dodana številka.",
+    "Cancel" : "Prekliči",
+    "Continue" : "Nadaljuj",
+    "(all selected)" : "(vse izbrano)",
+    "({count} selected)" : "({count} izbranih)",
+    "Error loading file exists template" : "Napaka nalaganja predloge obstoječih datotek",
+    "Pending" : "Na čakanju",
+    "Copy to {folder}" : "Kopiraj v {folder}",
+    "Move to {folder}" : "Premakni v {folder}",
+    "Saving..." : "Poteka shranjevanje ...",
+    "Authentication required" : "Opravilo zahteva overitev!",
+    "This action requires you to confirm your password" : "Opravilo zahteva potrditev z vpisom skrbniškega gesla.",
+    "Confirm" : "Potrdi",
+    "Failed to authenticate, try again" : "Napaka pri preverjanju prisotnosti, poskusi znova",
+    "seconds ago" : "pred nekaj sekundami",
+    "Connection to server lost" : "Povezava s strežnikom spodletela",
+    "View changelog" : "Ogled dnevnika sprememb",
+    "No action available" : "Ni razpoložljivih dejanj",
+    "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
     "Personal" : "Osebno",
     "Users" : "Uporabniki",
     "Apps" : "Programi",
@@ -232,13 +236,6 @@ OC.L10N.register(
     "Reset search" : "Ponastavi iskanje",
     "Settings menu" : "Meni nastavitev",
     "Confirm your password" : "Potrdi svoje geslo",
-    "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
-    "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
-    "An internal error occurred." : "Prišlo je do notranje napake.",
-    "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
-    "Username or email" : "Uporabniško ime ali elektronski naslov",
-    "Log in" : "Prijava",
-    "Forgot password?" : "Ali ste pozabili geslo?",
     "App token" : "Ključ aplikacije",
     "Grant access" : "Odobri dostop",
     "New password" : "Novo geslo",
@@ -262,13 +259,16 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Stopite v stik s skrbnikom sistema, če se bo sporočilo še naprej nepričakovano prikazovalo.",
     "Updated \"%s\" to %s" : "Datoteka \"%s\" je posodobljena na %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Med preverjanjem celovitosti kode je prišlo do napak. Več podrobnosti …</a>",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Povezava za ponastavitev gesla je bila poslana na naveden elektronski naslov. V kolikor sporočila ne dobite v kratkem, preverite tudi mapo neželene pošte.<br> Če sporočila ni niti v tej mapi, stopite v stik s skrbnikom.",
+    "Dismiss" : "Opusti",
+    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Povezava za ponastavitev gesla je bila poslana na naveden elektronski naslov. V kolikor sporočila ne prejmete v kratkem, preverite tudi mapo neželene pošte.<br> Če sporočila ni niti v tej mapi, stopite v stik s skrbnikom.",
+    "I know what I'm doing" : "Vem, kaj delam!",
+    "Sending email …" : "Poteka pošiljanje elektronske pošte ...",
     "Copy URL" : "Kopiraj naslov URL",
     "Enable" : "Omogoči",
     "{sharee} (group)" : "{sharee} (skupina)",
     "{sharee} (remote)" : "{sharee} (oddaljeno)",
     "{sharee} (email)" : "{sharee} (email)",
-    "The specified document has not been found on the server." : "Določenega dokumenta na strežniku ni mogoče najti.",
+    "The specified document has not been found on the server." : "Navedenega dokumenta na strežniku ni mogoče najti.",
     "You can click here to return to %s." : "S klikom na povezavo boste vrnjeni na %s.",
     "SQLite will be used as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite",
     "For larger installations we recommend to choose a different database backend." : "Za večje namestitve je priporočljivo uporabiti drug ozadnji program zbirke podatkov.",
