@@ -59,151 +59,6 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (некомпатибилан)",
     "Following apps have been disabled: %s" : "Следеће апликације су онемогућене: %s",
     "Already up to date" : "Већ има последњу верзију",
-    ": " : ": ",
-    "Dismiss" : "Откажи",
-    "Connection to server lost" : "Изгубљена је веза са сервером",
-    "No" : "Не",
-    "Yes" : "Да",
-    "No files in here" : "Овде нема фајлова",
-    "New folder" : "Нова фасцикла",
-    "No more subfolders in here" : "Овде више нема потфасцикли",
-    "Name" : "Назив",
-    "Size" : "Величина",
-    "Modified" : "Измењен",
-    "{newName} already exists" : "{newName} већ постоји",
-    "Choose" : "Изаберите",
-    "Copy" : "Копирај",
-    "Move" : "Премести",
-    "Error loading file picker template: {error}" : "Грешка при учитавању шаблона бирача фајлова: {error}",
-    "OK" : "У реду",
-    "Error loading message template: {error}" : "Грешка при учитавању шаблона поруке: {error}",
-    "read-only" : "само-за-читање",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} сукоб фајлова","{count} сукоба фајлова","{count} сукоба фајлова"],
-    "One file conflict" : "Један сукоб фајлова",
-    "New Files" : "Нови фајлови",
-    "Already existing files" : "Постојећи фајлови",
-    "Which files do you want to keep?" : "Које фајлове желите да задржите?",
-    "If you select both versions, the copied file will have a number added to its name." : "Ако изаберете обе верзије, копираном фајлу ће бити додат број у називу.",
-    "Cancel" : "Одустани",
-    "Continue" : "Настави",
-    "(all selected)" : "(све изабрано)",
-    "({count} selected)" : "(изабрано: {count})",
-    "Error loading file exists template" : "Грешка при учитавању шаблона „Фајл постоји“",
-    "Pending" : "На чекању",
-    "Copy to {folder}" : "Копирај у {folder}",
-    "Move to {folder}" : "Премести у {folder}",
-    "Saving..." : "Чувам...",
-    "seconds ago" : "пре пар секунди",
-    "Settings" : "Поставке",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
-    "Authentication required" : "Неопходна провера идентитета",
-    "This action requires you to confirm your password" : "Ова радња захтева да потврдите лозинку",
-    "Confirm" : "Потврди",
-    "Password" : "Лозинка",
-    "Failed to authenticate, try again" : "Неуспешна провера идентитета, покушајте поново",
-    "Could not load your contacts" : "Не могу да учитам Ваше контакте",
-    "Search contacts …" : "Претражи контакте ...",
-    "No contacts found" : "Контакти нису нађени",
-    "Show all contacts …" : "Прикажи све контакте ...",
-    "Loading your contacts …" : "Учитавам контакте ...",
-    "Looking for {term} …" : "Тражим {term} …",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Послали смо Вам е-пошту за ресетовање лозинке на е-мејл адресу која је повезана са овим налогом. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора.",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваши фајлови су шифровани. Не постоји ниједан начин да се Ваши подаци поврате ако се лозинка сад ресетује.<br /> Уколико нисте сигурни шта да радите, контактирајте Вашег администратора пре него што наставите.<br /> Да ли стварно желите да наставите?",
-    "I know what I'm doing" : "Знам шта радим",
-    "Password can not be changed. Please contact your administrator." : "Лозинка се не може променити. Контактирајте администратора.",
-    "Reset password" : "Ресетуј лозинку",
-    "Sending email …" : "Слање е-поште…",
-    "Logging in …" : "Пријављивање ...",
-    "New in" : "Ново у",
-    "View changelog" : "Погледајте дневник измена",
-    "No action available" : "Нема доступне радње",
-    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
-    "Error" : "Грешка",
-    "Error while sharing" : "Грешка при дељењу",
-    "Error removing share" : "Грешка при уклањању дељења",
-    "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
-    "Shared with you and {circle} by {owner}" : "Дељемп са Вама и кругом {circle} од стране корисника {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поделио са Вама и у разговору {conversation}",
-    "Shared with you in a conversation by {owner}" : "{owner} поделио са Вама у разговору",
-    "Shared with you by {owner}" : "{owner} дели са вама",
-    "Choose a password for the public link" : "Унесите лозинку за јавну везу",
-    "Choose a password for the public link or press the \"Enter\" key" : "Унесите лозинку за јавну везу или притисните \"Ентер\"",
-    "Copied!" : "Копирано!",
-    "Copy link" : "Копирај везу",
-    "Not supported!" : "Није подржано!",
-    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
-    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
-    "Unable to create a link share" : "Не могу да направим везу дељења",
-    "Unable to toggle this option" : "Не могу да укључим/искључим ову опцију",
-    "Resharing is not allowed" : "Поновно дељење није дозвољено",
-    "Link" : "Веза",
-    "Hide download" : "Сакриј скидање",
-    "Password protection enforced" : "Захтевана заштита лозинком",
-    "Password protect" : "Заштићено лозинком",
-    "Allow editing" : "Дозволи уређивање",
-    "Email link to person" : "Пошаљи е-поштом",
-    "Send" : "Пошаљи",
-    "Allow upload and editing" : "Дозволи отпремање и уређивање",
-    "Read only" : "Само за читање",
-    "File drop (upload only)" : "Превлачење фајлова (само за отпремање)",
-    "Expiration date enforced" : "Захтевано постављање датума истека",
-    "Set expiration date" : "Постави датум истека",
-    "Expiration" : "Истиче",
-    "Expiration date" : "Датум истека",
-    "Note to recipient" : "Белешка примаоцу",
-    "Unshare" : "Укини дељење",
-    "Delete share link" : "Обриши везу дељења",
-    "Add another link" : "Додај још једну везу",
-    "Password protection for links is mandatory" : "За везе је обавезна заштита лозинком",
-    "Share to {name}" : "Подели са {name}",
-    "Share link" : "Веза дељења",
-    "New share link" : "Нова веза дељења",
-    "Created on {time}" : "Направљено {time}",
-    "Password protect by Talk" : "Заштити лозинком преко Talk-а",
-    "Could not unshare" : "Не могу да укинем дељење",
-    "Choose a password for the mail share" : "Изаберите лозинку за дељење е-поштом",
-    "group" : "група",
-    "remote" : "удаљени",
-    "remote group" : "удаљена група",
-    "email" : "е-пошта",
-    "conversation" : "разговор",
-    "shared by {sharer}" : "поделио је {sharer}",
-    "Can reshare" : "Може да дели даље",
-    "Can edit" : "Може да мења",
-    "Can create" : "Може да направи",
-    "Can change" : "Може да мења",
-    "Can delete" : "Може да брише",
-    "Access control" : "Контрола приступа",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} је поделио преко везе",
-    "Share details could not be loaded for this item." : "Не могу да учитам детаље дељења за ову ставку.",
-    "Search globally" : "Претражите глобално",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Најмање {count} слово је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Ова листа је можда скраћена - претражите опет користећи мало специфичније изразе да бисте добили још резултата.",
-    "No users or groups found for {search}" : "Није нађен ниједан корисник ни група за претрагу {search}",
-    "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Десила се грешка (\"{message}\"). Покушајте поново.",
-    "An error occurred. Please try again" : "Дошло је до грешке. Покушајте поново",
-    "Home" : "Почетна",
-    "Work" : "Посао",
-    "Other" : "Остало",
-    "{sharee} (remote group)" : "{sharee} (удаљена група)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Дели",
-    "Name or email address..." : "Име или адреса е-поште...",
-    "Name or federated cloud ID..." : "Име или ID здруженог облака...",
-    "Name, federated cloud ID or email address..." : "Име, ID здруженог облака или адреса е-поште...",
-    "Name..." : "Име...",
-    "Shared" : "Дељено",
-    "Shared with" : "Дељено са",
-    "Shared by" : "Поделио",
-    "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
-    "restricted" : "ограничен",
-    "invisible" : "невидљив",
-    "({scope})" : "({scope})",
-    "Delete" : "Обриши",
-    "Rename" : "Преименуј",
-    "Collaborative tags" : "Групне ознаке",
-    "No tags found" : "Ознаке нису нађене",
     "Very weak password" : "Веома слаба лозинка",
     "Weak password" : "Слаба лозинка",
     "So-so password" : "Осредња лозинка",
@@ -255,6 +110,94 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP заглавље \"{header}\" није постављено на \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Овиме могу процурети информације о рефералу. Погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C препоруке↗</a>",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "\"Strict-Transport-Security\" HTTP заглавље није подешено да буде бар \"{seconds}\" секунди. За додатну сигурност, предлаже се да омогућите HSTS као што је описано у <a href=\"{docUrl}\" rel=\"noreferrer noopener\">сигурносним саветима↗</a>.",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Приступање сајту преко HTTP-а. Препоручује се да подесите Ваш сервер да захтева HTTPS као што је описано у <a href=\"{docUrl}\">безбедоносним саветима↗</a>",
+    "Shared" : "Дељено",
+    "Shared with" : "Дељено са",
+    "Shared by" : "Поделио",
+    "Choose a password for the public link" : "Унесите лозинку за јавну везу",
+    "Choose a password for the public link or press the \"Enter\" key" : "Унесите лозинку за јавну везу или притисните \"Ентер\"",
+    "Copied!" : "Копирано!",
+    "Copy link" : "Копирај везу",
+    "Not supported!" : "Није подржано!",
+    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
+    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
+    "Copy" : "Копирај",
+    "Unable to create a link share" : "Не могу да направим везу дељења",
+    "Unable to toggle this option" : "Не могу да укључим/искључим ову опцију",
+    "Resharing is not allowed" : "Поновно дељење није дозвољено",
+    "Link" : "Веза",
+    "Hide download" : "Сакриј скидање",
+    "Password protection enforced" : "Захтевана заштита лозинком",
+    "Password protect" : "Заштићено лозинком",
+    "Password" : "Лозинка",
+    "Allow editing" : "Дозволи уређивање",
+    "Email link to person" : "Пошаљи е-поштом",
+    "Send" : "Пошаљи",
+    "Allow upload and editing" : "Дозволи отпремање и уређивање",
+    "Read only" : "Само за читање",
+    "File drop (upload only)" : "Превлачење фајлова (само за отпремање)",
+    "Expiration date enforced" : "Захтевано постављање датума истека",
+    "Set expiration date" : "Постави датум истека",
+    "Expiration" : "Истиче",
+    "Expiration date" : "Датум истека",
+    "Note to recipient" : "Белешка примаоцу",
+    "Unshare" : "Укини дељење",
+    "Delete share link" : "Обриши везу дељења",
+    "Add another link" : "Додај још једну везу",
+    "Password protection for links is mandatory" : "За везе је обавезна заштита лозинком",
+    "Share to {name}" : "Подели са {name}",
+    "Share link" : "Веза дељења",
+    "New share link" : "Нова веза дељења",
+    "Created on {time}" : "Направљено {time}",
+    "Password protect by Talk" : "Заштити лозинком преко Talk-а",
+    "Could not unshare" : "Не могу да укинем дељење",
+    "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
+    "Shared with you and {circle} by {owner}" : "Дељемп са Вама и кругом {circle} од стране корисника {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} поделио са Вама и у разговору {conversation}",
+    "Shared with you in a conversation by {owner}" : "{owner} поделио са Вама у разговору",
+    "Shared with you by {owner}" : "{owner} дели са вама",
+    "Choose a password for the mail share" : "Изаберите лозинку за дељење е-поштом",
+    "group" : "група",
+    "remote" : "удаљени",
+    "remote group" : "удаљена група",
+    "email" : "е-пошта",
+    "conversation" : "разговор",
+    "shared by {sharer}" : "поделио је {sharer}",
+    "Can reshare" : "Може да дели даље",
+    "Can edit" : "Може да мења",
+    "Can create" : "Може да направи",
+    "Can change" : "Може да мења",
+    "Can delete" : "Може да брише",
+    "Access control" : "Контрола приступа",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} је поделио преко везе",
+    "Error while sharing" : "Грешка при дељењу",
+    "Share details could not be loaded for this item." : "Не могу да учитам детаље дељења за ову ставку.",
+    "Search globally" : "Претражите глобално",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Најмање {count} слово је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање","Најмање {count} слова је потребно за аутокомплетирање"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Ова листа је можда скраћена - претражите опет користећи мало специфичније изразе да бисте добили још резултата.",
+    "No users or groups found for {search}" : "Није нађен ниједан корисник ни група за претрагу {search}",
+    "No users found for {search}" : "Није нађен ниједан корисник за претрагу {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Десила се грешка (\"{message}\"). Покушајте поново.",
+    "An error occurred. Please try again" : "Дошло је до грешке. Покушајте поново",
+    "Home" : "Почетна",
+    "Work" : "Посао",
+    "Other" : "Остало",
+    "{sharee} (remote group)" : "{sharee} (удаљена група)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Дели",
+    "Name or email address..." : "Име или адреса е-поште...",
+    "Name or federated cloud ID..." : "Име или ID здруженог облака...",
+    "Name, federated cloud ID or email address..." : "Име, ID здруженог облака или адреса е-поште...",
+    "Name..." : "Име...",
+    "Error" : "Грешка",
+    "Error removing share" : "Грешка при уклањању дељења",
+    "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
+    "restricted" : "ограничен",
+    "invisible" : "невидљив",
+    "({scope})" : "({scope})",
+    "Delete" : "Обриши",
+    "Rename" : "Преименуј",
+    "Collaborative tags" : "Групне ознаке",
+    "No tags found" : "Ознаке нису нађене",
     "unknown text" : "непознат текст",
     "Hello world!" : "Здраво свете!",
     "sunny" : "сунчано",
@@ -274,6 +217,79 @@ OC.L10N.register(
     "Searching other places" : "Претражујем остала места",
     "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултата претраге у осталим фасциклама за {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} резултат претраге у осталим фасциклама","{count} резултата претраге у осталим фасциклама","{count} резултата претраге у осталим фасциклама"],
+    "Server side authentication failed!" : "Потврда идентитета на серверу није успела!",
+    "Please contact your administrator." : "Контактирајте вашег администратора.",
+    "An internal error occurred." : "Догодила се унутрашња грешка. ",
+    "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
+    "Username or email" : "Корисничко име или адреса е-поште",
+    "Username or\temail" : "Корисничко име или\tадреса е-поште",
+    "Log in" : "Пријава",
+    "Logging in …" : "Пријављивање ...",
+    "Wrong username or password." : "Погрешно корисничко име или лозинка",
+    "User disabled" : "Корисник онемогућен",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
+    "Reset password" : "Ресетуј лозинку",
+    "If it is not there ask your local administrator." : "Ако није ни тамо, контактирајте вашег администратора.",
+    "Password can not be changed. Please contact your administrator." : "Лозинка се не може променити. Контактирајте администратора.",
+    "Back to login" : "Назад на пријаву",
+    "Forgot password?" : "Заборавили сте лозинку?",
+    "Settings" : "Поставке",
+    "Could not load your contacts" : "Не могу да учитам Ваше контакте",
+    "Search contacts …" : "Претражи контакте ...",
+    "No contacts found" : "Контакти нису нађени",
+    "Show all contacts …" : "Прикажи све контакте ...",
+    "Loading your contacts …" : "Учитавам контакте ...",
+    "Looking for {term} …" : "Тражим {term} …",
+    "No" : "Не",
+    "Yes" : "Да",
+    "No files in here" : "Овде нема фајлова",
+    "New folder" : "Нова фасцикла",
+    "No more subfolders in here" : "Овде више нема потфасцикли",
+    "Name" : "Назив",
+    "Size" : "Величина",
+    "Modified" : "Измењен",
+    "{newName} already exists" : "{newName} већ постоји",
+    "Choose" : "Изаберите",
+    "Move" : "Премести",
+    "Error loading file picker template: {error}" : "Грешка при учитавању шаблона бирача фајлова: {error}",
+    "OK" : "У реду",
+    "Error loading message template: {error}" : "Грешка при учитавању шаблона поруке: {error}",
+    "read-only" : "само-за-читање",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} сукоб фајлова","{count} сукоба фајлова","{count} сукоба фајлова"],
+    "One file conflict" : "Један сукоб фајлова",
+    "New Files" : "Нови фајлови",
+    "Already existing files" : "Постојећи фајлови",
+    "Which files do you want to keep?" : "Које фајлове желите да задржите?",
+    "If you select both versions, the copied file will have a number added to its name." : "Ако изаберете обе верзије, копираном фајлу ће бити додат број у називу.",
+    "Cancel" : "Одустани",
+    "Continue" : "Настави",
+    "(all selected)" : "(све изабрано)",
+    "({count} selected)" : "(изабрано: {count})",
+    "Error loading file exists template" : "Грешка при учитавању шаблона „Фајл постоји“",
+    "Pending" : "На чекању",
+    "Copy to {folder}" : "Копирај у {folder}",
+    "Move to {folder}" : "Премести у {folder}",
+    "Saving..." : "Чувам...",
+    "Authentication required" : "Неопходна провера идентитета",
+    "This action requires you to confirm your password" : "Ова радња захтева да потврдите лозинку",
+    "Confirm" : "Потврди",
+    "Failed to authenticate, try again" : "Неуспешна провера идентитета, покушајте поново",
+    "seconds ago" : "пре пар секунди",
+    "Connection to server lost" : "Изгубљена је веза са сервером",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
+    "Add to a project" : "Додај у пројекат",
+    "Show details" : "Прикажи детаље",
+    "Hide details" : "Сакриј детаље",
+    "Rename project" : "Преименуј пројекат",
+    "Failed to rename the project" : "Грешка при преименовању пројекат",
+    "Failed to create a project" : "Грешка при креирању пројекта",
+    "Failed to add the item to the project" : "Грешка приликом додавања ставке у пројекат",
+    "Connect items to a project to make them easier to find" : "Повежите ставке у пројекат да Вам буде лакше да их нађете",
+    "Type to search for existing projects" : "Крените да куцате да тражите постојеће пројекте",
+    "New in" : "Ново у",
+    "View changelog" : "Погледајте дневник измена",
+    "No action available" : "Нема доступне радње",
+    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
     "Personal" : "Лично",
     "Users" : "Корисници",
     "Apps" : "Апликације",
@@ -336,17 +352,6 @@ OC.L10N.register(
     "Contacts menu" : "Мени контаката",
     "Settings menu" : "Мени подешавања",
     "Confirm your password" : "Потврдите лозинку",
-    "Server side authentication failed!" : "Потврда идентитета на серверу није успела!",
-    "Please contact your administrator." : "Контактирајте вашег администратора.",
-    "An internal error occurred." : "Догодила се унутрашња грешка. ",
-    "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
-    "Username or email" : "Корисничко име или адреса е-поште",
-    "Log in" : "Пријава",
-    "Wrong username or password." : "Погрешно корисничко име или лозинка",
-    "User disabled" : "Корисник онемогућен",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
-    "Forgot password?" : "Заборавили сте лозинку?",
-    "Back to login" : "Назад на пријаву",
     "Connect to your account" : "Повежите се на Ваш налог",
     "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
     "App token" : "Апликативни жетон",
@@ -364,9 +369,13 @@ OC.L10N.register(
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повећана сигурност је омогућена за овај налог. Одаберите други фактор за проверу идентитета:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Није могуће учитати ниједан метод двофакторске провере идентитета. Контактирајте администратора.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора за помоћ.",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора да подеси двофакторску проверу идентитета.",
+    "Set up two-factor authentication" : "Подеси двофакторску проверу идентитета",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Или употребите Ваше резервне кôдове, или контактирајте администратора за помоћ.",
     "Use backup code" : "Користите резервни кôд",
     "Cancel log in" : "Поништите пријаву",
+    "Setup two-factor authentication" : "Подеси двофакторску проверу идентитета",
+    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Повећана сигурност је захтевана за овај налог. Одаберите провајдера којег желите да подесите:",
     "Error while validating your second factor" : "Грешка при провери Вашег другог фактора",
     "Access through untrusted domain" : "Приступ кроз небезбедни домен",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php као у примеру config.sample.php.",
@@ -391,7 +400,11 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
     "Updated \"%s\" to %s" : "„%s“ ажуриран на %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Догодила се грешка приликом провере интегритета кода. Више информација...</a>",
+    "Dismiss" : "Откажи",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Веза за ресетовање лозинке је послата на вашу е-пошту. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваши фајлови су шифровани. Не постоји ниједан начин да се Ваши подаци поврате ако се лозинка сад ресетује.<br /> Уколико нисте сигурни шта да радите, контактирајте Вашег администратора пре него што наставите.<br /> Да ли стварно желите да наставите?",
+    "I know what I'm doing" : "Знам шта радим",
+    "Sending email …" : "Слање е-поште…",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} испод верзије {version} је инсталиран. Због стабилности и перформанси, препоручује се ажурирање на новију, {name} верзију.",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP не може да чита /dev/urandom. Ово се баш не препоручује из сигурносних разлога. Можете наћи више информација у <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">документацији</a>.",
     "Copy URL" : "Копирај URL",
@@ -414,6 +427,7 @@ OC.L10N.register(
     "Further information how to configure this can be found in the %sdocumentation%s." : "Више информација о томе како ово подесити можете да нађете у %s документацији%s.",
     "%s will be updated to version %s" : "%s ће бити ажурирана на верзију %s",
     "This page will refresh itself when the %s instance is available again." : "Ова страница ће се сама освежити када %s постане поново доступан.",
-    "Thank you for your patience." : "Хвала Вам на стрпљењу."
+    "Thank you for your patience." : "Хвала Вам на стрпљењу.",
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Послали смо Вам е-пошту за ресетовање лозинке на е-мејл адресу која је повезана са овим налогом. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
