@@ -59,151 +59,6 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (inkompatibel)",
     "Following apps have been disabled: %s" : "Följande appar har inaktiverats: %s",
     "Already up to date" : "Redan uppdaterad",
-    ": " : ": ",
-    "Dismiss" : "Avfärda",
-    "Connection to server lost" : "Anslutning till server förlorad",
-    "No" : "Nej",
-    "Yes" : "Ja",
-    "No files in here" : "Det finns inga filer här",
-    "New folder" : "Ny mapp",
-    "No more subfolders in here" : "Inga fler undermappar här",
-    "Name" : "Namn",
-    "Size" : "Storlek",
-    "Modified" : "Ändrad",
-    "{newName} already exists" : "{newName} existerar redan",
-    "Choose" : "Välj",
-    "Copy" : "Kopiera",
-    "Move" : "Flytta",
-    "Error loading file picker template: {error}" : "Fel uppstod för filväljarmall: {error}",
-    "OK" : "OK",
-    "Error loading message template: {error}" : "Fel uppstod under inläsningen av meddelandemallen: {error}",
-    "read-only" : "skrivskyddad",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonflikter"],
-    "One file conflict" : "En filkonflikt",
-    "New Files" : "Nya filer",
-    "Already existing files" : "Filer som redan existerar",
-    "Which files do you want to keep?" : "Vilka filer vill du behålla?",
-    "If you select both versions, the copied file will have a number added to its name." : "Om du väljer båda versionerna kommer de kopierade filerna ha nummer tillagda i filnamnet.",
-    "Cancel" : "Avbryt",
-    "Continue" : "Fortsätt",
-    "(all selected)" : "(Alla valda)",
-    "({count} selected)" : "({count} valda)",
-    "Error loading file exists template" : "Fel uppstod filmall existerar",
-    "Pending" : "Väntar",
-    "Copy to {folder}" : "Kopiera till {folder}",
-    "Move to {folder}" : "Flytta till {folder}",
-    "Saving..." : "Sparar...",
-    "seconds ago" : "sekunder sedan",
-    "Settings" : "Inställningar",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem med att ladda sidan, laddar om sidan om %n sekund","Problem med att ladda sidan, laddar om sidan om %n sekunder"],
-    "Authentication required" : "Autentisering krävs",
-    "This action requires you to confirm your password" : "Denna åtgärd kräver att du bekräftar ditt lösenord",
-    "Confirm" : "Bekräfta",
-    "Password" : "Lösenord",
-    "Failed to authenticate, try again" : "Misslyckades att autentisera, försök igen",
-    "Could not load your contacts" : "Kunde inte ladda dina kontakter",
-    "Search contacts …" : "Sök kontakter ...",
-    "No contacts found" : "Inga kontakter hittades",
-    "Show all contacts …" : "Visa alla kontakter ...",
-    "Loading your contacts …" : "Laddar dina kontakter ...",
-    "Looking for {term} …" : "Letar efter {term} …",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Vi har skickat ett mejl för lösenordsåterställning till den e-postadress som är känd för detta konto. Om du inte får det inom rimlig tid, kontrollera dina skräppost-mappar.<br>Om det inte är där, fråga din lokala administratör.",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka din data efter att ditt lösenord om ditt lösenord återställs..<br />Om du är osäker på hur du ska göra, vänligen kontakta din administratör innan du fortsätter..<br />Är du verkligen säker på att du vill fortsätta?",
-    "I know what I'm doing" : "Jag vet vad jag gör",
-    "Password can not be changed. Please contact your administrator." : "Lösenordet kan inte ändras. Vänligen kontakta din administratör.",
-    "Reset password" : "Återställ lösenord",
-    "Sending email …" : "Skickar epost ...",
-    "Logging in …" : "Loggar in ...",
-    "New in" : "Ny i",
-    "View changelog" : "Visa ändringslogg",
-    "No action available" : "Ingen åtgärd tillgänglig",
-    "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
-    "Error" : "Fel",
-    "Error while sharing" : "Fel vid delning",
-    "Error removing share" : "Fel uppstod när delning försökte tas bort",
-    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
-    "Shared with you and {circle} by {owner}" : "Delad med dig och {circle} av {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Delad med dig och konversation {conversation} av {owner}",
-    "Shared with you in a conversation by {owner}" : "Delad med dig i en konversation av {owner}",
-    "Shared with you by {owner}" : "Delad med dig av {owner}",
-    "Choose a password for the public link" : "Välj ett lösenord för den offentliga länken",
-    "Choose a password for the public link or press the \"Enter\" key" : "Välj ett lösenord för den publika länken eller tryck Enter",
-    "Copied!" : "Kopierad!",
-    "Copy link" : "Kopiera länk",
-    "Not supported!" : "Stöds ej!",
-    "Press ⌘-C to copy." : "Tryck ned ⌘-C för att kopiera.",
-    "Press Ctrl-C to copy." : "Tryck ned Ctrl-C för att kopiera.",
-    "Unable to create a link share" : "Kan inte skapa länkdelning",
-    "Unable to toggle this option" : "Kan inte växla om det här alternativet",
-    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
-    "Link" : "Länk",
-    "Hide download" : "Dölj nedladdning",
-    "Password protection enforced" : "Lösenordsskydd obligatorisk",
-    "Password protect" : "Lösenordsskydda",
-    "Allow editing" : "Tillåt redigering",
-    "Email link to person" : "Skicka länken som e-postmeddelande",
-    "Send" : "Skicka",
-    "Allow upload and editing" : "Tillåt uppladdning och redigering",
-    "Read only" : "Läsbehörigheter",
-    "File drop (upload only)" : "Göm fillista (endast uppladdning)",
-    "Expiration date enforced" : "Förfallodatum obligatorisk",
-    "Set expiration date" : "Välj utgångsdatum",
-    "Expiration" : "Upphör",
-    "Expiration date" : "Utgångsdatum",
-    "Note to recipient" : "Notering till mottagare",
-    "Unshare" : "Sluta dela",
-    "Delete share link" : "Radera delad länk",
-    "Add another link" : "Lägg till en annan länk",
-    "Password protection for links is mandatory" : "Lösenordsskydd för länkar är obligatoriskt",
-    "Share to {name}" : "Dela till {name}",
-    "Share link" : "Dela länk",
-    "New share link" : "Ny delad länk",
-    "Created on {time}" : "Skapades {time}",
-    "Password protect by Talk" : "Lösenordsskydda med Talk",
-    "Could not unshare" : "Kunde inte ta bort delning",
-    "Choose a password for the mail share" : "Välj ett lösenord för delning via e-post",
-    "group" : "Grupp",
-    "remote" : "extern",
-    "remote group" : "Fjärrgrupp",
-    "email" : "e-post",
-    "conversation" : "Konversation",
-    "shared by {sharer}" : "delat av {sharer}",
-    "Can reshare" : "Kan dela vidare",
-    "Can edit" : "Kan redigera",
-    "Can create" : "Kan skapa",
-    "Can change" : "Kan ändra",
-    "Can delete" : "Kan radera",
-    "Access control" : "Åtkomstkontroll",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} delad via länk",
-    "Share details could not be loaded for this item." : "Delningsdetaljer kunde inte laddas för detta objekt.",
-    "Search globally" : "Sök globalt",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Minst {count} tecken krävs för automatisk ifyllning","Minst {count} tecken krävs för automatisk ifyllning"],
-    "This list is maybe truncated - please refine your search term to see more results." : "Denna lista kan vara trunkerad - var god förfina dina söktermer för att se fler resultat",
-    "No users or groups found for {search}" : "Inga användare eller grupper funna för {search}",
-    "No users found for {search}" : "Inga användare funna för {search}",
-    "An error occurred (\"{message}\"). Please try again" : "Ett fel uppstod (\"{message}\"). Försök igen",
-    "An error occurred. Please try again" : "Ett fel uppstod. Vänligen försök igen",
-    "Home" : "Hem",
-    "Work" : "Arbete",
-    "Other" : "Annan",
-    "{sharee} (remote group)" : "{sharee} (remote group)",
-    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
-    "Share" : "Dela",
-    "Name or email address..." : "Namn eller e-postadress",
-    "Name or federated cloud ID..." : "Namn eller federerat moln-ID",
-    "Name, federated cloud ID or email address..." : "Namn, federerat moln-ID eller e-postadress...",
-    "Name..." : "Namn...",
-    "Shared" : "Delad",
-    "Shared with" : "Delad med",
-    "Shared by" : "Delad av",
-    "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
-    "restricted" : "begränsad",
-    "invisible" : "osynlig",
-    "({scope})" : "({scope})",
-    "Delete" : "Radera",
-    "Rename" : "Byt namn",
-    "Collaborative tags" : "Samverkanstaggar",
-    "No tags found" : "Hittade inga taggar",
     "Very weak password" : "Väldigt svagt lösenord",
     "Weak password" : "Svagt lösenord",
     "So-so password" : "Okej lösenord",
@@ -225,6 +80,94 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Din datakatalog och filer är förmodligen tillgängliga från Internet. .htaccess-filen fungerar inte. Det rekommenderas starkt att du konfigurerar din webbserver så att datakatalogen inte längre är tillgänglig eller flyttar datakatalogen utanför dokument root för webbservern.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" är inte inställd till \"{expected}\". Detta är en potentiell säkerhets- eller sekretessrisk, eftersom det rekommenderas att justera denna inställning i enlighet med detta.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" är inte inställd till \"{expected}\". Vissa funktioner kanske inte fungerar korrekt, eftersom det rekommenderas att justera den här inställningen i enlighet med detta.",
+    "Shared" : "Delad",
+    "Shared with" : "Delad med",
+    "Shared by" : "Delad av",
+    "Choose a password for the public link" : "Välj ett lösenord för den offentliga länken",
+    "Choose a password for the public link or press the \"Enter\" key" : "Välj ett lösenord för den publika länken eller tryck Enter",
+    "Copied!" : "Kopierad!",
+    "Copy link" : "Kopiera länk",
+    "Not supported!" : "Stöds ej!",
+    "Press ⌘-C to copy." : "Tryck ned ⌘-C för att kopiera.",
+    "Press Ctrl-C to copy." : "Tryck ned Ctrl-C för att kopiera.",
+    "Copy" : "Kopiera",
+    "Unable to create a link share" : "Kan inte skapa länkdelning",
+    "Unable to toggle this option" : "Kan inte växla om det här alternativet",
+    "Resharing is not allowed" : "Dela vidare är inte tillåtet",
+    "Link" : "Länk",
+    "Hide download" : "Dölj nedladdning",
+    "Password protection enforced" : "Lösenordsskydd obligatorisk",
+    "Password protect" : "Lösenordsskydda",
+    "Password" : "Lösenord",
+    "Allow editing" : "Tillåt redigering",
+    "Email link to person" : "Skicka länken som e-postmeddelande",
+    "Send" : "Skicka",
+    "Allow upload and editing" : "Tillåt uppladdning och redigering",
+    "Read only" : "Läsbehörigheter",
+    "File drop (upload only)" : "Göm fillista (endast uppladdning)",
+    "Expiration date enforced" : "Förfallodatum obligatorisk",
+    "Set expiration date" : "Välj utgångsdatum",
+    "Expiration" : "Upphör",
+    "Expiration date" : "Utgångsdatum",
+    "Note to recipient" : "Notering till mottagare",
+    "Unshare" : "Sluta dela",
+    "Delete share link" : "Radera delad länk",
+    "Add another link" : "Lägg till en annan länk",
+    "Password protection for links is mandatory" : "Lösenordsskydd för länkar är obligatoriskt",
+    "Share to {name}" : "Dela till {name}",
+    "Share link" : "Dela länk",
+    "New share link" : "Ny delad länk",
+    "Created on {time}" : "Skapades {time}",
+    "Password protect by Talk" : "Lösenordsskydda med Talk",
+    "Could not unshare" : "Kunde inte ta bort delning",
+    "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
+    "Shared with you and {circle} by {owner}" : "Delad med dig och {circle} av {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Delad med dig och konversation {conversation} av {owner}",
+    "Shared with you in a conversation by {owner}" : "Delad med dig i en konversation av {owner}",
+    "Shared with you by {owner}" : "Delad med dig av {owner}",
+    "Choose a password for the mail share" : "Välj ett lösenord för delning via e-post",
+    "group" : "Grupp",
+    "remote" : "extern",
+    "remote group" : "Fjärrgrupp",
+    "email" : "e-post",
+    "conversation" : "Konversation",
+    "shared by {sharer}" : "delat av {sharer}",
+    "Can reshare" : "Kan dela vidare",
+    "Can edit" : "Kan redigera",
+    "Can create" : "Kan skapa",
+    "Can change" : "Kan ändra",
+    "Can delete" : "Kan radera",
+    "Access control" : "Åtkomstkontroll",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} delad via länk",
+    "Error while sharing" : "Fel vid delning",
+    "Share details could not be loaded for this item." : "Delningsdetaljer kunde inte laddas för detta objekt.",
+    "Search globally" : "Sök globalt",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Minst {count} tecken krävs för automatisk ifyllning","Minst {count} tecken krävs för automatisk ifyllning"],
+    "This list is maybe truncated - please refine your search term to see more results." : "Denna lista kan vara trunkerad - var god förfina dina söktermer för att se fler resultat",
+    "No users or groups found for {search}" : "Inga användare eller grupper funna för {search}",
+    "No users found for {search}" : "Inga användare funna för {search}",
+    "An error occurred (\"{message}\"). Please try again" : "Ett fel uppstod (\"{message}\"). Försök igen",
+    "An error occurred. Please try again" : "Ett fel uppstod. Vänligen försök igen",
+    "Home" : "Hem",
+    "Work" : "Arbete",
+    "Other" : "Annan",
+    "{sharee} (remote group)" : "{sharee} (remote group)",
+    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "Share" : "Dela",
+    "Name or email address..." : "Namn eller e-postadress",
+    "Name or federated cloud ID..." : "Namn eller federerat moln-ID",
+    "Name, federated cloud ID or email address..." : "Namn, federerat moln-ID eller e-postadress...",
+    "Name..." : "Namn...",
+    "Error" : "Fel",
+    "Error removing share" : "Fel uppstod när delning försökte tas bort",
+    "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
+    "restricted" : "begränsad",
+    "invisible" : "osynlig",
+    "({scope})" : "({scope})",
+    "Delete" : "Radera",
+    "Rename" : "Byt namn",
+    "Collaborative tags" : "Samverkanstaggar",
+    "No tags found" : "Hittade inga taggar",
     "unknown text" : "okänd text",
     "Hello world!" : "Hej världen!",
     "sunny" : "soligt",
@@ -244,6 +187,79 @@ OC.L10N.register(
     "Searching other places" : "Söker på andra platser",
     "No search results in other folders for {tag}{filter}{endtag}" : "Inget sökresultat i andra mappar för {tag}{filter}{endtag}",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} sökresultat i en annan mapp","{count} sökresultat i andra mappar"],
+    "Server side authentication failed!" : "Servern misslyckades med autentisering!",
+    "Please contact your administrator." : "Kontakta din administratör.",
+    "An internal error occurred." : "Ett internt fel uppstod.",
+    "Please try again or contact your administrator." : "Vänligen försök igen eller kontakta din administratör.",
+    "Username or email" : "Användarnamn eller e-post",
+    "Username or\temail" : "Användarnamn eller\te-post",
+    "Log in" : "Logga in",
+    "Logging in …" : "Loggar in ...",
+    "Wrong username or password." : "Felaktigt användarnamn eller lösenord",
+    "User disabled" : "Användare inaktiverad",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
+    "Reset password" : "Återställ lösenord",
+    "If it is not there ask your local administrator." : "Om det inte finns, fråga din lokala administratör.",
+    "Password can not be changed. Please contact your administrator." : "Lösenordet kan inte ändras. Vänligen kontakta din administratör.",
+    "Back to login" : "Tillbaka till inloggning",
+    "Forgot password?" : "Glömt lösenordet?",
+    "Settings" : "Inställningar",
+    "Could not load your contacts" : "Kunde inte ladda dina kontakter",
+    "Search contacts …" : "Sök kontakter ...",
+    "No contacts found" : "Inga kontakter hittades",
+    "Show all contacts …" : "Visa alla kontakter ...",
+    "Loading your contacts …" : "Laddar dina kontakter ...",
+    "Looking for {term} …" : "Letar efter {term} …",
+    "No" : "Nej",
+    "Yes" : "Ja",
+    "No files in here" : "Det finns inga filer här",
+    "New folder" : "Ny mapp",
+    "No more subfolders in here" : "Inga fler undermappar här",
+    "Name" : "Namn",
+    "Size" : "Storlek",
+    "Modified" : "Ändrad",
+    "{newName} already exists" : "{newName} existerar redan",
+    "Choose" : "Välj",
+    "Move" : "Flytta",
+    "Error loading file picker template: {error}" : "Fel uppstod för filväljarmall: {error}",
+    "OK" : "OK",
+    "Error loading message template: {error}" : "Fel uppstod under inläsningen av meddelandemallen: {error}",
+    "read-only" : "skrivskyddad",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonflikter"],
+    "One file conflict" : "En filkonflikt",
+    "New Files" : "Nya filer",
+    "Already existing files" : "Filer som redan existerar",
+    "Which files do you want to keep?" : "Vilka filer vill du behålla?",
+    "If you select both versions, the copied file will have a number added to its name." : "Om du väljer båda versionerna kommer de kopierade filerna ha nummer tillagda i filnamnet.",
+    "Cancel" : "Avbryt",
+    "Continue" : "Fortsätt",
+    "(all selected)" : "(Alla valda)",
+    "({count} selected)" : "({count} valda)",
+    "Error loading file exists template" : "Fel uppstod filmall existerar",
+    "Pending" : "Väntar",
+    "Copy to {folder}" : "Kopiera till {folder}",
+    "Move to {folder}" : "Flytta till {folder}",
+    "Saving..." : "Sparar...",
+    "Authentication required" : "Autentisering krävs",
+    "This action requires you to confirm your password" : "Denna åtgärd kräver att du bekräftar ditt lösenord",
+    "Confirm" : "Bekräfta",
+    "Failed to authenticate, try again" : "Misslyckades att autentisera, försök igen",
+    "seconds ago" : "sekunder sedan",
+    "Connection to server lost" : "Anslutning till server förlorad",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem med att ladda sidan, laddar om sidan om %n sekund","Problem med att ladda sidan, laddar om sidan om %n sekunder"],
+    "Add to a project" : "Lägg till i ett projekt",
+    "Show details" : "Visa detaljer",
+    "Hide details" : "Göm detaljer",
+    "Rename project" : "Byt namn på projekt",
+    "Failed to rename the project" : "Kunde inte byta namn på projektet",
+    "Failed to create a project" : "Kunde inte skapa projekt",
+    "Failed to add the item to the project" : "Kunde inte att lägga till objektet i projektet",
+    "Connect items to a project to make them easier to find" : "Länka objekt till ett projekt för att göra dem enklare att hitta",
+    "Type to search for existing projects" : "Skriv för att söka efter befintliga projekt",
+    "New in" : "Ny i",
+    "View changelog" : "Visa ändringslogg",
+    "No action available" : "Ingen åtgärd tillgänglig",
+    "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
     "Personal" : "Personliga Inställningar",
     "Users" : "Användare",
     "Apps" : "Appar",
@@ -301,17 +317,6 @@ OC.L10N.register(
     "Contacts menu" : "Kontaktmeny",
     "Settings menu" : "Inställningsmeny",
     "Confirm your password" : "Bekräfta ditt lösenord",
-    "Server side authentication failed!" : "Servern misslyckades med autentisering!",
-    "Please contact your administrator." : "Kontakta din administratör.",
-    "An internal error occurred." : "Ett internt fel uppstod.",
-    "Please try again or contact your administrator." : "Vänligen försök igen eller kontakta din administratör.",
-    "Username or email" : "Användarnamn eller e-post",
-    "Log in" : "Logga in",
-    "Wrong username or password." : "Felaktigt användarnamn eller lösenord",
-    "User disabled" : "Användare inaktiverad",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
-    "Forgot password?" : "Glömt lösenordet?",
-    "Back to login" : "Tillbaka till inloggning",
     "Connect to your account" : "Anslut ditt konto",
     "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
     "App token" : "App-polett",
@@ -329,9 +334,13 @@ OC.L10N.register(
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj en andra faktor för autentisering:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kunde inte ladda minst en av dina aktiverade inloggningsmetoder. Vänligen kontakta din systemadministratören.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Kontakta din administratör för hjälp.",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Fortsätt och konfigurera tvåfaktorsautentisering.",
+    "Set up two-factor authentication" : "Ställ in tvåfaktorsautentisering",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Använd en av dina säkerhetskoder för att logga in eller kontakta din administratör för hjälp.",
     "Use backup code" : "Använd reservkod",
     "Cancel log in" : "Avbryt inloggning",
+    "Setup two-factor authentication" : "Ställ in tvåfaktorsautentisering",
+    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj vilken leverantör du vill konfigurera:",
     "Error while validating your second factor" : "Fel vid verifiering av tvåfaktorsautentisering.",
     "Access through untrusted domain" : "Åtkomst genom obetrodd domän",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Vänligen kontakta din administratör. Om du är en administratör, ändra \"trusted_domains\"-inställningen i config/config.php likt exemplet i config.sample.php.",
@@ -356,7 +365,12 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hör av dig till din systemadministratör om detta meddelande fortsätter eller visas oväntat.",
     "Updated \"%s\" to %s" : "Uppdaterade \"%s\" till %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\"> Ett problem uppstod under integritetskontrollen av koden. Mer information ... </a>",
+    "Dismiss" : "Avfärda",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Länken för att återställa ditt lösenord har skickats till din e-post. Om du inte mottar något inom kort, kontrollera spam/skräpkorgen.<br>Om det inte finns något där, vänligen kontakta din lokala administratör.",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka din data efter att ditt lösenord om ditt lösenord återställs..<br />Om du är osäker på hur du ska göra, vänligen kontakta din administratör innan du fortsätter..<br />Är du verkligen säker på att du vill fortsätta?",
+    "I know what I'm doing" : "Jag vet vad jag gör",
+    "Sending email …" : "Skickar epost ...",
+    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} under version {version} är installerad, för stabilitet och prestanda rekommenderar vi uppdatering till en nyare {name} version.",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "/dev/urandom är inte läsbar av PHP som är mycket avskräckt av säkerhetsskäl. Ytterligare information finns i <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentationen</a>.",
     "Copy URL" : "Kopiera URL",
     "Enable" : "Aktivera",
@@ -378,6 +392,7 @@ OC.L10N.register(
     "Further information how to configure this can be found in the %sdocumentation%s." : "Ytterligare information hur du konfigurerar detta finns i %sdokumentationen%s.",
     "%s will be updated to version %s" : "%s kommer att uppdateras till version %s",
     "This page will refresh itself when the %s instance is available again." : "Denna sida uppdaterar sig själv när %s-instansen är tillgänglig igen.",
-    "Thank you for your patience." : "Tack för ditt tålamod."
+    "Thank you for your patience." : "Tack för ditt tålamod.",
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Vi har skickat ett mejl för lösenordsåterställning till den e-postadress som är känd för detta konto. Om du inte får det inom rimlig tid, kontrollera dina skräppost-mappar.<br>Om det inte är där, fråga din lokala administratör."
 },
 "nplurals=2; plural=(n != 1);");
