@@ -59,151 +59,6 @@ OC.L10N.register(
     "%s (incompatible)" : "%s （不兼容）",
     "Following apps have been disabled: %s" : "下列应用已经被禁用：%s",
     "Already up to date" : "已经是最新",
-    ": " : "：",
-    "Dismiss" : "忽略",
-    "Connection to server lost" : "与服务器的连接断开",
-    "No" : "否",
-    "Yes" : "是",
-    "No files in here" : "未找到文件",
-    "New folder" : "新建文件夹",
-    "No more subfolders in here" : "没有更多的子文件夹",
-    "Name" : "名称",
-    "Size" : "大小",
-    "Modified" : "已修改",
-    "{newName} already exists" : "{newName} 已经存在",
-    "Choose" : "选择",
-    "Copy" : "复制",
-    "Move" : "移动",
-    "Error loading file picker template: {error}" : "加载文件选择模板出错：{error}",
-    "OK" : "确认",
-    "Error loading message template: {error}" : "加载消息模板出错：{error}",
-    "read-only" : "只读",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 个文件冲突"],
-    "One file conflict" : "1 个文件冲突",
-    "New Files" : "新文件",
-    "Already existing files" : "已经存在的文件",
-    "Which files do you want to keep?" : "请选择需要保留的文件？",
-    "If you select both versions, the copied file will have a number added to its name." : "如果同时选择了两个版本，副本的文件名中将会追加数字。",
-    "Cancel" : "取消",
-    "Continue" : "继续",
-    "(all selected)" : "（选中全部）",
-    "({count} selected)" : "（选择了 {count} 个）",
-    "Error loading file exists template" : "加载文件存在性模板失败",
-    "Pending" : "等待",
-    "Copy to {folder}" : "复制到 {folder}",
-    "Move to {folder}" : "移动到 {folder}",
-    "Saving..." : "保存中...",
-    "seconds ago" : "几秒前",
-    "Settings" : "设置",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在 %n 秒后重新加载"],
-    "Authentication required" : "授权请求",
-    "This action requires you to confirm your password" : "请您确认您的密码",
-    "Confirm" : "确认",
-    "Password" : "密码",
-    "Failed to authenticate, try again" : "授权失败，请重试",
-    "Could not load your contacts" : "无法加载您的联系人",
-    "Search contacts …" : "搜索联系人 …",
-    "No contacts found" : "无法找到联系人",
-    "Show all contacts …" : "显示所有联系人 …",
-    "Loading your contacts …" : "加载您的联系人 …",
-    "Looking for {term} …" : "查找 {term} …",
-    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "我们已将密码重置电子邮件发送到我们已知道的此帐户的电子邮件地址。 如果您未在合理的时间内收到，请检查您的垃圾邮件/垃圾邮件文件夹。<br> 如果不存在，请咨询管理员。",
-    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "您的文件已经加密。当您的密码重置后没有任何方式能恢复您的数据。<br />如果您不确定，请在继续前联系您的管理员。<br/>您是否真的要继续？",
-    "I know what I'm doing" : "我知道我在做什么",
-    "Password can not be changed. Please contact your administrator." : "无法修改密码，请联系管理员。",
-    "Reset password" : "重置密码",
-    "Sending email …" : "正在发送邮件…",
-    "Logging in …" : "正在登录 …",
-    "New in" : "新品",
-    "View changelog" : "查看更新记录",
-    "No action available" : "无可用操作",
-    "Error fetching contact actions" : "查找联系人时出错",
-    "Error" : "错误",
-    "Error while sharing" : "共享时出错",
-    "Error removing share" : "移除共享时出错",
-    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
-    "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 共享给您及对话 {conversation}",
-    "Shared with you in a conversation by {owner}" : "由 {owner} 通过一个对话与您分享",
-    "Shared with you by {owner}" : "{owner} 共享给您",
-    "Choose a password for the public link" : "为公开链接设置密码",
-    "Choose a password for the public link or press the \"Enter\" key" : "为公开链接设置密码，或按 \"回车\" 键",
-    "Copied!" : "已复制！",
-    "Copy link" : "复制链接",
-    "Not supported!" : "不支持！",
-    "Press ⌘-C to copy." : "按 ⌘ + C 进行复制。",
-    "Press Ctrl-C to copy." : "按  Ctrl + C 进行复制。",
-    "Unable to create a link share" : "无法创建共享链接",
-    "Unable to toggle this option" : "无法切换此项",
-    "Resharing is not allowed" : "不允许二次共享",
-    "Link" : "链接",
-    "Hide download" : "隐藏下载",
-    "Password protection enforced" : "强制密码保护",
-    "Password protect" : "密码保护",
-    "Allow editing" : "允许编辑",
-    "Email link to person" : "发送链接到个人",
-    "Send" : "发送",
-    "Allow upload and editing" : "允许上传和编辑",
-    "Read only" : "只读",
-    "File drop (upload only)" : "文件拖拽（仅上传）",
-    "Expiration date enforced" : "强制有效期",
-    "Set expiration date" : "设置过期日期",
-    "Expiration" : "过期",
-    "Expiration date" : "过期日期",
-    "Note to recipient" : "备注",
-    "Unshare" : "取消共享",
-    "Delete share link" : "删除共享链接",
-    "Add another link" : "添加其他链接",
-    "Password protection for links is mandatory" : "强制使用密码保护的链接",
-    "Share to {name}" : "共享给 {name}",
-    "Share link" : "共享链接",
-    "New share link" : "新共享链接",
-    "Created on {time}" : "创建于 {time}",
-    "Password protect by Talk" : "通过 Talk 保护密码",
-    "Could not unshare" : "无法共享",
-    "Choose a password for the mail share" : "为电子邮件共享选择一个密码",
-    "group" : "群组",
-    "remote" : "外部",
-    "remote group" : "远程群组",
-    "email" : "邮件",
-    "conversation" : "对话",
-    "shared by {sharer}" : "由 {sharer} 共享",
-    "Can reshare" : "可以再次共享",
-    "Can edit" : "可以编辑",
-    "Can create" : "可以创建",
-    "Can change" : "可以修改",
-    "Can delete" : "可以删除",
-    "Access control" : "访问控制",
-    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} 通过链接共享",
-    "Share details could not be loaded for this item." : "无法加载这个项目的共享详情。",
-    "Search globally" : "全局搜索",
-    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["{count}字符需要自动完成"],
-    "This list is maybe truncated - please refine your search term to see more results." : "此列表可能会被截断 - 请缩短您的搜索词以查看更多结果。",
-    "No users or groups found for {search}" : "{search} 条件下没有找到用户或用户组",
-    "No users found for {search}" : "没有找到 {search} 用户",
-    "An error occurred (\"{message}\"). Please try again" : "发生错误（\"{message}\"）。请重试",
-    "An error occurred. Please try again" : "发生错误。请重试",
-    "Home" : "家庭",
-    "Work" : "工作",
-    "Other" : "其他",
-    "{sharee} (remote group)" : "{sharee}（远程组）",
-    "{sharee} ({type}, {owner})" : "{share}({type},{owner})",
-    "Share" : "共享",
-    "Name or email address..." : "姓名或电子邮件地址...",
-    "Name or federated cloud ID..." : "姓名或联合云 ID...",
-    "Name, federated cloud ID or email address..." : "姓名，联合云 ID 或电子邮件地址...",
-    "Name..." : "名称...",
-    "Shared" : "已共享",
-    "Shared with" : "共享给",
-    "Shared by" : "共享人",
-    "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
-    "restricted" : "受限",
-    "invisible" : "不可见",
-    "({scope})" : "({scope})",
-    "Delete" : "删除",
-    "Rename" : "重命名",
-    "Collaborative tags" : "协作标签",
-    "No tags found" : "标签未找到",
     "Very weak password" : "非常弱的密码",
     "Weak password" : "弱密码",
     "So-so password" : "一般强度的密码",
@@ -255,6 +110,94 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP 头 \"{header}\" 未设置成 \"{val1}\"，\"{val2}\"，\"{val3}\"，\"{val4}\" 或 \"{val5}\"。这会泄露更多的信息。请查阅 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C 建议↗</a>。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "HTTP的请求头 \"Strict-Transport-Security\" 未设置为至少 \"{seconds}\" 秒。为了提高安全性，建议参照<a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>中的说明启用HSTS。",
     "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "通过 HTTP 访问网站不安全。强烈建议您将服务器设置成 HTTPS 协议，请查阅 <a href=\"{docUrl}\">安全贴士↗</a>。",
+    "Shared" : "已共享",
+    "Shared with" : "共享给",
+    "Shared by" : "共享人",
+    "Choose a password for the public link" : "为公开链接设置密码",
+    "Choose a password for the public link or press the \"Enter\" key" : "为公开链接设置密码，或按 \"回车\" 键",
+    "Copied!" : "已复制！",
+    "Copy link" : "复制链接",
+    "Not supported!" : "不支持！",
+    "Press ⌘-C to copy." : "按 ⌘ + C 进行复制。",
+    "Press Ctrl-C to copy." : "按  Ctrl + C 进行复制。",
+    "Copy" : "复制",
+    "Unable to create a link share" : "无法创建共享链接",
+    "Unable to toggle this option" : "无法切换此项",
+    "Resharing is not allowed" : "不允许二次共享",
+    "Link" : "链接",
+    "Hide download" : "隐藏下载",
+    "Password protection enforced" : "强制密码保护",
+    "Password protect" : "密码保护",
+    "Password" : "密码",
+    "Allow editing" : "允许编辑",
+    "Email link to person" : "发送链接到个人",
+    "Send" : "发送",
+    "Allow upload and editing" : "允许上传和编辑",
+    "Read only" : "只读",
+    "File drop (upload only)" : "文件拖拽（仅上传）",
+    "Expiration date enforced" : "强制有效期",
+    "Set expiration date" : "设置过期日期",
+    "Expiration" : "过期",
+    "Expiration date" : "过期日期",
+    "Note to recipient" : "备注",
+    "Unshare" : "取消共享",
+    "Delete share link" : "删除共享链接",
+    "Add another link" : "添加其他链接",
+    "Password protection for links is mandatory" : "强制使用密码保护的链接",
+    "Share to {name}" : "共享给 {name}",
+    "Share link" : "共享链接",
+    "New share link" : "新共享链接",
+    "Created on {time}" : "创建于 {time}",
+    "Password protect by Talk" : "通过 Talk 保护密码",
+    "Could not unshare" : "无法共享",
+    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
+    "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 共享给您及对话 {conversation}",
+    "Shared with you in a conversation by {owner}" : "由 {owner} 通过一个对话与您分享",
+    "Shared with you by {owner}" : "{owner} 共享给您",
+    "Choose a password for the mail share" : "为电子邮件共享选择一个密码",
+    "group" : "群组",
+    "remote" : "外部",
+    "remote group" : "远程群组",
+    "email" : "邮件",
+    "conversation" : "对话",
+    "shared by {sharer}" : "由 {sharer} 共享",
+    "Can reshare" : "可以再次共享",
+    "Can edit" : "可以编辑",
+    "Can create" : "可以创建",
+    "Can change" : "可以修改",
+    "Can delete" : "可以删除",
+    "Access control" : "访问控制",
+    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} 通过链接共享",
+    "Error while sharing" : "共享时出错",
+    "Share details could not be loaded for this item." : "无法加载这个项目的共享详情。",
+    "Search globally" : "全局搜索",
+    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["{count}字符需要自动完成"],
+    "This list is maybe truncated - please refine your search term to see more results." : "此列表可能会被截断 - 请缩短您的搜索词以查看更多结果。",
+    "No users or groups found for {search}" : "{search} 条件下没有找到用户或用户组",
+    "No users found for {search}" : "没有找到 {search} 用户",
+    "An error occurred (\"{message}\"). Please try again" : "发生错误（\"{message}\"）。请重试",
+    "An error occurred. Please try again" : "发生错误。请重试",
+    "Home" : "家庭",
+    "Work" : "工作",
+    "Other" : "其他",
+    "{sharee} (remote group)" : "{sharee}（远程组）",
+    "{sharee} ({type}, {owner})" : "{share}({type},{owner})",
+    "Share" : "共享",
+    "Name or email address..." : "姓名或电子邮件地址...",
+    "Name or federated cloud ID..." : "姓名或联合云 ID...",
+    "Name, federated cloud ID or email address..." : "姓名，联合云 ID 或电子邮件地址...",
+    "Name..." : "名称...",
+    "Error" : "错误",
+    "Error removing share" : "移除共享时出错",
+    "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
+    "restricted" : "受限",
+    "invisible" : "不可见",
+    "({scope})" : "({scope})",
+    "Delete" : "删除",
+    "Rename" : "重命名",
+    "Collaborative tags" : "协作标签",
+    "No tags found" : "标签未找到",
     "unknown text" : "未知文字",
     "Hello world!" : "你好，世界！",
     "sunny" : "晴",
@@ -274,6 +217,80 @@ OC.L10N.register(
     "Searching other places" : "搜索其他位置",
     "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于 {tag}{filter}{endtag} 的搜索结果",
     "_{count} search result in another folder_::_{count} search results in other folders_" : ["在其他文件夹中找到 {count} 条搜索结果"],
+    "Server side authentication failed!" : "服务端认证失败！",
+    "Please contact your administrator." : "请联系您的管理员。",
+    "An internal error occurred." : "发生了内部错误。",
+    "Please try again or contact your administrator." : "请重试或联系您的管理员。",
+    "Username or email" : "用户名或邮箱",
+    "Username or\temail" : "用户名或\t邮箱",
+    "Log in" : "登录",
+    "Logging in …" : "正在登录 …",
+    "Wrong username or password." : "错误的用户名或密码。",
+    "User disabled" : "用户不可用",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到您的 IP 进行了多次无效登录尝试。因此，请 30 秒之后再尝试。",
+    "Reset password" : "重置密码",
+    "If it is not there ask your local administrator." : "如果它不在此处，请询问您的本地管理员。",
+    "Password can not be changed. Please contact your administrator." : "无法修改密码，请联系管理员。",
+    "Back to login" : "返回登录",
+    "Forgot password?" : "忘记密码？",
+    "Settings" : "设置",
+    "Could not load your contacts" : "无法加载您的联系人",
+    "Search contacts …" : "搜索联系人 …",
+    "No contacts found" : "无法找到联系人",
+    "Show all contacts …" : "显示所有联系人 …",
+    "Install the Contacts app" : "安装联系人应用",
+    "Loading your contacts …" : "加载您的联系人 …",
+    "Looking for {term} …" : "查找 {term} …",
+    "No" : "否",
+    "Yes" : "是",
+    "No files in here" : "未找到文件",
+    "New folder" : "新建文件夹",
+    "No more subfolders in here" : "没有更多的子文件夹",
+    "Name" : "名称",
+    "Size" : "大小",
+    "Modified" : "已修改",
+    "{newName} already exists" : "{newName} 已经存在",
+    "Choose" : "选择",
+    "Move" : "移动",
+    "Error loading file picker template: {error}" : "加载文件选择模板出错：{error}",
+    "OK" : "确认",
+    "Error loading message template: {error}" : "加载消息模板出错：{error}",
+    "read-only" : "只读",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 个文件冲突"],
+    "One file conflict" : "1 个文件冲突",
+    "New Files" : "新文件",
+    "Already existing files" : "已经存在的文件",
+    "Which files do you want to keep?" : "请选择需要保留的文件？",
+    "If you select both versions, the copied file will have a number added to its name." : "如果同时选择了两个版本，副本的文件名中将会追加数字。",
+    "Cancel" : "取消",
+    "Continue" : "继续",
+    "(all selected)" : "（选中全部）",
+    "({count} selected)" : "（选择了 {count} 个）",
+    "Error loading file exists template" : "加载文件存在性模板失败",
+    "Pending" : "等待",
+    "Copy to {folder}" : "复制到 {folder}",
+    "Move to {folder}" : "移动到 {folder}",
+    "Saving..." : "保存中...",
+    "Authentication required" : "授权请求",
+    "This action requires you to confirm your password" : "请您确认您的密码",
+    "Confirm" : "确认",
+    "Failed to authenticate, try again" : "授权失败，请重试",
+    "seconds ago" : "几秒前",
+    "Connection to server lost" : "与服务器的连接断开",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在 %n 秒后重新加载"],
+    "Add to a project" : "添加到项目",
+    "Show details" : "显示详情",
+    "Hide details" : "隐藏详细信息",
+    "Rename project" : "重命名项目",
+    "Failed to rename the project" : "无法重命名项目",
+    "Failed to create a project" : "无法创建项目",
+    "Failed to add the item to the project" : "无法添加条目到项目中",
+    "Connect items to a project to make them easier to find" : "将条目关联到项目以使它们更容易查找",
+    "Type to search for existing projects" : "输入以搜索已有项目",
+    "New in" : "新品",
+    "View changelog" : "查看更新记录",
+    "No action available" : "无可用操作",
+    "Error fetching contact actions" : "查找联系人时出错",
     "Personal" : "个人",
     "Users" : "用户",
     "Apps" : "应用",
@@ -336,17 +353,6 @@ OC.L10N.register(
     "Contacts menu" : "联系人菜单",
     "Settings menu" : "设置菜单",
     "Confirm your password" : "确认您的密码",
-    "Server side authentication failed!" : "服务端认证失败！",
-    "Please contact your administrator." : "请联系您的管理员。",
-    "An internal error occurred." : "发生了内部错误。",
-    "Please try again or contact your administrator." : "请重试或联系您的管理员。",
-    "Username or email" : "用户名或邮箱",
-    "Log in" : "登录",
-    "Wrong username or password." : "错误的用户名或密码。",
-    "User disabled" : "用户不可用",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到您的 IP 进行了多次无效登录尝试。因此，请 30 秒之后再尝试。",
-    "Forgot password?" : "忘记密码？",
-    "Back to login" : "返回登录",
     "Connect to your account" : "连接您的账户",
     "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的 %2$s 账户之前，请先登录。",
     "App token" : "App 令牌",
@@ -364,9 +370,13 @@ OC.L10N.register(
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的账户已启用安全增强。请选择第二种验证方式。",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "无法载入您启用的任何两步验证方法。请联系管理员。",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "两步验证是强制性的，但您的账户似乎未做配置。请联系管理员获得支持。",
+    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "两步验证是强制性的，但您的账户未做配置。请联系管理员配置两步验证。",
+    "Set up two-factor authentication" : "配置两步验证",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "两步验证是强制性的，但您的账户似乎未做配置。使用您的备份代码登录或联系管理员。",
     "Use backup code" : "使用备用口令",
     "Cancel log in" : "取消登录",
+    "Setup two-factor authentication" : "配置两步验证",
+    "Enhanced security is enforced for your account. Choose wich provider to set up:" : "您的账户已启用安全增强。请选择提供者进行配置：",
     "Error while validating your second factor" : "验证您的第二项时出错",
     "Access through untrusted domain" : "通过不被信任的域名访问",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "请联系您的管理员。如果您就是管理员，请参照 config.sample.php 中的示例编辑 config/config.php 中的  \"trusted_domains\" 设置。",
@@ -391,7 +401,11 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系您的系统管理员。",
     "Updated \"%s\" to %s" : "更新 \"%s\" 为 %s",
     "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">代码完整性检查出现异常，点击查看详细信息...</a>",
+    "Dismiss" : "忽略",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "密码重置邮件已经发送到您的电子邮箱中。如果您长时间没能收到邮件，请检查您邮箱的垃圾/广告文件夹。<br>如果未能收到邮件请联系管理员。",
+    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "您的文件已经加密。当您的密码重置后没有任何方式能恢复您的数据。<br />如果您不确定，请在继续前联系您的管理员。<br/>您是否真的要继续？",
+    "I know what I'm doing" : "我知道我在做什么",
+    "Sending email …" : "正在发送邮件…",
     "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} 已安装 {version} 版本，出于稳定和性能的考虑，建议更新到 {name} 版本。",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP 无法访问 /dev/urandom，出于安全原因这是强烈不推荐的。更多信息请参见<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档</a>。",
     "Copy URL" : "复制超链接",
@@ -414,6 +428,7 @@ OC.L10N.register(
     "Further information how to configure this can be found in the %sdocumentation%s." : "更多配置信息可以查看 %s文档%s。",
     "%s will be updated to version %s" : "%s 将会更新至版本 %s",
     "This page will refresh itself when the %s instance is available again." : "当实例 %s 再次可用时此页面将刷新。",
-    "Thank you for your patience." : "感谢您久等了。"
+    "Thank you for your patience." : "感谢您久等了。",
+    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "我们已将密码重置电子邮件发送到我们已知道的此帐户的电子邮件地址。 如果您未在合理的时间内收到，请检查您的垃圾邮件/垃圾邮件文件夹。<br> 如果不存在，请咨询管理员。"
 },
 "nplurals=1; plural=0;");
